@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/admin/groups.php,v 1.50.2.8 2007/01/02 13:54:03 jan Exp $
+ * $Horde: horde/admin/groups.php,v 1.50.2.1 2005/02/17 00:18:54 jan Exp $
  *
- * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999, 2000, 2001 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -44,22 +44,18 @@ case 'addchildform':
     $parent = $cid;
     if ($parent == DATATREE_ROOT) {
         $child = &$groups->newGroup(Util::getFormData('child'));
+        $result = $groups->addGroup($child);
     } else {
-        $child = &$groups->newGroup(Util::getFormData('child'), $parent);
+        $pOb = &$groups->getGroupById($parent);
+        $name = $pOb->getName() . ':' . DataTree::encodeName(Util::getFormData('child'));
+        $child = &$groups->newGroup($name);
+        $result = $groups->addGroup($child);
     }
-    if (is_a($child, 'PEAR_Error')) {
-        Horde::logMessage($child, __FILE__, __LINE__, PEAR_LOG_ERR);
-        $notification->push(sprintf(_("Group was not created: %s."), $child->getMessage()), 'horde.error');
-        break;
-    }
-
-    $result = $groups->addGroup($child);
     if (is_a($result, 'PEAR_Error')) {
-        Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
-        $notification->push(sprintf(_("\"%s\" was not created: %s."), $child->getShortName(), $result->getMessage()), 'horde.error');
+        $notification->push(sprintf(_("'%s' was not created: %s."), $child->getShortName(), $result->getMessage()), 'horde.error');
     } else {
-        $notification->push(sprintf(_("\"%s\" was added to the groups system."), $child->getShortName()), 'horde.success');
-        $group = $child;
+        $notification->push(sprintf(_("'%s' was added to the groups system."), $child->getShortName()), 'horde.success');
+        $group = &$child;
         $form = 'edit.inc';
         $reload = true;
     }
@@ -80,9 +76,9 @@ case 'deleteform':
         } else {
             $result = $groups->removeGroup($group, true);
             if (is_a($result, 'PEAR_Error')) {
-                $notification->push(sprintf(_("Unable to delete \"%s\": %s."), $group->getShortName(), $result->getMessage()), 'horde.error');
+                $notification->push(sprintf(_("Unable to delete '%s': %s."), $group->getShortName(), $result->getMessage()), 'horde.error');
              } else {
-                $notification->push(sprintf(_("Successfully deleted \"%s\"."), $group->getShortName()), 'horde.success');
+                $notification->push(sprintf(_("Successfully deleted '%s'."), $group->getShortName()), 'horde.success');
                 $cid = null;
                 $reload = true;
             }
@@ -112,9 +108,6 @@ case 'edit':
 case 'editform':
     $group = &$groups->getGroupById($cid);
 
-    // make a copy of the group so we can restore it if there is an error.
-    $restore = $group;
-
     // Add any new users.
     $newuser = Util::getFormData('new_user');
     if (!empty($newuser)) {
@@ -139,22 +132,16 @@ case 'editform':
     $group->set('email', Util::getFormData('email'));
 
     // Save the group to the backend.
-    $result = $group->save();
-
-    if (is_a($result, 'PEAR_Error')) {
-        $notification->push($result->getMessage(), 'horde.error');
-        // restore backup copy
-        $group = $restore;
-    } else {
-        $notification->push(sprintf(_("Updated \"%s\"."), $group->getShortName()), 'horde.success');
-    }
+    $group->save();
 
+    $notification->push(sprintf(_("Updated '%s'."), $group->getShortName()), 'horde.success');
     $form = 'edit.inc';
     $reload = true;
     break;
 }
 
 switch ($form) {
+
 case 'addchild.inc':
     $notification->push('document.add_child.child.focus()', 'javascript');
     break;
@@ -166,13 +153,6 @@ case 'edit.inc':
         $notification->push($users, 'horde.error');
         $users = array();
     }
-    $all_users = $group->listAllUsers();
-    if (is_a($all_users, 'PEAR_Error')) {
-        $notification->push($all_users, 'horde.error');
-        $all_users = array();
-    }
-    $inherited_users = array_diff($all_users, $users);
-
     if ($auth->hasCapability('list')) {
         $user_list = $auth->listUsers();
         if (is_a($user_list, 'PEAR_Error')) {
@@ -192,12 +172,11 @@ require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/admin/common-header.inc';
 $notification->notify(array('listeners' => 'status'));
 if (!empty($form)) {
-    require HORDE_TEMPLATES . '/admin/groups/' . $form;
+    include HORDE_TEMPLATES . '/admin/groups/' . $form;
 }
 
 /* Get the perms tree. */
-$nodes = $groups->listGroups(true);
-$nodes[DATATREE_ROOT] = DATATREE_ROOT;
+$nodes = $groups->_datatree->get(DATATREE_FORMAT_FLAT, -1, true);
 
 /* Set up some node params. */
 $spacer = '&nbsp;&nbsp;&nbsp;&nbsp;';
@@ -210,39 +189,38 @@ $edit_img = Horde::img('edit.png', _("Edit Group"));
 $delete_img = Horde::img('delete.png', _("Delete Group"));
 
 /* Set up the tree. */
-$tree = Horde_Tree::factory('admin_groups', 'javascript');
+$tree = &Horde_Tree::singleton('admin_groups', 'javascript');
 $tree->setOption(array('alternate' => true, 'hideHeaders' => true));
 $tree->setHeader(array(array('width' => '50%')));
 
 /* Explicitly check for > 0 since we can be called with current = -1
  * for the root node. */
 if ($cid > 0) {
-    $cid_parents = $groups->getGroupParentList($cid);
+    $cid_parents = $groups->_datatree->getParentList($cid);
     if (is_a($cid_parents, 'PEAR_ERror')) {
         Horde::fatal($cid_parents, __FILE__, __LINE__);
     }
 }
 
 foreach ($nodes as $id => $node) {
-    $node_params = ($cid == $id) ? array('class' => 'selected') : array();
-    if ($id == DATATREE_ROOT) {
+    $node_class = ($cid == $id) ? array('class' => 'selected') : array();
+    if ($id == -1) {
         $add_img = Horde::img('group.png', _("Add New Group"));
         $add_link = Horde::link(Util::addParameter($add, 'cid', $id), _("Add New Group")) . $add_img . '</a>';
 
         $base_node_params = $icondir + array('icon' => 'administration.png');
-        $tree->addNode($id, null, _("All Groups"), 0, true, $base_node_params + $node_params, array($spacer, $add_link));
+        $tree->addNode($id, null, _("All Groups"), 0, true, $base_node_params + $node_class, array($spacer, $add_link));
     } else {
-        $node_params['url'] = Util::addParameter($edit, 'cid', $id);
         $add_img = Horde::img('group.png', _("Add Child Group"));
         $add_link = Horde::link(Util::addParameter($add, 'cid', $id), _("Add Child Group")) . $add_img . '</a>';
+        $edit_link = Horde::link(Util::addParameter($edit, 'cid', $id), _("Edit Group")) . $edit_img . '</a>';
         $delete_link = Horde::link(Util::addParameter($delete, 'cid', $id), _("Delete Group")) . $delete_img . '</a>';
 
-        $parent_id = $groups->getGroupParent($id);
-        $group_extra = array($spacer, $add_link, $delete_link);
-        $tree->addNode($id, $parent_id, $groups->getGroupShortName($node), $groups->getLevel($id) + 1, (isset($cid_parents[$id])) ? true : false, $group_node + $node_params, $group_extra);
+        $parent_id = $groups->_datatree->getParent($node);
+        $group_extra = array($spacer, $add_link, $edit_link, $delete_link);
+        $tree->addNode($id, $parent_id, DataTree::getShortName($node), substr_count($node, ':') + 1, (isset($cid_parents[$id])) ? true : false, $group_node + $node_class, $group_extra);
     }
 }
 
-echo '<h1 class="header">' . Horde::img('group.png') . ' ' . _("Groups") . '</h1>';
 $tree->renderTree();
 require HORDE_TEMPLATES . '/common-footer.inc';
