@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/js/alphaImageLoader.php,v 1.2.8.2 2005/05/04 21:08:20 chuck Exp $
+ * $Horde: horde/js/alphaImageLoader.php,v 1.2.8.1 2005/01/03 12:25:39 jan Exp $
  *
  * Copyright 2004-2005 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -24,6 +24,7 @@ header('Content-Type: text/x-component');
 <public:attach event="onpropertychange" for="element" onEvent="propertyChanged()" />
 <script language="JavaScript">
 
+var needHack = needHack();
 var transparentImage = "<?php echo $registry->getImageDir('horde') ?>/blank.gif";
 
 pngHack();
@@ -37,6 +38,10 @@ function propertyChanged()
 
 function pngHack()
 {
+    if (!needHack) {
+        return;
+    }
+
     var w = element.width;
     var h = element.height;
     var src = element.src;
@@ -56,5 +61,17 @@ function pngHack()
     element.runtimeStyle.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + src + "',sizingMethod='scale')";
 }
 
+function needHack()
+{
+    var pos = navigator.userAgent.indexOf("MSIE ");
+    if (pos == -1) {
+        return false;
+    }
+
+    var version = navigator.userAgent.substring(pos + 5);
+
+    return (((version.indexOf("5.5") == 0) || (version.indexOf("6") == 0)) && (navigator.platform == ("Win32")));
+}
+
 </script>
 </public:component>
