@@ -1,26 +1,18 @@
 <?php
 
-if ((@include_once 'Services/Weather.php') &&
-    !empty($GLOBALS['conf']['sql']['phptype'])) {
-    $block_name = _("Metar Weather");
-}
+$block_name = _("Metar Weather");
 
 /**
  * The Horde_Block_metar class provides an applet for the portal
  * screen to display METAR weather data for a specified location
  * (currently airports).
  *
- * $Horde: horde/lib/Block/metar.php,v 1.22.10.9 2008/08/28 19:37:59 mrubinsk Exp $
+ * $Horde: horde/lib/Block/metar.php,v 1.22 2004/10/29 15:38:12 jan Exp $
  *
  * @package Horde_Block
  */
 class Horde_Block_Horde_metar extends Horde_Block {
 
-    /**
-     * Whether this block has changing content.
-     */
-    var $updateable = true;
-
     var $_app = 'horde';
 
     /**
@@ -55,15 +47,6 @@ class Horde_Block_Horde_metar extends Horde_Block {
                 return $db;
             }
 
-            // Set DB portability options.
-            switch ($db->phptype) {
-            case 'mssql':
-                $db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS | DB_PORTABILITY_RTRIM);
-                break;
-            default:
-                $db->setOption('portability', DB_PORTABILITY_LOWERCASE | DB_PORTABILITY_ERRORS);
-            }
-
             $result = $db->query('SELECT icao, name, country FROM metarAirports ORDER BY country');
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
@@ -106,12 +89,12 @@ class Horde_Block_Horde_metar extends Horde_Block {
 
     function _row($label, $content)
     {
-        return '<br /><strong>' . $label . ':</strong> ' . $content;
+        return '<br /><b>' . $label . ':</b> ' . $content;
     }
 
     function _sameRow($label, $content)
     {
-        return ' <strong>' . $label . ':</strong> ' . $content;
+        return ' <b>' . $label . ':</b> ' . $content;
     }
 
     /**
@@ -142,39 +125,42 @@ class Horde_Block_Horde_metar extends Horde_Block {
             $metarLocs = $this->getParams();
         }
 
+        require_once 'Services/Weather.php';
         $metar = &Services_Weather::service('METAR', array('debug' => 0));
-        $metar->setMetarDB($conf['sql']);
+        $dbString = $conf['sql']['phptype'] . '://';
+        $dbString .= $conf['sql']['username'] . ':';
+        $dbString .= $conf['sql']['password'] . '@';
+        $dbString .= $conf['sql']['hostspec'] . '/';
+        $dbString .= $conf['sql']['database'];
+        $metar->setMetarDB($dbString);
         $metar->setUnitsFormat($this->_params['units']);
         $metar->setDateTimeFormat('M j, Y', 'H:i');
         $metar->setMetarSource('http');
 
         $units = $metar->getUnitsFormat($this->_params['units']);
         $weather = $metar->getWeather($this->_params['location']);
-        if (is_a($weather, 'PEAR_Error')) {
-            $html = $weather->getMessage();
-            return $html;
-        }
-        $html = '<table width="100%" cellspacing="0">' .
-            '<tr><td class="control"><strong>' .
+
+        $html = '<table width="100%" border="0" cellpadding="0" cellspacing="0">' .
+            '<tr><td class="control"><b>' .
             sprintf('%s, %s (%s)',
                     $metarLocs['location']['values'][$this->_params['__location']][$this->_params['location']],
                     $this->_params['__location'],
                     $this->_params['location']) .
-            '</strong></td></tr></table><strong>' . _("Last Updated:") . '</strong> ' .
+            '</td></tr></table><b>' . _("Last Updated:") . '</b> ' .
             $weather['update'] . '<br /><br />';
 
         // Wind.
         if (isset($weather['wind'])) {
-            $html .= '<strong>' . _("Wind:") . '</strong> ';
+            $html .= '<b>' . _("Wind:") . '</b> ';
             if ($weather['windDirection'] == 'Variable') {
                 if (!empty($this->_params['knots'])) {
-                    $html .= sprintf(_("%s at %s %s"),
+                    $html .= sprintf(_('%s at %s %s'),
                         $weather['windDirection'],
                         round($metar->convertSpeed($weather['wind'],
                             $units['wind'], 'kt')),
                         'kt');
                 } else {
-                    $html .= sprintf(_("%s at %s %s"),
+                    $html .= sprintf(_('%s at %s %s'),
                         $weather['windDirection'],
                         round($weather['wind']),
                         $units['wind']);
@@ -275,12 +261,12 @@ class Horde_Block_Horde_metar extends Horde_Block {
                     foreach ($value as $precip) {
                         if (is_numeric($precip['amount'])) {
                             $remarks .= '<br />' .
-                                sprintf(ngettext("Precipitation for last %d hour: ", "Precipitation for last %d hours: ", $precip['hours']),
+                                sprintf(_("Precipitation for last %s hour(s): "),
                                         $precip['hours']) .
                                 $precip['amount'] . ' ' . $units['rain'];
                         } else {
                             $remarks .= '<br />' .
-                                sprintf(ngettext("Precipitation for last %d hour: ", "Precipitation for last %d hours: ", $precip['hours']),
+                                sprintf(_("Precipitation for last %s hour(s): "),
                                         $precip['hours']) . $precip['amount'];
                         }
                     }
@@ -295,7 +281,7 @@ class Horde_Block_Horde_metar extends Horde_Block {
                     break;
 
                 case 'sunduration':
-                    $remarks .= '<br />' . sprintf(_("%d minutes"), $value);
+                    $remarks .= '<br />' . sprintf(_("%s minutes"), $value);
                     break;
 
                 case '1htemp':
@@ -342,25 +328,25 @@ class Horde_Block_Horde_metar extends Horde_Block {
         if (!empty($this->_params['taf'])) {
             $taf = $metar->getForecast($this->_params['location']);
             if (!is_a($taf, 'PEAR_Error')) {
-                $forecast = '<table width="100%" cellspacing="0">';
-                $forecast .= '<tr><td class="control" colspan="2"><center><strong>' . _("Forecast (TAF)") . '</strong></td></tr></table>';
-                $forecast .= '<strong>Valid: </strong>' . $taf['validFrom'] . ' - ' . $taf['validTo'] . '<br /><br />';
+                $forecast = '<table width="100%" border="0" cellpadding="0" cellspacing="0">';
+                $forecast .= '<tr><td class="control" colspan="2"><center><b>' . _("Forecast (TAF)") . '</b></td></tr></table>';
+                $forecast .= '<b>Valid: </b>' . $taf['validFrom'] . ' - ' . $taf['validTo'] . '<br /><br />';
                 $item = 0;
                 foreach ($taf['time'] as $time => $entry) {
                     $item++;
-                    $forecast .= '<table width="100%" cellspacing="0">';
+                    $forecast .= '<table width="100%" border="0" cellpadding="0" cellspacing="0">';
                     $forecast .= '<tr class="item' . ($item % 2) . '">';
-                    $forecast .= '<td align="center" width="50">' . $time . '</td><td><strong>Wind:</strong> ';
+                    $forecast .= '<td align="center" width="50">' . $time . '</td><td><b>Wind:</b> ';
                     if (isset($entry['wind'])) {
                         if ($entry['windDirection'] == 'Variable') {
                             if (!empty($this->_params['knots'])) {
-                                $forecast .= sprintf(_("%s at %s %s"),
+                                $forecast .= sprintf(_('%s at %s %s'),
                                     strtolower($entry['windDirection']),
                                     round($metar->convertSpeed($entry['wind'],
                                         $units['wind'], 'kt')),
                                     'kt');
                             } else {
-                                $forecast .= sprintf(_("%s at %s %s"),
+                                $forecast .= sprintf(_('%s at %s %s'),
                                     $entry['windDirection'],
                                     round($entry['wind']),
                                     $units['wind']);
@@ -382,19 +368,19 @@ class Horde_Block_Horde_metar extends Horde_Block {
                         $forecast .= '<br />';
                     }
                     if (isset($entry['temperatureLow']) || isset($entry['temperatureHigh'])) {
-                        $forecast .= '<strong>Temperature</strong>';
+                        $forecast .= '<b>Temperature</b>';
                         if (isset($entry['temperatureLow'])) {
-                            $forecast .= '<strong> Low:</strong>';
+                            $forecast .= '<b> Low:</b>';
                             $forecast .= $entry['temperatureLow'];
                         }
                         if (isset($entry['temperatureHigh'])) {
-                            $forecast .= '<strong> High:</strong>';
+                            $forecast .= '<b> High:</b>';
                             $forecast .= $entry['temperatureHigh'];
                         }
                         $forecast .= '<br />';
                     }
                     if (isset($entry['windshear'])) {
-                        $forecast .= '<strong>Windshear:</strong>';
+                        $forecast .= '<b>Windshear:</b>';
                         $forecast .= sprintf(_("from the %s (%s) at %s %s"),
                                         $entry['windshearDirection'],
                                         $entry['windshearDegrees'],
@@ -403,16 +389,16 @@ class Horde_Block_Horde_metar extends Horde_Block {
                         $forecast .= '<br />';
                     }
                     if (isset($entry['visibility'])) {
-                        $forecast .= '<strong>Visibility:</strong> ';
+                        $forecast .= '<b>Visibility:</b> ';
                         $forecast .= strtolower($entry['visQualifier']) . ' ' . $entry['visibility'] . ' ' . $units['vis'];
                         $forecast .= '<br />';
                     }
                     if (isset($entry['condition'])) {
-                        $forecast .= '<strong>Conditions:</strong> ';
+                        $forecast .= '<b>Conditions:</b> ';
                         $forecast .= $entry['condition'];
                         $forecast .= '<br />';
                     }
-                    $forecast .= '<strong>Clouds:</strong> ';
+                    $forecast .= '<b>Clouds:</b> ';
                     foreach ($entry['clouds'] as $clouds) {
                         if (isset($clouds['type'])) {
                             $forecast .= ' ' . $clouds['type'];
@@ -432,15 +418,15 @@ class Horde_Block_Horde_metar extends Horde_Block {
                             $forecast .= '<td align="center" width="50">';
                             $forecast .= '* ' . $fmcEntry['from'] . '<br /> - ' . $fmcEntry['to'] . '</td>';
                             $forecast .= '<td>';
-                            $forecast .= '<strong>Type: </strong>' . $fmcEntry['type'];
+                            $forecast .= '<b>Type: </b>' . $fmcEntry['type'];
                             if (isset($fmcEntry['probability'])) {
-                                $forecast .= ' <strong> Prob: </strong>' . $fmcEntry['probability'] . '%';
+                                $forecast .= ' <b> Prob: </b>' . $fmcEntry['probability'] . '%';
                             }
                             if (isset($fmcEntry['condition'])) {
-                                $forecast .= ' <strong> Conditions: </strong>' . $fmcEntry['condition'];
+                                $forecast .= ' <b> Conditions: </b>' . $fmcEntry['condition'];
                             }
                             if (isset($fmcEntry['clouds'])) {
-                                $forecast .= ' <strong>Clouds:</strong>';
+                                $forecast .= ' <b>Clouds:</b>';
                                 foreach ($fmcEntry['clouds'] as $fmcClouds) {
                                     if (isset($fmcClouds['type'])) {
                                         $forecast .= ' ' . $fmcClouds['type'];
@@ -455,7 +441,7 @@ class Horde_Block_Horde_metar extends Horde_Block {
                                 }
                             }
                             if (isset($fmcEntry['visQualifier'])) {
-                                $forecast .= ' <strong>Visibility:</strong> ';
+                                $forecast .= ' <b>Visibility:</b> ';
                                 $forecast .= strtolower($fmcEntry['visQualifier']) . ' ';
                                 $forecast .= $fmcEntry['visibility'] . ' ' . $units['vis'];
                             }
