@@ -60,7 +60,7 @@ define('AUTH_REASON_SESSIONIP', 'sessionip');
  * The Auth:: class provides a common abstracted interface into the various
  * backends for the Horde authentication system.
  *
- * $Horde: framework/Auth/Auth.php,v 1.142.10.12 2005/09/12 16:42:56 selsky Exp $
+ * $Horde: framework/Auth/Auth.php,v 1.142.10.4 2005/03/04 23:51:11 jan Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -68,6 +68,7 @@ define('AUTH_REASON_SESSIONIP', 'sessionip');
  * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
+ * @version $Revision: 1.142.10.4 $
  * @since   Horde 1.3
  * @package Horde_Auth
  */
@@ -77,7 +78,7 @@ class Auth {
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array
+     * @var array $capabilities
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -90,7 +91,7 @@ class Auth {
    /**
     * Hash containing parameters.
     *
-    * @var array
+    * @var array $_params
     */
     var $_params = array();
 
@@ -99,7 +100,7 @@ class Auth {
      *
      * @access protected
      *
-     * @var array
+     * @var array $_authCredentials
      */
     var $_authCredentials = array();
 
@@ -117,6 +118,8 @@ class Auth {
      * Finds out if a set of login credentials are valid, and if requested,
      * mark the user as logged in in the current session.
      *
+     * @access public
+     *
      * @param string $userId      The userId to check.
      * @param array $credentials  The credentials to check.
      * @param boolean $login      Whether to log the user in. If false, we'll
@@ -185,6 +188,8 @@ class Auth {
     /**
      * Formats a password using the current encryption.
      *
+     * @access public
+     *
      * @param string $plaintext      The plaintext password to encrypt.
      * @param string $salt           The salt to use to encrypt the password.
      *                               If not present, a new salt will be
@@ -281,10 +286,12 @@ class Auth {
     }
 
     /**
-     * Returns a salt for the appropriate kind of password encryption.
-     * Optionally takes a seed and a plaintext password, to extract the seed of
-     * an existing password, or for encryption types that use the plaintext in
-     * the generation of the salt.
+     * Returns a salt for the appropriate kind of password
+     * encryption. Optionally takes a seed and a plaintext password, to
+     * extract the seed of an existing password, or for encryption types that
+     * use the plaintext in the generation of the salt.
+     *
+     * @access public
      *
      * @param string $encryption  The kind of pasword encryption to use.
      *                            Defaults to md5-hex.
@@ -339,6 +346,7 @@ class Auth {
         case 'aprmd5':
             /**
              * 64 characters that are valid for APRMD5 passwords.
+             * @var string $_APRMD5
              */
             $APRMD5 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
 
@@ -363,9 +371,9 @@ class Auth {
      */
     function genRandomPassword()
     {
-        $vowels    = 'aeiouy';
-        $constants = 'bcdfghjklmnpqrstvwxz';
-        $numbers   = '0123456789';
+        $vowels     ='aeiouy';
+        $constants  ='bcdfghjklmnpqrstvwxz';
+        $numbers    ='0123456789';
 
         /* Alternate constant and vowel random chars with two random numbers
          * at the end. This should produce a fairly pronounceable password. */
@@ -383,6 +391,7 @@ class Auth {
     /**
      * Adds a set of authentication credentials.
      *
+     * @access public
      * @abstract
      *
      * @param string $userId      The userId to add.
@@ -398,6 +407,7 @@ class Auth {
     /**
      * Updates a set of authentication credentials.
      *
+     * @access public
      * @abstract
      *
      * @param string $oldID        The old userId.
@@ -414,6 +424,7 @@ class Auth {
     /**
      * Deletes a set of authentication credentials.
      *
+     * @access public
      * @abstract
      *
      * @param string $userId  The userId to delete.
@@ -450,6 +461,7 @@ class Auth {
     /**
      * Lists all users in the system.
      *
+     * @access public
      * @abstract
      *
      * @return mixed  The array of userIds, or a PEAR_Error object on failure.
@@ -462,6 +474,7 @@ class Auth {
     /**
      * Checks if $userId exists in the system.
      *
+     * @access public
      * @abstract
      *
      * @return boolean  Whether or not $userId already exists.
@@ -475,6 +488,7 @@ class Auth {
      * Automatic authentication: Finds out if the client matches an allowed IP
      * block.
      *
+     * @access public
      * @abstract
      *
      * @return boolean  Whether or not the client is allowed.
@@ -489,6 +503,8 @@ class Auth {
      * specified user. If there isn't, but the configured Auth driver supports
      * transparent authentication, then we try that.
      *
+     * @access public
+     *
      * @param string $realm  The authentication realm to check.
      *
      * @return boolean  Whether or not the user is authenticated.
@@ -524,6 +540,8 @@ class Auth {
     /**
      * Returns the currently logged in user, if there is one.
      *
+     * @access public
+     *
      * @return mixed  The userId of the current user, or false if no user is
      *                logged in.
      */
@@ -543,6 +561,8 @@ class Auth {
      * Returns the curently logged-in user without any domain information
      * (e.g., bob@example.com would be returned as 'bob').
      *
+     * @access public
+     *
      * @return mixed  The user ID of the current user, or false if no user
      *                is logged in.
      */
@@ -559,30 +579,12 @@ class Auth {
         return $user;
     }
 
-    /**
-     * Returns the domain of currently logged-in user (e.g.,
-     * bob@example.com would be returned as 'example.com').
-     *
-     * @since Horde 3.0.6
-     *
-     * @return mixed  The domain suffix of the current user, or false.
-     */
-    function getAuthDomain()
-    {
-        if ($user = Auth::getAuth()) {
-            $pos = strpos($user, '@');
-            if ($pos !== false) {
-                return substr($user, $pos + 1);
-            }
-        }
-
-        return false;
-    }
-
     /**
      * Returns the requested credential for the currently logged in user, if
      * present.
      *
+     * @access public
+     *
      * @param string $credential  The credential to retrieve.
      *
      * @return mixed  The requested credential, or false if no user is
@@ -609,6 +611,8 @@ class Auth {
     /**
      * Sets the requested credential for the currently logged in user.
      *
+     * @access public
+     *
      * @param string $credential  The credential to set.
      * @param string $value       The value to set the credential to.
      */
@@ -634,6 +638,8 @@ class Auth {
      * If a user name hook was defined in the configuration, it gets applied
      * to the userId at this point.
      *
+     * @access public
+     *
      * @param string $userId      The userId who has been authorized.
      * @param array $credentials  The credentials of the user.
      * @param string $realm       The authentication realm to use.
@@ -671,7 +677,6 @@ class Auth {
 
         /* Reload preferences for the new user. */
         $GLOBALS['registry']->loadPrefs();
-        NLS::setLang($GLOBALS['prefs']->getValue('language'));
 
         /* Fetch the user's last login time. */
         $old_login = @unserialize($GLOBALS['prefs']->getValue('last_login'));
@@ -699,6 +704,8 @@ class Auth {
     /**
      * Clears any authentication tokens in the current session.
      *
+     * @access public
+     *
      * @param string $realm  The authentication realm to clear.
      */
     function clearAuth($realm = null)
@@ -720,6 +727,8 @@ class Auth {
     /**
      * Is the current user an administrator?
      *
+     * @access public
+     *
      * @param string $permission  Allow users with this permission admin access
      *                            in the current context.
      * @param integer $permlevel  The level of permissions to check for
@@ -809,6 +818,8 @@ class Auth {
      * Queries the current Auth object to find out if it supports the given
      * capability.
      *
+     * @access public
+     *
      * @param string $capability  The capability to test for.
      *
      * @return boolean  Whether or not the capability is supported.
@@ -822,6 +833,8 @@ class Auth {
      * Returns the URI of the login screen for the current authentication
      * method.
      *
+     * @access public
+     *
      * @param string $app  The application to use.
      * @param string $url  The URL to redirect to after login.
      *
@@ -837,6 +850,8 @@ class Auth {
     /**
      * Returns the named parameter for the current auth driver.
      *
+     * @access public
+     *
      * @param string $param  The parameter to fetch.
      *
      * @return string  The parameter's value.
@@ -849,6 +864,8 @@ class Auth {
     /**
      * Returns the name of the authentication provider.
      *
+     * @access public
+     *
      * @param string $driver  Used by recursive calls when untangling composite
      *                        auth.
      * @param array  $params  Used by recursive calls when untangling composite
@@ -886,6 +903,8 @@ class Auth {
     /**
      * Returns the logout reason.
      *
+     * @access public
+     *
      * @return string One of the logout reasons (see the AUTH_LOGOUT_*
      *                constants for the valid reasons).  Returns null if there
      *                is no logout reason present.
@@ -902,6 +921,8 @@ class Auth {
     /**
      * Returns the status string to use for logout messages.
      *
+     * @access public
+     *
      * @return string  The logout reason string.
      */
     function getLogoutReasonString()
@@ -953,6 +974,8 @@ class Auth {
      * If no reason/msg is passed in, use the current global authentication
      * error message.
      *
+     * @access public
+     *
      * @param string $url     The URL to redirect to.
      * @param string $reason  The reason for logout.
      * @param string $msg     If reason is AUTH_REASON_MESSAGE, the message to
@@ -1088,6 +1111,7 @@ class Auth {
     {
         /**
          * 64 characters that are valid for APRMD5 passwords.
+         * @var string $_APRMD5
          */
         $APRMD5 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
 
@@ -1114,8 +1138,7 @@ class Auth {
         $bin = '';
         $length = strlen($hex);
         for ($i = 0; $i < $length; $i += 2) {
-            $tmp = sscanf(substr($hex, $i, 2), '%x');
-            $bin .= chr(array_shift($tmp));
+            $bin .= chr(array_shift(sscanf(substr($hex, $i, 2), '%x')));
         }
         return $bin;
     }
@@ -1123,6 +1146,8 @@ class Auth {
     /**
      * Attempts to return a concrete Auth instance based on $driver.
      *
+     * @access public
+     *
      * @param mixed $driver  The type of concrete Auth subclass to return. This
      *                       is based on the storage driver ($driver). The code
      *                       is dynamically included. If $driver is an array,
@@ -1181,6 +1206,8 @@ class Auth {
      *
      * This method must be invoked as: $var = &Auth::singleton()
      *
+     * @access public
+     *
      * @param string $driver  The type of concrete Auth subclass to return.
      *                        This is based on the storage driver ($driver).
      *                        The code is dynamically included.
