@@ -122,15 +122,15 @@ require_once 'Horde/Auth/sql.php';
  * );
  *
  *
- * $Horde: framework/Auth/Auth/cyrsql.php,v 1.33 2004/06/22 14:01:37 chuck Exp $
+ * $Horde: framework/Auth/Auth/cyrsql.php,v 1.33.10.2 2005/01/19 15:05:03 jan Exp $
  *
- * Copyright 2002-2004 Ilya <mail@krel.org>
+ * Copyright 2002-2005 Ilya <mail@krel.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Ilya <mail@krel.org>
- * @version $Revision: 1.33 $
+ * @version $Revision: 1.33.10.2 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -160,7 +160,7 @@ class Auth_cyrsql extends Auth_sql {
     function Auth_cyrsql($params = array())
     {
         if (!Util::extensionExists('imap')) {
-            Horde::fatal(PEAR::raiseError(_("Auth_cyrsql: Required imap extension not found."), __FILE__, __LINE__));
+            Horde::fatal(_("Auth_cyrsql: Required imap extension not found."), __FILE__, __LINE__);
         }
         parent::Auth_sql($params);
     }
@@ -309,7 +309,7 @@ class Auth_cyrsql extends Auth_sql {
 
             $this->_imapStream = @imap_open($this->_params['imap_dsn'], $this->_params['cyradmin'], $this->_params['cyrpass'], OP_HALFOPEN);
             if (!$this->_imapStream) {
-                Horde::fatal(PEAR::raiseError(sprintf(_("Can't connect to IMAP server: %s"), imap_last_error())), __FILE__, __LINE__);
+                Horde::fatal(sprintf(_("Can't connect to IMAP server: %s"), imap_last_error()), __FILE__, __LINE__);
             }
 
             if (!empty($this->_params['unixhier'])) {
