@@ -49,7 +49,7 @@
  *       }
  *   }
  *
- * $Horde: framework/Auth/Auth/cyrus.php,v 1.15.10.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/cyrus.php,v 1.15.10.2 2005/01/19 15:05:03 jan Exp $
  *
  * Copyright 2002-2005 Ilya <mail@krel.org>
  * Copyright 2003-2005 Mike Cochrane <mike@graftonhall.co.nz>
@@ -59,7 +59,7 @@
  *
  * @author  Ilya <mail@krel.org>
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 1.15.10.1 $
+ * @version $Revision: 1.15.10.2 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -121,7 +121,7 @@ class Auth_cyrus extends Auth {
         }
 
         if (!Util::extensionExists('imap')) {
-            Horde::fatal(PEAR::raiseError(_("Auth_cyrus: Required imap extension not found."), __FILE__, __LINE__));
+            Horde::fatal(_("Auth_cyrus: Required imap extension not found."), __FILE__, __LINE__);
         }
 
         // Create backend instance.
@@ -134,7 +134,7 @@ class Auth_cyrus extends Auth {
         if (!$this->_backend->hasCapability('add') ||
             !$this->_backend->hasCapability('update') ||
             !$this->_backend->hasCapability('remove')) {
-            Horde::fatal(PEAR::raiseError(_("Auth_cyrus: Backend does not have required capabilites."), __FILE__, __LINE__));
+            Horde::fatal(_("Auth_cyrus: Backend does not have required capabilites."), __FILE__, __LINE__);
         }
 
         $this->capabilities['list'] = $this->_backend->hasCapability('list');
@@ -238,8 +238,8 @@ class Auth_cyrus extends Auth {
                                             $this->_params['cyrpass'], OP_HALFOPEN);
 
             if (!$this->_imapStream) {
-                Horde::fatal(PEAR::raiseError(sprintf(_("Can't connect to IMAP server: %s"),
-                                                      imap_last_error())), __FILE__, __LINE__);
+                Horde::fatal(sprintf(_("Can't connect to IMAP server: %s"),
+                                     imap_last_error()), __FILE__, __LINE__);
             }
 
             $this->_connected = true;
