@@ -11,7 +11,7 @@
  *                   DEFAULT: 21
  *
  *
- * $Horde: framework/Auth/Auth/ftp.php,v 1.23.12.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/ftp.php,v 1.23.12.2 2005/01/19 15:05:04 jan Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Max Kalika <max@horde.org>
@@ -21,7 +21,7 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Max Kalika <max@horde.org>
- * @version $Revision: 1.23.12.1 $
+ * @version $Revision: 1.23.12.2 $
  * @since   Horde 1.3
  * @package Horde_Auth
  */
@@ -37,7 +37,7 @@ class Auth_ftp extends Auth {
     function Auth_ftp($params = array())
     {
         if (!Util::extensionExists('ftp')) {
-            Horde::fatal(PEAR::raiseError(_("Auth_ftp: Required FTP extension not found. Compile PHP with the --enable-ftp switch.")), __FILE__, __LINE__);
+            Horde::fatal(_("Auth_ftp: Required FTP extension not found. Compile PHP with the --enable-ftp switch."), __FILE__, __LINE__);
         }
 
         $default_params = array(
