@@ -3,45 +3,53 @@
  * The Auth_imap:: class provides an IMAP implementation of the Horde
  * authentication system.
  *
- * Optional parameters:<pre>
- *  'hostspec'        The hostname or IP address of the server.
- *                    DEFAULT: 'localhost'
- *  'port'            The server port to which we will connect.
- *                    IMAP is generally 143, while IMAP-SSL is generally 993.
- *                    DEFAULT: 143
- *  'protocol'        The connection protocol (e.g. 'imap', 'pop3', 'nntp').
- *                    Protocol is one of 'imap/notls' (or only 'imap' if you
- *                    have a c-client version 2000c or older), 'imap/ssl',
- *                    or 'imap/ssl/novalidate-cert' (for a self-signed
- *                    certificate).
- *                    DEFAULT: 'imap'
- *  'admin_user'      The name of a user with admin privileges.
- *                    DEFAULT: null
- *  'admin_password'  The password of the adminstrator.
- *                    DEFAULT: null
- *  'userhierarchy'   The hierarchy where user mailboxes are stored.
- *                    DEFAULT: 'user.'
- *  'dsn'             The full IMAP connection string.
- *                    If not present, this is built from 'hostspec', 'port'
- *                    and 'protocol' parameters.</pre>
+ * Optional parameters:
+ * ====================
+ *  'folder'         --  The initial folder / mailbox to open.
+ *                       Should be null for 'imap' and 'nntp' protocols.
+ *                       DEFAULT: null
+ *  'hostspec'       --  The hostname or IP address of the server.
+ *                       DEFAULT: 'localhost'
+ *  'port'           --  The server port to which we will connect.
+ *                       IMAP is generally 143, while IMAP-SSL is generally 993.
+ *                       DEFAULT: 143
+ *  'protocol'       --  The connection protocol (e.g. 'imap', 'pop3', 'nntp').
+ *                       Protocol is one of 'imap/notls' (or only 'imap' if you
+ *                       have a c-client version 2000c or older), 'imap/ssl',
+ *                       or 'imap/ssl/novalidate-cert' (for a self-signed
+ *                       certificate).
+ *                       DEFAULT: 'imap'
+ *  'admin_user'     --  The name of a user with admin privileges.
+ *                       DEFAULT: null
+ *  'admin_password' --  The password of the adminstrator.
+ *                       DEFAULT: null
+ *  'userhierarchy'  --  The hierarchy where user mailboxes are stored.
+ *                       DEFAULT: 'user.'
+ *  'dsn'            --  The full IMAP connection string.
+ *                       If not present, this is built from 'hostspec', 'port'
+ *                       and 'protocol' parameters.
  *
  *
- * If setting up as Horde auth handler in conf.php, this is a sample entry:<pre>
+ * If setting up as Horde auth handler in conf.php, this is a sample entry:
+ *   $conf['auth']['params']['folder'] = 'INBOX';
  *   $conf['auth']['params']['hostspec'] = 'imap.example.com';
  *   $conf['auth']['params']['port'] = 143;
- *   $conf['auth']['params']['protocol'] = 'imap/notls/novalidate-cert';</pre>
+ *   $conf['auth']['params']['protocol'] = 'imap/notls/novalidate-cert';
  *
+ * 
+ * $Horde: framework/Auth/Auth/imap.php,v 1.28.10.2 2005/01/19 15:05:04 jan Exp $
  *
- * $Horde: framework/Auth/Auth/imap.php,v 1.28.10.14 2008/09/12 16:52:51 wrobel Exp $
- *
- * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Gaudenz Steinlin <gaudenz.steinlin@id.unibe.ch>
+ * Copyright 2004-2005 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://opensource.org/licenses/lgpl-license.php.
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @author  Gaudenz Steinlin <gaudenz@soziologie.ch>
+ * @author  Gaudenz Steinlin <gaudenz.steinlin@id.unibe.ch>
  * @author  Jan Schneider <jan@horde.org>
+ * @version $Revision: 1.28.10.2 $
  * @since   Horde 1.3
  * @package Horde_Auth
  */
@@ -50,30 +58,24 @@ class Auth_imap extends Auth {
     /**
      * Constructs a new IMAP authentication object.
      *
-     * @param array $params  A hash containing connection parameters.
+     * @access public
+     *
+     * @param optional array $params  A hash containing connection parameters.
      */
     function Auth_imap($params = array())
     {
+        if (!Util::extensionExists('imap')) {
+            Horde::fatal(_("Auth_imap: Required IMAP extension not found."), __FILE__, __LINE__);
+        }
+
         $default_params = array(
+            'folder' => null,
             'hostspec' => 'localhost',
             'port' => '143',
             'protocol' => 'imap',
             'userhierarchy' => 'user.'
         );
-        $this->_setParams(array_merge($default_params, $params));
-    }
-
-
-    /**
-     * Update the connection parameters.
-     *
-     * @access private
-     *
-     * @param array $params  A hash containing connection parameters.
-     */
-    function _setParams($params)
-    {
-        $this->_params = array_merge($this->_params, $params);
+        $this->_params = array_merge($default_params, $params);
 
         if (!empty($this->_params['admin_user'])) {
             $this->capabilities['add'] = true;
@@ -81,16 +83,15 @@ class Auth_imap extends Auth {
             $this->capabilities['list'] = true;
         }
 
-        /**
-         * If the given params updated the connection parameters and
-         * contained no DSN we need to update the DSN string.
-         */
-        if ((isset($params['hostspec']) || isset($params['port'])
-             || isset($params['protocol'])) && !isset($params['dsn'])) {
-            $this->_params['dsn'] = sprintf('{%s:%d/%s}',
+        /* Create DSN string. */
+        if (!isset($this->_params['dsn'])) {
+            $this->_params['dsn'] = sprintf('{%s:%d/%s}', 
                                             $this->_params['hostspec'],
                                             $this->_params['port'],
                                             $this->_params['protocol']);
+            if (!empty($this->_params['folder'])) {
+                $this->_params['dsn'] .= $this->_params['folder'];
+            }
         }
     }
 
@@ -107,9 +108,8 @@ class Auth_imap extends Auth {
      */
     function _authenticate($userId, $credentials)
     {
-        if (!Util::extensionExists('imap')) {
-            $this->_setAuthError(AUTH_REASON_FAILED, _("Auth_imap: Required IMAP extension not found."));
-            return false;
+        if (empty($credentials['password'])) {
+            Horde::fatal(_("No password provided for IMAP authentication."), __FILE__, __LINE__);
         }
 
         $imap = @imap_open($this->_params['dsn'], $userId,
@@ -135,7 +135,7 @@ class Auth_imap extends Auth {
     function addUser($userId, $credentials)
     {
         require_once 'Horde/IMAP/Admin.php';
-        $imap = new IMAP_Admin($this->_params);
+        $imap = &new IMAP_Admin($this->_params);
         return $imap->addMailbox(String::convertCharset($userId, NLS::getCharset(), 'utf7-imap'));
     }
 
@@ -149,7 +149,7 @@ class Auth_imap extends Auth {
     function removeUser($userId)
     {
         require_once 'Horde/IMAP/Admin.php';
-        $imap = new IMAP_Admin($this->_params);
+        $imap = &new IMAP_Admin($this->_params);
         $result = $imap->removeMailbox(String::convertCharset($userId, NLS::getCharset(), 'utf7-imap'));
         if (is_a($result, 'PEAR_Error')) {
             return $result;
@@ -165,7 +165,7 @@ class Auth_imap extends Auth {
     function listUsers()
     {
         require_once 'Horde/IMAP/Admin.php';
-        $imap = new IMAP_Admin($this->_params);
+        $imap = &new IMAP_Admin($this->_params);
         return $imap->listMailboxes();
     }
 
