@@ -4,9 +4,9 @@
  * This will be most benificial if already using an IMSP based preference
  * system or IMSP based addressbook system
  *
- * $Horde: framework/Auth/Auth/imsp.php,v 1.2.10.11 2007/01/02 13:54:07 jan Exp $
+ * $Horde: framework/Auth/Auth/imsp.php,v 1.2.10.4 2005/02/27 17:54:48 mrubinsk Exp $
  *
- * Copyright 2004-2007 Michael Rubinsky <mrubinsk@horde.org>
+ * Copyright 2004-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -20,7 +20,7 @@ class Auth_imsp extends Auth{
      * An array of capabilities, so that the driver can report which
      * operations it supports and which it doesn't.
      *
-     * @var array
+     * @var array $capabilities
      */
     var $capabilities = array('add'           => false,
                               'update'        => false,
@@ -31,7 +31,8 @@ class Auth_imsp extends Auth{
     /**
      * Constructor function. Creates new Auth_imsp object.
      *
-     * @param array $params A hash containing parameters.
+     * @access public
+     * @param optional array $params A hash containing parameters.
      */
     function Auth_imsp($params = array())
     {
@@ -42,25 +43,25 @@ class Auth_imsp extends Auth{
      * Private authentication function.
      *
      * @access private
-     *
      * @param string $userID Username for IMSP server.
      * @param array $credentials Hash containing 'password' element.
-     *
      * @return boolean True on success / False on failure.
      */
     function _authenticate($userID, $credentials)
     {
         require_once 'Net/IMSP/Auth.php';
 
-        $this->_params['username'] = $userID;
-        $this->_params['password'] = $credentials['password'];
+        $params = array();
+        $params['username'] = $userID;
+        $params['password'] = $credentials['password'];
+        $params['server'] = $this->_params['server'];
+        $params['port'] = $this->_params['port'];
         $imsp = &Net_IMSP_Auth::singleton($this->_params['auth_method']);
-
-        if (is_a($imsp, 'PEAR_Error')) {
+        if (is_a($imsp, 'PEAR_Error')){
             return $imsp;
         }
 
-        $result = $imsp->authenticate($this->_params, false);
+        $result = $imsp->authenticate($params, false);
         if (is_a($result, 'PEAR_Error')) {
             $this->_setAuthError(AUTH_REASON_BADLOGIN);
             return false;
@@ -77,15 +78,10 @@ class Auth_imsp extends Auth{
      */
     function _setParams($params)
     {
-        $this->_params['server'] = $params['server'];
-        $this->_params['port'] = $params['port'];
-        $this->_params['auth_method'] = $params['auth_method'];
-
-        if (isset($params['auth_mechanism'])) {
-            $this->_params['auth_mechanism'] = $params['auth_mechanism'];
-            $this->_params['socket'] = $params['socket'];
-            $this->_params['command'] = $params['command'];
+        if (empty($params['auth_method'])) {
+            $params['auth_method'] = 'plaintext';
         }
+        $this->_params = $params;
     }
 
 }
