@@ -1,11 +1,11 @@
 <?php
 /**
- * The Auth_sasl:: class provides a SASL-based implementation of the
- * Horde authentication system.
+ * The Auth_sasl:: class provides a SASL-based implementation of the Horde
+ * authentication system.
  *
- * SASL is the Simple Authentication and Security Layer (as defined by
- * RFC 2222). It provides a system for adding plugable authenticating
- * support to connection-based protocols.
+ * SASL is the Simple Authentication and Security Layer (as defined by RFC
+ * 2222). It provides a system for adding plugable authenticating support to
+ * connection-based protocols.
  *
  * This driver relies on the PECL sasl package:
  *
@@ -20,7 +20,7 @@
  *                  DEFAULT: php
  *
  *
- * $Horde: framework/Auth/Auth/sasl.php,v 1.4.10.1 2005/01/03 12:18:53 jan Exp $
+ * $Horde: framework/Auth/Auth/sasl.php,v 1.4.10.2 2005/01/19 15:05:04 jan Exp $
  *
  * Copyright 2004-2005 Jon Parise <jon@horde.org>
  *
@@ -28,7 +28,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Parise <jon@horde.org>
- * @version $Revision: 1.4.10.1 $
+ * @version $Revision: 1.4.10.2 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -79,17 +79,17 @@ class Auth_sasl extends Auth
     function _authenticate($userId, $credentials)
     {
         if (empty($credentials['password'])) {
-            Horde::fatal(PEAR::raiseError(_("No password provided for Login authentication.")), __FILE__, __LINE__);
+            Horde::fatal(_("No password provided for Login authentication."), __FILE__, __LINE__);
         }
 
         if (!extension_loaded('sasl')) {
-            Horde::fatal(PEAR::raiseError(_("SASL authentication is not available.")), __FILE__, __LINE__);
+            Horde::fatal(_("SASL authentication is not available."), __FILE__, __LINE__);
         }
 
         $service = (!empty($params['service'])) ? $params['service'] : 'php';
         $conn = sasl_server_new($service);
         if (!is_resource($conn)) {
-            Horde::fatal(PEAR::raiseError(_("Failed to create new SASL connection.")), __FILE__, __LINE__);
+            Horde::fatal(_("Failed to create new SASL connection."), __FILE__, __LINE__);
         }
 
         if (!sasl_checkpass($conn, $userId, $credentials['password'])) {
