@@ -1,19 +1,16 @@
 <?php
 
-/** Horde_String */
 require_once 'Horde/String.php';
 
 /**
  * The Browser:: class provides capability information for the current
- * web client.
+ * web client. Browser identification is performed by examining the
+ * HTTP_USER_AGENT environmental variable provide by the web server.
  *
- * Browser identification is performed by examining the HTTP_USER_AGENT
- * environment variable provided by the web server.
+ * $Horde: framework/Browser/Browser.php,v 1.153.2.12 2005/03/02 16:16:46 jan Exp $
  *
- * $Horde: framework/Browser/Browser.php,v 1.153.2.53 2007/09/27 00:16:27 jan Exp $
- *
- * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 1999-2007 Jon Parise <jon@horde.org>
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -28,56 +25,56 @@ class Browser {
     /**
      * Major version number.
      *
-     * @var integer
+     * @var integer $_majorVersion
      */
     var $_majorVersion = 0;
 
     /**
      * Minor version number.
      *
-     * @var integer
+     * @var integer $_minorVersion
      */
     var $_minorVersion = 0;
 
     /**
      * Browser name.
      *
-     * @var string
+     * @var string $_browser
      */
     var $_browser = '';
 
     /**
      * Full user agent string.
      *
-     * @var string
+     * @var string $_agent
      */
     var $_agent = '';
 
     /**
      * Lower-case user agent string.
      *
-     * @var string
+     * @var string $_agent
      */
     var $_lowerAgent = '';
 
     /**
      * HTTP_ACCEPT string
      *
-     * @var string
+     * @var string $_accept
      */
     var $_accept = '';
 
     /**
      * Platform the browser is running on.
      *
-     * @var string
+     * @var string $_platform
      */
     var $_platform = '';
 
     /**
      * Known robots.
      *
-     * @var array
+     * @var array $_robots
      */
     var $_robots = array(
         /* The most common ones. */
@@ -86,72 +83,51 @@ class Browser {
         'Slurp',
         'Yahoo',
         /* The rest alphabetically. */
-        'appie',
         'Arachnoidea',
         'ArchitextSpider',
         'Ask Jeeves',
         'B-l-i-t-z-Bot',
-        'Baiduspider',
-        'BecomeBot',
-        'cfetch',
         'ConveraCrawler',
         'ExtractorPro',
         'FAST-WebCrawler',
         'FDSE robot',
         'fido',
-        'findlinks',
-        'Francis',
         'geckobot',
         'Gigabot',
         'Girafabot',
         'grub-client',
         'Gulliver',
-        'HTTrack',
         'ia_archiver',
-        'iCCrawler',
         'InfoSeek',
-        'kinjabot',
         'KIT-Fireball',
-        'larbin',
         'LEIA',
-        'lmspider',
-        'lwp-trivial',
         'Lycos_Spider',
         'Mediapartners-Google',
         'MuscatFerret',
         'NaverBot',
-        'OmniExplorer_Bot',
         'polybot',
         'Pompos',
-        'RufusBot',
         'Scooter',
-        'Seekbot',
-        'sogou spider',
-        'sproose',
         'Teoma',
-        'TheSuBot',
         'TurnitinBot',
         'Ultraseek',
         'ViolaBot',
-        'voyager',
-        'W3C-checklink',
         'webbandit',
         'www.almaden.ibm.com/cs/crawler',
-        'yacy',
         'ZyBorg',
     );
 
     /**
      * Is this a mobile browser?
      *
-     * @var boolean
+     * @var boolean $_mobile
      */
     var $_mobile = false;
 
     /**
      * Features.
      *
-     * @var array
+     * @var array $_features
      */
     var $_features = array(
         'html'       => true,
@@ -176,7 +152,7 @@ class Browser {
     /**
      * Quirks
      *
-     * @var array
+     * @var array $_quirks
      */
     var $_quirks = array(
         'avoid_popup_windows'        => false,
@@ -195,14 +171,13 @@ class Browser {
         'png_transparency'           => false,
         'scrollbar_in_way'           => false,
         'scroll_tds'                 => false,
-        'windowed_controls'          => false,
     );
 
     /**
      * List of viewable image MIME subtypes.
      * This list of viewable images works for IE and Netscape/Mozilla.
      *
-     * @var array
+     * @var array $_images
      */
     var $_images = array('jpeg', 'gif', 'png', 'pjpeg', 'x-png', 'bmp');
 
@@ -212,13 +187,15 @@ class Browser {
      * Returns a reference to the global Browser object, only creating it
      * if it doesn't already exist.
      *
-     * This method must be invoked as:<pre>
-     *   $browser = &Browser::singleton([$userAgent[, $accept]]);</pre>
+     * This method must be invoked as:
+     *   $browser = &Browser::singleton([$userAgent[, $accept]]);
      *
-     * @param string $userAgent  The browser string to parse.
-     * @param string $accept     The HTTP_ACCEPT settings to use.
+     * @access public
      *
-     * @return Browser  The Browser object.
+     * @param optional string $userAgent  The browser string to parse.
+     * @param optional string $accept     The HTTP_ACCEPT settings to use.
+     *
+     * @return object Browser  The Browser object.
      */
     function &singleton($userAgent = null, $accept = null)
     {
@@ -239,8 +216,10 @@ class Browser {
     /**
      * Create a browser instance (Constructor).
      *
-     * @param string $userAgent  The browser string to parse.
-     * @param string $accept     The HTTP_ACCEPT settings to use.
+     * @access public
+     *
+     * @param optional string $userAgent  The browser string to parse.
+     * @param optional string $accept     The HTTP_ACCEPT settings to use.
      */
     function Browser($userAgent = null, $accept = null)
     {
@@ -251,8 +230,10 @@ class Browser {
      * Parses the user agent string and inititializes the object with
      * all the known features and quirks for the given browser.
      *
-     * @param string $userAgent  The browser string to parse.
-     * @param string $accept     The HTTP_ACCEPT settings to use.
+     * @access public
+     *
+     * @param optional string $userAgent  The browser string to parse.
+     * @param optional string $accept     The HTTP_ACCEPT settings to use.
      */
     function match($userAgent = null, $accept = null)
     {
@@ -283,33 +264,20 @@ class Browser {
         if (!empty($this->_agent)) {
             $this->_setPlatform();
 
-            if (strpos($this->_lowerAgent, 'iemobile') !== false ||
-                strpos($this->_lowerAgent, 'mobileexplorer') !== false ||
-                strpos($this->_lowerAgent, 'openwave') !== false ||
-                strpos($this->_lowerAgent, 'opera mini') !== false ||
-                strpos($this->_lowerAgent, 'operamini') !== false) {
-                $this->setFeature('frames', false);
-                $this->setFeature('javascript', false);
-                $this->setQuirk('avoid_popup_windows');
-                $this->_mobile = true;
-            } elseif (preg_match('|Opera[/ ]([0-9.]+)|', $this->_agent, $version)) {
+            if (preg_match('|Opera[/ ]([0-9.]+)|', $this->_agent, $version)) {
                 $this->setBrowser('opera');
                 list($this->_majorVersion, $this->_minorVersion) = explode('.', $version[1]);
                 $this->setFeature('javascript', true);
                 $this->setQuirk('no_filename_spaces');
 
-                /* Opera Mobile reports its screen resolution in the
-                 * user agent strings. */
-                if (preg_match('/; (120x160|240x280|240x320|320x320)\)/', $this->_agent)) {
-                    $this->_mobile = true;
-                }
-
-                if ($this->_majorVersion >= 7) {
+                switch ($this->_majorVersion) {
+                case 7:
                     $this->setFeature('dom');
                     $this->setFeature('iframes');
                     $this->setFeature('accesskey');
                     $this->setFeature('optgroup');
                     $this->setQuirk('double_linebreak_textarea');
+                    break;
                 }
             } elseif (strpos($this->_lowerAgent, 'elaine/') !== false ||
                       strpos($this->_lowerAgent, 'palmsource') !== false ||
@@ -335,24 +303,23 @@ class Browser {
                     $this->_minorVersion = 0;
                 }
 
-                /* IE (< 7) on Windows does not support alpha transparency in
-                 * PNG images. */
-                if (($this->_majorVersion < 7) &&
-                    preg_match('/windows/i', $this->_agent)) {
+                /* IE on Windows does not support alpha transparency in PNG
+                 * images. */
+                if (preg_match('/windows/i', $this->_agent)) {
                     $this->setQuirk('png_transparency');
                 }
 
-                /* IE 6 (pre-SP1) and 5.5 (pre-SP1) have buggy compression.
+                /* IE 6 (pre-SP1) and 5.5 (pre-SP1) has buggy compression.
                  * The versions affected are as follows:
                  * 6.00.2462.0000  Internet Explorer 6 Public Preview (Beta)
                  * 6.00.2479.0006  Internet Explorer 6 Public Preview (Beta)
                                     Refresh
                  * 6.00.2600.0000  Internet Explorer 6 (Windows XP)
-                 * 5.50.3825.1300  Internet Explorer 5.5 Developer Preview (Beta)
-                 * 5.50.4030.2400  Internet Explorer 5.5 & Internet Tools Beta
-                 * 5.50.4134.0100  Internet Explorer 5.5 for Windows Me (4.90.3000)
-                 * 5.50.4134.0600  Internet Explorer 5.5
-                 * 5.50.4308.2900  Internet Explorer 5.5 Advanced Security Privacy Beta
+                 * 5.50.3825.1300   Internet Explorer 5.5 Developer Preview (Beta)
+                 * 5.50.4030.2400   Internet Explorer 5.5 & Internet Tools Beta
+                 * 5.50.4134.0100   Internet Explorer 5.5 for Windows Me (4.90.3000)
+                 * 5.50.4134.0600   Internet Explorer 5.5
+                 * 5.50.4308.2900   Internet Explorer 5.5 Advanced Security Privacy Beta
                  *
                  * See:
                  * ====
@@ -373,23 +340,11 @@ class Browser {
                 /* Some Handhelds have their screen resolution in the
                  * user agent string, which we can use to look for
                  * mobile agents. */
-                if (preg_match('/; (120x160|240x280|240x320|320x320)\)/', $this->_agent)) {
+                if (preg_match('/; (120x160|240x280|240x320)\)/', $this->_agent)) {
                     $this->_mobile = true;
                 }
 
                 switch ($this->_majorVersion) {
-                case 7:
-                    $this->setFeature('javascript', 1.4);
-                    $this->setFeature('dom');
-                    $this->setFeature('iframes');
-                    $this->setFeature('utf');
-                    $this->setFeature('rte');
-                    $this->setFeature('homepage');
-                    $this->setFeature('accesskey');
-                    $this->setFeature('optgroup');
-                    $this->setFeature('xmlhttpreq');
-                    break;
-
                 case 6:
                     $this->setFeature('javascript', 1.4);
                     $this->setFeature('dom');
@@ -402,7 +357,6 @@ class Browser {
                     $this->setFeature('xmlhttpreq');
                     $this->setQuirk('scrollbar_in_way');
                     $this->setQuirk('broken_multipart_form');
-                    $this->setQuirk('windowed_controls');
                     break;
 
                 case 5:
@@ -416,7 +370,6 @@ class Browser {
                         $this->setFeature('xmlhttpreq');
                         if ($this->_minorVersion >= 5) {
                             $this->setFeature('rte');
-                            $this->setQuirk('windowed_controls');
                         }
                     }
                     $this->setFeature('iframes');
@@ -471,6 +424,7 @@ class Browser {
                     if ($this->_majorVersion > 125 ||
                         ($this->_majorVersion == 125 &&
                          $this->_minorVersion >= 1)) {
+                        $this->setFeature('utf');
                         $this->setFeature('accesskey');
                         $this->setFeature('xmlhttpreq');
                     }
@@ -587,20 +541,6 @@ class Browser {
                 $this->setBrowser('imode');
                 $this->setFeature('images', false);
                 $this->_mobile = true;
-        } elseif (strpos($this->_agent, 'BlackBerry') !== false) {
-                $this->setBrowser('blackberry');
-                $this->setFeature('html', false);
-                $this->setFeature('javascript', false);
-                $this->setFeature('hdml');
-                $this->setFeature('wml');
-                $this->_mobile = true;
-            } elseif (strpos($this->_agent, 'MOT-') !== false) {
-                $this->setBrowser('motorola');
-                $this->setFeature('html', false);
-                $this->setFeature('javascript', false);
-                $this->setFeature('hdml');
-                $this->setFeature('wml');
-                $this->_mobile = true;
             } elseif (strpos($this->_lowerAgent, 'j-') !== false) {
                 $this->setBrowser('mml');
                 $this->_mobile = true;
@@ -615,6 +555,8 @@ class Browser {
      * to let us tell what line breaks to send, so it's good enough
      * for its purpose.
      *
+     * @access public
+     *
      * @since Horde 2.2
      */
     function _setPlatform()
@@ -643,6 +585,8 @@ class Browser {
     /**
      * Sets the current browser.
      *
+     * @access public
+     *
      * @param string $browser  The browser to set as current.
      */
     function setBrowser($browser)
@@ -653,6 +597,8 @@ class Browser {
     /**
      * Determine if the given browser is the same as the current.
      *
+     * @access public
+     *
      * @param string $browser  The browser to check.
      *
      * @return boolean  Is the given browser the same as the current?
@@ -675,6 +621,8 @@ class Browser {
     /**
      * Determines if the browser is a robot or not.
      *
+     * @access public
+     *
      * @return boolean  True if browser is a known robot.
      */
     function isRobot()
@@ -690,6 +638,8 @@ class Browser {
     /**
      * Retrieve the current browser.
      *
+     * @access public
+     *
      * @return string  The current browser.
      */
     function getBrowser()
@@ -700,6 +650,8 @@ class Browser {
     /**
      * Retrieve the current browser's major version.
      *
+     * @access public
+     *
      * @return integer  The current browser's major version.
      */
     function getMajor()
@@ -710,6 +662,8 @@ class Browser {
     /**
      * Retrieve the current browser's minor version.
      *
+     * @access public
+     *
      * @return integer  The current browser's minor version.
      */
     function getMinor()
@@ -720,6 +674,8 @@ class Browser {
     /**
      * Retrieve the current browser's version.
      *
+     * @access public
+     *
      * @return string  The current browser's version.
      */
     function getVersion()
@@ -730,6 +686,8 @@ class Browser {
     /**
      * Return the full browser agent string.
      *
+     * @access public
+     *
      * @return string  The browser agent string.
      */
     function getAgentString()
@@ -740,8 +698,10 @@ class Browser {
     /**
      * Set unique behavior for the current browser.
      *
-     * @param string $quirk  The behavior to set.
-     * @param string $value  Special behavior parameter.
+     * @access public
+     *
+     * @param string $quirk           The behavior to set.
+     * @param optional string $value  Special behavior parameter.
      */
     function setQuirk($quirk, $value = true)
     {
@@ -751,6 +711,8 @@ class Browser {
     /**
      * Check unique behavior for the current browser.
      *
+     * @access public
+     *
      * @param string $quirk  The behavior to check.
      *
      * @return boolean  Does the browser have the behavior set?
@@ -761,9 +723,11 @@ class Browser {
     }
 
     /**
-     * Retrieve unique behavior for the current browser.
+     * Retreive unique behavior for the current browser.
      *
-     * @param string $quirk  The behavior to retrieve.
+     * @access public
+     *
+     * @param string $quirk  The behavior to retreive.
      *
      * @return string  The value for the requested behavior.
      */
@@ -777,8 +741,10 @@ class Browser {
     /**
      * Set capabilities for the current browser.
      *
-     * @param string $feature  The capability to set.
-     * @param string $value    Special capability parameter.
+     * @access public
+     *
+     * @param string $feature         The capability to set.
+     * @param optional string $value  Special capability parameter.
      */
     function setFeature($feature, $value = true)
     {
@@ -788,6 +754,8 @@ class Browser {
     /**
      * Check the current browser capabilities.
      *
+     * @access public
+     *
      * @param string $feature  The capability to check.
      *
      * @return boolean  Does the browser have the capability set?
@@ -798,9 +766,11 @@ class Browser {
     }
 
     /**
-     * Retrieve the current browser capability.
+     * Retreive the current browser capability.
      *
-     * @param string $feature  The capability to retrieve.
+     * @access public
+     *
+     * @param string $feature  The capability to retreive.
      *
      * @return string  The value of the requested capability.
      */
@@ -814,6 +784,8 @@ class Browser {
     /**
      * Determine if we are using a secure (SSL) connection.
      *
+     * @access public
+     *
      * @return boolean  True if using SSL, false if not.
      */
     function usingSSLConnection()
@@ -826,6 +798,8 @@ class Browser {
     /**
      * Returns the server protocol in use on the current server.
      *
+     * @access public
+     *
      * @return string  The HTTP server protocol version.
      */
     function getHTTPProtocol()
@@ -842,6 +816,8 @@ class Browser {
     /**
      * Determine if files can be uploaded to the system.
      *
+     * @access public
+     *
      * @return integer  If uploads allowed, returns the maximum size of the
      *                  upload in bytes.  Returns 0 if uploads are not
      *                  allowed.
@@ -853,35 +829,21 @@ class Browser {
                 !is_writable($dir)) {
                 return 0;
             }
-            $filesize = ini_get('upload_max_filesize');
-            switch (strtolower(substr($filesize, -1, 1))) {
+            $size = ini_get('upload_max_filesize');
+            switch (strtolower(substr($size, -1, 1))) {
             case 'k':
-                $filesize = intval(floatval($filesize) * 1024);
+                $size = intval(floatval($size) * 1024);
                 break;
 
             case 'm':
-                $filesize = intval(floatval($filesize) * 1024 * 1024);
+                $size = intval(floatval($size) * 1024 * 1024);
                 break;
 
             default:
-                $filesize = intval($filesize);
+                $size = intval($size);
                 break;
             }
-            $postsize = ini_get('post_max_size');
-            switch (strtolower(substr($postsize, -1, 1))) {
-            case 'k':
-                $postsize = intval(floatval($postsize) * 1024);
-                break;
-
-            case 'm':
-                $postsize = intval(floatval($postsize) * 1024 * 1024);
-                break;
-
-            default:
-                $postsize = intval($postsize);
-                break;
-            }
-            return min($filesize, $postsize);
+            return $size;
         } else {
             return 0;
         }
@@ -891,10 +853,12 @@ class Browser {
      * Determines if the file was uploaded or not.  If not, will return the
      * appropriate error message.
      *
-     * @param string $field  The name of the field containing the uploaded
-     *                       file.
-     * @param string $name   The file description string to use in the error
-     *                       message.  Default: 'file'.
+     * @access public
+     *
+     * @param string $field           The name of the field containing the
+     *                                uploaded file.
+     * @param optional string $name   The file description string to use in the
+     *                                error message.  Default: 'file'.
      *
      * @return mixed  True on success, PEAR_Error on error.
      */
@@ -946,10 +910,13 @@ class Browser {
     /**
      * Returns the headers for a browser download.
      *
-     * @param string $filename  The filename of the download.
-     * @param string $cType     The content-type description of the file.
-     * @param boolean $inline   True if inline, false if attachment.
-     * @param string $cLength   The content-length of this file.
+     * @access public
+     *
+     * @param optional string $filename  The filename of the download.
+     * @param optional string $cType     The content-type description of the
+     *                                   file.
+     * @param optional boolean $inline   True if inline, false if attachment.
+     * @param optional string $cLength   The content-length of this file.
      *
      * @since Horde 2.2
      */
@@ -998,15 +965,16 @@ class Browser {
             }
         }
 
-        /* Content-Length Header. */
-        if (!is_null($cLength)) {
+        /* Content-Length Header. Don't send Content-Length for
+         * HTTP/1.1 servers. */
+        if (($this->getHTTPProtocol() != '1.1') && !is_null($cLength)) {
             header('Content-Length: ' . $cLength);
         }
 
         /* Overwrite Pragma: and other caching headers for IE. */
         if ($this->hasQuirk('cache_ssl_downloads')) {
             header('Expires: 0');
-            header('Cache-Control: must-revalidate');
+            header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
             header('Pragma: public');
         }
     }
@@ -1014,6 +982,8 @@ class Browser {
     /**
      * Determines if a browser can display a given MIME type.
      *
+     * @access public
+     *
      * @param string $mimetype  The MIME type to check.
      *
      * @return boolean  True if the browser can display the MIME type.
@@ -1056,15 +1026,17 @@ class Browser {
             return false;
         }
 
-        return in_array($subtype, $this->_images);
+        return (in_array($subtype, $this->_images));
     }
 
     /**
      * Escape characters in javascript code if the browser requires it.
-     * %23, %26, and %2B (for some browsers) and %27 need to be escaped or
-     * else javascript will interpret it as a single quote, pound sign, or
+     * %23, %26, and %2B (for IE) and %27 need to be escaped or else
+     * jscript will interpret it as a single quote, pound sign, or
      * ampersand and refuse to work.
      *
+     * @access public
+     *
      * @param string $code  The JS code to escape.
      *
      * @return string  The escaped code.
@@ -1074,10 +1046,9 @@ class Browser {
         $from = $to = array();
 
         if ($this->isBrowser('msie') ||
-            ($this->isBrowser('mozilla') && ($this->getMajor() >= 5)) ||
-            $this->isBrowser('konqueror')) {
+            ($this->isBrowser('mozilla') && ($this->getMajor() >= 5))) {
             $from = array('%23', '%26', '%2B');
-            $to = array('%2523', '%2526', '%252B');
+            $to = array(urlencode('%23'), urlencode('%26'), urlencode('%2B'));
         }
         $from[] = '%27';
         $to[] = '\%27';
@@ -1088,6 +1059,8 @@ class Browser {
     /**
      * Set the IE version in the session.
      *
+     * @access public
+     *
      * @param string $ver  The IE Version string.
      */
     function setIEVersion($ver)
@@ -1100,6 +1073,8 @@ class Browser {
     /**
      * Return the IE version stored in the session, if available.
      *
+     * @access public
+     *
      * @return mixed  The IE Version string or null if no string is stored.
      */
     function getIEVersion()
