@@ -1,12 +1,9 @@
 <?php
-
-require_once dirname(__FILE__) . '/../Browser.php';
-
 /**
  * The Browser_imode:: class extends the Browser API by providing
  * specific information about Imode handsets.
  *
- * $Horde: framework/Browser/Browser/imode.php,v 1.7.12.1 2005/01/03 12:18:54 jan Exp $
+ * $Horde: framework/Browser/Browser/imode.php,v 1.7.12.2 2005/01/12 15:54:42 chuck Exp $
  *
  * Copyright 2000-2005 Mika Tuupola
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
@@ -15,7 +12,6 @@ require_once dirname(__FILE__) . '/../Browser.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.7.12.1 $
  * @since   Horde 3.0
  * @package Horde_Browser
  */
@@ -26,7 +22,7 @@ class Browser_imode {
      *
      * @var array $_data
      */
-    var $_data = array( 
+    var $_data = array(
         'D209i' => array(
             'imagewidth' => 96, 'imageheight' => 90,
             'textwidth' => 8, 'textheight' => 7,
@@ -51,61 +47,61 @@ class Browser_imode {
             'color' => 'grey',
             'imageformats' => array('gif')
         ),
-        'P209is' => array( 
+        'P209is' => array(
             'imagewidth' => 96, 'imageheight' => 87,
             'textwidth' => 8, 'textheight' => 6,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'R209i' => array( 
+        'R209i' => array(
             'imagewidth' => 96, 'imageheight' => 72,
             'textwidth' => 8, 'textheight' => 6,
             'color' => 'grey',
             'imageformats' => array('gif')
         ),
-        'ER209i' => array( 
+        'ER209i' => array(
             'imagewidth' => 120, 'imageheight' => 72,
             'textwidth' => 10, 'textheight' => 6,
             'color' => 'grey',
             'imageformats' => array('gif')
         ),
-        'KO209i' => array( 
+        'KO209i' => array(
             'imagewidth' => 96, 'imageheight' => 96,
             'textwidth' => 8, 'textheight' => 8,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'D210i' => array( 
+        'D210i' => array(
             'imagewidth' => 96, 'imageheight' => 91,
             'textwidth' => 8, 'textheight' => 7,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'F210i' => array( 
+        'F210i' => array(
             'imagewidth' => 96, 'imageheight' => 113,
             'textwidth' => 8, 'textheight' => 8,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'N210i' => array( 
+        'N210i' => array(
             'imagewidth' => 118, 'imageheight' => 113,
             'textwidth' => 10, 'textheight' => 8,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'P210i' => array( 
+        'P210i' => array(
             'imagewidth' => 96, 'imageheight' => 91,
             'textwidth' => 8, 'textheight' => 6,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'KO210i' => array( 
+        'KO210i' => array(
             'imagewidth' => 96, 'imageheight' => 96,
             'textwidth' => 8, 'textheight' => 8,
             'color' => 256,
             'imageformats' => array('gif')
         ),
-        'SO210i' => array( 
+        'SO210i' => array(
             'imagewidth' => 120, 'imageheight' => 113,
             'textwidth' => 8, 'textheight' => 7,
             'color' => 256,
@@ -288,36 +284,26 @@ class Browser_imode {
         's' => 'Second version'
     );
 
-    // properties. meant be private. 
-    //
-    var $_user_agent;   
-    var $_model;            
-    var $_manufacturer;     
-    var $_httpversion;  
+    var $_user_agent;
+    var $_model;
+    var $_manufacturer;
+    var $_httpversion;
     var $_cache = 5;
     var $_extra;
 
-    // Constructor
-    //   This gets called when new object is initialized. Does not
-    //   handle bogus user_agents or most of the other error situation
-    //   properly yet.
-    //
-    // Parameters:
-    //   String describing the user_agent.
-    //
-    // Returns:
-    //   Object
-    //
-    // Example usage:
-    //   $ua = new Imode_User_Agent($HTTP_USER_AGENT);
-    //
+    /**
+     * Does not handle bogus user_agents or most of the other error
+     * situation properly yet.
+     *
+     * Example usage:
+     *   $ua = &new Browser_imode($_SERVEr['HTTP_USER_AGENT']);
+     *
+     * @param string $input  The user agent to match.
+     */
     function Browser_imode($input)
     {
-        //DoCoMo/1.0/SO502i
-        //DoCoMo/1.0/N502it/c10
-
         $_error = 0;
-        $temp = explode('/', $input);    
+        $temp = explode('/', $input);
 
         $this->_user_agent = $input;
         $this->_httpversion = $temp[1];
@@ -327,61 +313,50 @@ class Browser_imode {
         }
 
         preg_match('/(^[a-zA-Z]+)([0-9]+i)(.*)\/?(.*)/', $this->_model, $matches);
- 
-        // TODO: Fix situation of unknown manufacturer. Implement
-        // extrainfo properly
-        //
+
+        // @TODO: Fix situation of unknown manufacturer. Implement
+        // extrainfo properly.
         $this->_manufacturer = $this->_manufacturerlist[$matches[1]];
-        $this->_extra = $matches[3]; 
+        $this->_extra = $matches[3];
 
         if (!($this->_data[$this->_model])) {
             $_error = PEAR::raiseError('Unknown User Agent');
         }
-    } 
+    }
 
-    // Method
-    //
-    // Returns:
-    //   Array containing maximum imagewidth and imageheight
-    //   to fit on the handset screen without scrolling.
-    //
-    // Example usage:
-    //  $imagedim    = $ua->getImageDimensions();
-    //  $imagewidth  = $imagedim[0];
-    //  $imageheight = $imagedim[1];
-    //
+    /**
+     * Example usage:
+     *  $imagedim    = $ua->getImageDimensions();
+     *  $imagewidth  = $imagedim[0];
+     *  $imageheight = $imagedim[1];
+     *
+     * @return array  The maximum imagewidth and imageheight that
+     *                fit on the handset screen without scrolling.
+     */
     function getImageDimensions()
     {
         $data = $this->_data[$this->_model];
         return array($data['imagewidth'], $data['imageheight']);
     }
 
-    // Method
-    //
-    // Returns:
-    //   Array containing maximum textwidth and textheight
-    //   to fit on the handset screen without scrolling.
-    //
-    // Example usage:
-    //  $textdim    = $ua->getTextDimensions();
-    //  $textwidth  = $textdim[0];
-    //  $textheight = $textdim[1];
-    //
+    /**
+     * Example usage:
+     *  $textdim    = $ua->getTextDimensions();
+     *  $textwidth  = $textdim[0];
+     *  $textheight = $textdim[1];
+     *
+     * @return array  The Maximum textwidth and textheight that
+     *                fit on the handset screen without scrolling.
+     */
     function getTextDimensions()
     {
-        $data = $this->_data[$this->_model];
-        return array($data['textwidth'], $data['textheight']);
+        return array($this->_data[$this->_model]['textwidth'],
+                     $this->_data[$this->_model]['textheight']);
     }
 
-    // Method
-    //
-    // Returns:
-    //   Integer containing the amount of handset cache in
-    //   kilobytes.
-    //
-    // Example usage:
-    //   $cache = $ua->getCache();
-    //
+    /**
+     * @return integer  The amount of handset cache in kilobytes.
+     */
     function getCache()
     {
         return (int)$this->_cache;
@@ -402,18 +377,13 @@ class Browser_imode {
         return $this->_data[$this->_model]['imageformats'];
     }
 
-    // Method
-    //
-    // Returns:
-    //   Integer describing what color model the handset supports.
-    //   Values have the following meaning:
-    //     0 -> black and white
-    //     1 -> 4 tone greyscale
-    //     2 -> 256 color
-    //
-    // Example usage:
-    //   $ua->getColor()
-    //
+    /**
+     * @return integer  Which color model the handset supports.
+     *   Values have the following meaning:
+     *     0 -> black and white
+     *     1 -> 4 tone greyscale
+     *     2 -> 256 color
+     */
     function getColor()
     {
         return $this->_data[$this->_model]['color'];
@@ -426,20 +396,17 @@ class Browser_imode {
 
     function isColor()
     {
-        $color = $this->_data[$this->_model]['color'];
-        return ($color == 256);
+        return $this->_data[$this->_model]['color'] == 256;
     }
 
     function isGreyScale()
     {
-        $color = $this->_data[$this->_model]['color'];
-        return ($color == 'grey');
+        return $this->_data[$this->_model]['color'] == 'grey';
     }
 
     function isBlackAndWhite()
     {
-        $color = $this->_data[$this->_model]['color'];
-        return ($color == 'black');
+        return $this->_data[$this->_model]['color'] == 'black';
     }
 
 }
