@@ -7,7 +7,7 @@
  *   'dir'          The directory to store the cache files in.
  *   'prefix'       The filename prefix to use for the cache files.
  *
- * $Horde: framework/Cache/Cache/file.php,v 1.28.10.1 2005/01/03 12:18:55 jan Exp $
+ * $Horde: framework/Cache/Cache/file.php,v 1.28.10.2 2005/01/07 19:06:09 chuck Exp $
  *
  * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
@@ -162,11 +162,9 @@ class Horde_Cache_file extends Horde_Cache {
                 return true;
             }
 
-            $lastmod = filemtime($filename);
-
             /* If the file was been created after the supplied value,
              * the data is valid (fresh). */
-            if (time() - $lifetime <= $lastmod) {
+            if (time() - $lifetime <= filemtime($filename)) {
                 return true;
             } else {
                 @unlink($filename);
