@@ -1,42 +1,37 @@
 <?php
 /**
- * The Cipher_rc4:: class implements the Cipher interface encryption data
+ * The Cipher_rc4:: class implements the Cipher interface enryption data
  * using the RC4 encryption algorthim. This class uses the PEAR Crypt_RC4
  * class to do the encryption.
  *
- * $Horde: framework/Cipher/Cipher/rc4.php,v 1.4.12.8 2007/01/02 13:54:10 jan Exp $
+ * $Horde: framework/Cipher/Cipher/rc4.php,v 1.4.12.1 2005/01/03 12:18:55 jan Exp $
  *
- * Copyright 2002-2007 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
+ * @version $Revision: 1.4.12.1 $
  * @since   Horde 2.2
  * @package Horde_Cipher
  */
 class Horde_Cipher_rc4 extends Horde_Cipher {
 
-    /**
-     * Pointer to a PEAR Crypt_rc4 object
-     *
-     * @var array
-     */
+    /* Pointer to a PEAR Crypt_rc4 object */
     var $_cipher = array();
 
-    /**
-     * Constructor
-     */
+    /* Constructor */
     function Horde_Cipher_rc4($params = null)
     {
         require_once 'Crypt/Rc4.php';
-        $this->_cipher = &new Crypt_Rc4();
+        $this->_cipher = new Crypt_Rc4();
     }
 
     /**
-     * Set the key to be used for en/decryption.
+     * Set the key to be used for en/decryption
      *
-     * @param string $key  The key to use.
+     * @param String $key   The key to use
      */
     function setKey($key)
     {
@@ -44,9 +39,9 @@ class Horde_Cipher_rc4 extends Horde_Cipher {
     }
 
     /**
-     * Return the size of the blocks that this cipher needs.
+     * Return the size of the blocks that this cipher needs
      *
-     * @return integer  The number of characters per block.
+     * @return Integer  The number of characters per block
      */
     function getBlockSize()
     {
@@ -54,12 +49,12 @@ class Horde_Cipher_rc4 extends Horde_Cipher {
     }
 
     /**
-     * Encrypt a block of data.
+     * Encrypt a block on data.
      *
-     * @param string $block  The data to encrypt.
-     * @param string $key    The key to use.
+     * @param String $block         The data to encrypt
+     * @param optional String $key  The key to use
      *
-     * @return string  The encrypted output.
+     * @return String the encrypted output
      */
     function encryptBlock($block, $key = null)
     {
@@ -67,7 +62,7 @@ class Horde_Cipher_rc4 extends Horde_Cipher {
             $this->setKey($key);
         }
 
-        // Make a copy of the cipher as it destroys itself during a crypt
+        // Make a copy of the cipher as it desctories its self during a crypt
         $cipher = $this->_cipher;
         $cipher->crypt($block);
 
@@ -75,12 +70,12 @@ class Horde_Cipher_rc4 extends Horde_Cipher {
     }
 
     /**
-     * Decrypt a block of data.
+     * Decrypt a block on data.
      *
-     * @param string $block  The data to decrypt.
-     * @param string $key    The key to use.
+     * @param String $block         The data to decrypt
+     * @param optional String $key  The key to use
      *
-     * @return string  The decrypted output.
+     * @return String the decrypted output
      */
     function decryptBlock($block, $key = null)
     {
@@ -88,12 +83,10 @@ class Horde_Cipher_rc4 extends Horde_Cipher {
             $this->setKey($key);
         }
 
-        // Make a copy of the cipher as it destroys itself during a
-        // crypt.
+        // Make a copy of the cipher as it desctories its self during a crypt
         $cipher = $this->_cipher;
         $cipher->decrypt($block);
 
         return $block;
     }
-
 }
