@@ -6,9 +6,9 @@ require_once 'Horde/Crypt.php';
  * Horde_Crypt_smime:: provides a framework for Horde applications to
  * interact with the OpenSSL library and implement S/MIME.
  *
- * $Horde: framework/Crypt/Crypt/smime.php,v 1.49.2.19 2008/07/16 05:42:24 slusarz Exp $
+ * $Horde: framework/Crypt/Crypt/smime.php,v 1.49.2.2 2005/01/28 21:01:34 chuck Exp $
  *
- * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -22,14 +22,14 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Object Identifers to name array.
      *
-     * @var array
+     * @var array $_oids
      */
     var $_oids = array(
         '2.5.4.3' => 'CommonName',
         '2.5.4.4' => 'Surname',
         '2.5.4.6' => 'Country',
-        '2.5.4.7' => 'Location',
-        '2.5.4.8' => 'StateOrProvince',
+        '2.5.4.7' => 'StateOrProvince',
+        '2.5.4.8' => 'Location',
         '2.5.4.9' => 'StreetAddress',
         '2.5.4.10' => 'Organisation',
         '2.5.4.11' => 'OrganisationalUnit',
@@ -70,6 +70,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Constructor.
      *
+     * @access public
+     *
      * @param array $params  Parameter array.
      *                       'temp' => Location of temporary directory.
      */
@@ -81,6 +83,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Verify a passphrase for a given private key.
      *
+     * @access public
+     *
      * @param string $private_key  The user's private key.
      * @param string $passphrase   The user's passphrase.
      *
@@ -102,6 +106,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Encrypt text using S/MIME.
      *
+     * @access public
+     *
      * @param string $text   The text to be encrypted.
      * @param array $params  The parameters needed for encryption.
      *                       See the individual _encrypt*() functions for
@@ -130,6 +136,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Decrypt text via S/MIME.
      *
+     * @access public
+     *
      * @param string $text   The text to be smime decrypted.
      * @param array $params  The parameters needed for decryption.
      *                       See the individual _decrypt*() functions for
@@ -159,15 +167,17 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Verify a signature using via S/MIME.
      *
+     * @access public
+     *
      * @param string $text  The multipart/signed data to be verified.
      * @param mixed $certs  Either a single or array of root certificates.
      *
-     * @return stdClass  Object with the following elements:
-     *                   'result' -> Returns true on success;
-     *                               PEAR_Error object on error.
-     *                   'cert' -> The certificate of the signer stored
-     *                             in the message (in PEM format).
-     *                   'email' -> The email of the signing person.
+     * @return object stdClass  Object with the following elements:
+     *                          'result' -> Returns true on success;
+     *                                      PEAR_Error object on error.
+     *                          'cert' -> The certificate of the signer stored
+     *                                    in the message (in PEM format).
+     *                          'email' -> The email of the signing person.
      */
     function verify($text, $certs)
     {
@@ -196,7 +206,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
             }
         }
 
-        $ob = new stdClass;
+        $ob = &new stdClass;
 
         if (!empty($root_certs)) {
             $result = openssl_pkcs7_verify($input, 0, $output, $root_certs);
@@ -212,12 +222,10 @@ class Horde_Crypt_smime extends Horde_Crypt {
         /* Try again without verfying the signer's cert */
         $result = openssl_pkcs7_verify($input, PKCS7_NOVERIFY, $output);
 
-        if ($result === true) {
+        if (($result === true) || ($result === -1)) {
             $ob->result = PEAR::raiseError(_("Message Verified Successfully but the signer's certificate could not be verified."), 'horde.warning');
-        } elseif ($result == -1) {
-            $ob->result = PEAR::raiseError(_("Verification failed - an unknown error has occurred."), 'horde.error');
         } else {
-            $ob->result = PEAR::raiseError(_("Verification failed - this message may have been tampered with."), 'horde.error');
+            $ob->result = PEAR::raiseError(_("Verification failed - this message may have been tampered with."), 'horde.warning');
         }
 
         $ob->cert = file_get_contents($output);
@@ -229,6 +237,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Extract the contents from signed S/MIME data.
      *
+     * @access public
+     *
      * @param string $data     The signed S/MIME data.
      * @param string $sslpath  The path to the OpenSSL binary.
      *
@@ -266,11 +276,14 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Sign a MIME_Part using S/MIME.
      *
-     * @param MIME_Part $mime_part  The MIME_Part object to sign.
-     * @param array $params         The parameters required for signing.
+     * @access public
      *
-     * @return MIME_Part  A MIME_Part object that is signed.
-     *                    Returns PEAR_Error object on error.
+     * @param object MIME_Part $mime_part  The MIME_Part object to sign.
+     * @param array $params                The parameters required for
+     *                                     signing.
+     *
+     * @return object MIME_Part  A MIME_Part object that is signed.
+     *                           Returns PEAR_Error object on error.
      */
     function signMIMEPart($mime_part, $params)
     {
@@ -288,7 +301,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
         $smime_sign->transferDecodeContents();
         $smime_sign->setTransferEncoding('base64');
 
-        $smime_part = new MIME_Part('multipart/signed');
+        $smime_part = &new MIME_Part('multipart/signed');
         $smime_part->setContents('This is a cryptographically signed message in MIME format.' . "\n");
         $smime_part->addPart($mime_part);
         $smime_part->addPart($smime_sign);
@@ -301,11 +314,14 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Encrypt a MIME_Part using S/MIME.
      *
-     * @param MIME_Part $mime_part  The MIME_Part object to encrypt.
-     * @param array $params         The parameters required for encryption.
+     * @access public
      *
-     * @return MIME_Part  A MIME_Part object that is encrypted.
-     *                    Returns PEAR_Error on error.
+     * @param object MIME_Part $mime_part  The MIME_Part object to encrypt.
+     * @param array $params                The parameters required for
+     *                                     encryption.
+     *
+     * @return object MIME_Part  A MIME_Part object that is encrypted.
+     *                           Returns PEAR_Error on error.
      */
     function encryptMIMEPart($mime_part, $params = array())
     {
@@ -318,15 +334,11 @@ class Horde_Crypt_smime extends Horde_Crypt {
             return $message;
         }
 
-        /* Get charset for mime part description. */
-        $charset = NLS::getEmailCharset();
-
         /* Break the result into its components */
         $mime_message = MIME_Structure::parseTextMIMEMessage($message);
 
         $smime_part = $mime_message->getBasePart();
-        $smime_part->setCharset($charset);
-        $smime_part->setDescription(String::convertCharset(_("S/MIME Encrypted Message"), NLS::getCharset(), $charset));
+        $smime_part->setDescription(_('S/MIME Encrypted Message'));
         $smime_part->transferDecodeContents();
         $smime_part->setTransferEncoding('base64');
         $smime_part->setDisposition('inline');
@@ -367,7 +379,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
 
         /* Check for required parameters. */
         if (!isset($params['pubkey'])) {
-            return PEAR::raiseError(_("A public S/MIME key is required to encrypt a message."), 'horde.error');
+            return PEAR::raiseError(_("A public SMIME key is required to encrypt a message."), 'horde.error');
         }
 
         /* Create temp files for input/output. */
@@ -392,7 +404,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
         if (openssl_pkcs7_encrypt($input, $output, $params['pubkey'], array('To' => $email))) {
             $result = file_get_contents($output);
             if (!empty($result)) {
-                return $this->_fixContentType($result, 'encrypt');
+                return $result;
             }
         }
 
@@ -473,8 +485,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
             return PEAR::raiseError(_("Could not S/MIME sign message."), 'horde.error');
         }
 
-        $data = file_get_contents($output);
-        return $this->_fixContentType($data, 'signature');
+        return file_get_contents($output);
     }
 
     /**
@@ -532,14 +543,18 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Sign and Encrypt a MIME_Part using S/MIME.
      *
-     * @param MIME_Part $mime_part   The MIME_Part object to sign and encrypt.
-     * @param array $sign_params     The parameters required for signing. See
-     *                               _encryptSignature().
-     * @param array $encrypt_params  The parameters required for encryption.
-     *                               See _encryptMessage().
+     * @access public
      *
-     * @return MIME_Part  A MIME_Part object that is signed and encrypted.
-     *                    Returns PEAR_Error on error.
+     * @param object MIME_Part $mime_part  The MIME_Part object to sign and
+     *                                     encrypt.
+     * @param array $sign_params           The parameters required for
+     *                                     signing. See _encryptSignature().
+     * @param array $encrypt_params        The parameters required for
+     *                                     encryption. See _encryptMessage().
+     *
+     * @return object MIME_Part  A MIME_Part object that is signed and
+     *                           encrypted.
+     *                           Returns PEAR_Error on error.
      */
     function signAndEncryptMIMEPart($mime_part, $sign_params = array(),
                                     $encrypt_params = array())
@@ -561,6 +576,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Convert a PEM format certificate to readable HTML version
      *
+     * @access public
+     *
      * @param string $cert   PEM format certificate
      *
      * @return string  HTML detailing the certificate.
@@ -584,38 +601,38 @@ class Horde_Crypt_smime extends Horde_Crypt {
 
         /* Netscape Extensions */
         $fieldnames += array(
-            'netscape-cert-type' => _("Netscape certificate type"),
-            'netscape-base-url' => _("Netscape Base URL"),
-            'netscape-revocation-url' => _("Netscape Revocation URL"),
-            'netscape-ca-revocation-url' => _("Netscape CA Revocation URL"),
-            'netscape-cert-renewal-url' => _("Netscape Renewal URL"),
-            'netscape-ca-policy-url' => _("Netscape CA policy URL"),
-            'netscape-ssl-server-name' => _("Netscape SSL server name"),
-            'netscape-comment' => _("Netscape certificate comment")
+            'netscape-cert-type' => _('Netscape certificate type'),
+            'netscape-base-url' => _('Netscape Base URL'),
+            'netscape-revocation-url' => _('Netscape Revocation URL'),
+            'netscape-ca-revocation-url' => _('Netscape CA Revocation URL'),
+            'netscape-cert-renewal-url' => _('Netscape Renewal URL'),
+            'netscape-ca-policy-url' => _('Netscape CA policy URL'),
+            'netscape-ssl-server-name' => _('Netscape SSL server name'),
+            'netscape-comment' => _('Netscape certificate comment')
         );
 
         /* X590v3 Extensions */
         $fieldnames += array(
-            'id-ce-extKeyUsage' => _("X509v3 Extended Key Usage"),
-            'id-ce-basicConstraints' => _("X509v3 Basic Constraints"),
-            'id-ce-subjectAltName' => _("X509v3 Subject Alternative Name"),
-            'id-ce-subjectKeyIdentifier' => _("X509v3 Subject Key Identifier"),
-            'id-ce-certificatePolicies' => _("Certificate Policies"),
-            'id-ce-CRLDistributionPoints' => _("CRL Distribution Points"),
-            'id-ce-keyUsage' => _("Key Usage")
+            'id-ce-extKeyUsage' => _('X509v3 Extended Key Usage'),
+            'id-ce-basicConstraints' => _('X509v3 Basic Constraints'),
+            'id-ce-subjectAltName' => _('X509v3 Subject Alternative Name'),
+            'id-ce-subjectKeyIdentifier' => _('X509v3 Subject Key Identifier'),
+            'id-ce-certificatePolicies' => _('Certificate Policies'),
+            'id-ce-CRLDistributionPoints' => _('CRL Distribution Points'),
+            'id-ce-keyUsage' => _('Key Usage')
         );
 
         $cert_details = $this->parseCert($cert);
         if (!is_array($cert_details)) {
-            return '<pre class="fixed">' . _("Unable to extract certificate details") . '</pre>';
+            return '<pre class="fixed">' . _('Unable to extract certificate details') . '</pre>';
         }
         $certificate = $cert_details['certificate'];
 
         $text = '<pre class="fixed">';
 
-        /* Subject (a/k/a Certificate Owner) */
+        /* Subject */
         if (isset($certificate['subject'])) {
-            $text .= "<strong>" . _("Certificate Owner") . ":</strong>\n";
+            $text .= "<b>" . _("Subject") . ":</b>\n";
 
             foreach ($certificate['subject'] as $key => $value) {
                 if (isset($fieldnames[$key])) {
@@ -629,7 +646,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
 
         /* Issuer */
         if (isset($certificate['issuer'])) {
-            $text .= "<strong>" . _("Issuer") . ":</strong>\n";
+            $text .= "<b>" . _("Issuer") . ":</b>\n";
 
             foreach ($certificate['issuer'] as $key => $value) {
                 if (isset($fieldnames[$key])) {
@@ -642,13 +659,13 @@ class Horde_Crypt_smime extends Horde_Crypt {
         }
 
         /* Dates  */
-        $text .= "<strong>" . _("Validity") . ":</strong>\n";
+        $text .= "<b>" . _("Validity") . ":</b>\n";
         $text .= sprintf("&nbsp;&nbsp;%s: %s\n", _("Not Before"), strftime("%x %X", $certificate['validity']['notbefore']));
         $text .= sprintf("&nbsp;&nbsp;%s: %s\n", _("Not After"), strftime("%x %X", $certificate['validity']['notafter']));
         $text .= "\n";
 
-        /* Certificate Owner - Public Key Info */
-        $text .= "<strong>" . _("Public Key Info") . ":</strong>\n";
+        /* Subject Public Key Info */
+        $text .= "<b>" . _("Subject Public Key Info") . ":</b>\n";
         $text .= sprintf("&nbsp;&nbsp;%s: %s\n", _("Public Key Algorithm"), $certificate['subjectPublicKeyInfo']['algorithm']);
         if ($certificate['subjectPublicKeyInfo']['algorithm'] == 'rsaEncryption') {
             if (Util::extensionExists('bcmath')) {
@@ -686,7 +703,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
 
         /* X509v3 extensions */
         if (isset($certificate['extensions'])) {
-            $text .= "<strong>" . _("X509v3 extensions") . ":</strong>\n";
+            $text .= "<b>" . _("X509v3 extensions") . ":</b>\n";
 
             foreach ($certificate['extensions'] as $key => $value) {
                 if (is_array($value)) {
@@ -703,7 +720,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
         }
 
         /* Certificate Details */
-        $text .= "<strong>" . _("Certificate Details") . ":</strong>\n";
+        $text .= "<b>" . _("Certificate Details") . ":</b>\n";
         $text .= sprintf("&nbsp;&nbsp;%s: %d\n", _("Version"), $certificate['version']);
         $text .= sprintf("&nbsp;&nbsp;%s: %d\n", _("Serial Number"), $certificate['serialNumber']);
 
@@ -732,6 +749,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Extract the contents of a PEM format certificate to an array.
      *
+     * @access public
+     *
      * @param string $cert  PEM format certificate
      *
      * @return array  Array containing all extractable information about
@@ -753,7 +772,9 @@ class Horde_Crypt_smime extends Horde_Crypt {
 
         $cert_details = array();
         $cert_details['fingerprints']['md5'] = md5($raw_cert);
-        $cert_details['fingerprints']['sha1'] = sha1($raw_cert);
+        if (Util::extensionExists('mhash')) {
+            $cert_details['fingerprints']['sha1'] = bin2hex(mhash(MHASH_SHA1, $raw_cert));
+        }
 
         $cert_details['certificate']['extensions'] = array();
         $cert_details['certificate']['version'] = $cert_data[1][0][1][0][1] + 1;
@@ -818,19 +839,17 @@ class Horde_Crypt_smime extends Horde_Crypt {
 
         if (isset($cert_data[1][0][1][7]) &&
             is_array($cert_data[1][0][1][7][1])) {
-            foreach ($cert_data[1][0][1][7][1] as $ext) {
+            foreach($cert_data[1][0][1][7][1] as $ext) {
                 $oid = $ext[1][0][1];
                 $cert_details['certificate']['extensions'][$oid] = $ext[1][1];
             }
         }
 
         $i = 9;
-
-        while (isset($cert_data[1][0][1][$i]) &&
-               is_array($cert_data[1][0][1][$i][1])) {
+        while (isset($cert_data[1][0][1][$i])) {
             $oid = $cert_data[1][0][1][$i][1][0][1];
             $cert_details['certificate']['extensions'][$oid] = $cert_data[1][0][1][$i][1][1];
-            ++$i;
+            $i++;
         }
 
         foreach ($cert_details['certificate']['extensions'] as $oid => $val) {
@@ -1229,6 +1248,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Check for the presence of the OpenSSL extension to PHP.
      *
+     * @access public
+     *
      * @return boolean  Returns true if the openssl extension is available.
      *                  Returns a PEAR_Error if not.
      */
@@ -1242,19 +1263,16 @@ class Horde_Crypt_smime extends Horde_Crypt {
     /**
      * Extract the email address from a public key.
      *
+     * @access public
+     *
      * @param string $key  The public key.
      *
-     * @return mixed Returns the first email address found, or null if
-     * there are none.
+     * @return string  Returns the email address, or null if none is found.
      */
     function getEmailFromKey($key)
     {
         $key_info = openssl_x509_parse($key);
-        if (!is_array($key_info)) {
-            return null;
-        }
-
-        if (isset($key_info['subject'])) {
+        if (is_array($key_info) && isset($key_info['subject'])) {
             if (isset($key_info['subject']['Email'])) {
                 return $key_info['subject']['Email'];
             } elseif (isset($key_info['subject']['emailAddress'])) {
@@ -1262,20 +1280,6 @@ class Horde_Crypt_smime extends Horde_Crypt {
             }
         }
 
-        // Check subjectAltName per http://www.ietf.org/rfc/rfc3850.txt
-        if (isset($key_info['extensions']['subjectAltName'])) {
-            $names = preg_split('/\s*,\s*/', $key_info['extensions']['subjectAltName'], -1, PREG_SPLIT_NO_EMPTY);
-            foreach ($names as $name) {
-                if (strpos($name, ':') === false) {
-                    continue;
-                }
-                list($kind, $value) = explode(':', $name, 2);
-                if (String::lower($kind) == 'email') {
-                    return $value;
-                }
-            }
-        }
-
         return null;
     }
 
@@ -1283,6 +1287,8 @@ class Horde_Crypt_smime extends Horde_Crypt {
      * Convert a PKCS 12 encrypted certificate package into a private key,
      * public key, and any additional keys.
      *
+     * @access public
+     *
      * @param string $text   The PKCS 12 data.
      * @param array $params  The parameters needed for parsing.
      * <pre>
@@ -1294,11 +1300,11 @@ class Horde_Crypt_smime extends Horde_Crypt {
      *                  (Optional)
      * </pre>
      *
-     * @return stdClass  An object.
-     *                   'private' -  The private key in PEM format.
-     *                   'public'  -  The public key in PEM format.
-     *                   'certs'   -  An array of additional certs.
-     *                   Returns PEAR_Error on error.
+     * @return object stdClass  An object.
+     *                          'private' -  The private key in PEM format.
+     *                          'public'  -  The public key in PEM format.
+     *                          'certs'   -  An array of additional certs.
+     *                          Returns PEAR_Error on error.
      */
     function parsePKCS12Data($pkcs12, $params)
     {
@@ -1317,7 +1323,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
         $input = $this->_createTempFile('horde-smime');
         $output = $this->_createTempFile('horde-smime');
 
-        $ob = new stdClass;
+        $ob = &new stdClass;
 
         /* Write text to file */
         $fp = fopen($input, 'w+');
@@ -1348,7 +1354,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
             return PEAR::raiseError(_("Password incorrect"), 'horde.error');
         }
 
-        /* Extract the client public key next. */
+        /* Extract the public key next. */
         $cmdline = $sslpath . ' pkcs12 -in ' . $input . ' -out ' . $output . ' -nokeys -clcerts';
         if (isset($params['password'])) {
             $cmdline .= ' -passin stdin';
@@ -1360,7 +1366,7 @@ class Horde_Crypt_smime extends Horde_Crypt {
         }
         $ob->public = trim(file_get_contents($output));
 
-        /* Extract the CA public key next. */
+        /* Extract the public key next. */
         $cmdline = $sslpath . ' pkcs12 -in ' . $input . ' -out ' . $output . ' -nokeys -cacerts';
         if (isset($params['password'])) {
             $cmdline .= ' -passin stdin';
@@ -1375,27 +1381,4 @@ class Horde_Crypt_smime extends Horde_Crypt {
         return $ob;
     }
 
-    /**
-     * The Content-Type parameters PHP's openssl_pkcs7_* functions return are
-     * deprecated.  Fix these headers to the correct ones (see RFC 2311).
-     *
-     * @access private
-     *
-     * @param string $text  The PKCS7 data.
-     * @param string $type  Is this 'message' or 'signature' data?
-     *
-     * @return string  The PKCS7 data with the correct Content-Type parameter.
-     */
-    function _fixContentType($text, $type)
-    {
-        if ($type == 'message') {
-            $from = 'application/x-pkcs7-mime';
-            $to = 'application/pkcs7-mime';
-        } else {
-            $from = 'application/x-pkcs7-signature';
-            $to = 'application/pkcs7-signature';
-        }
-        return str_replace('Content-Type: ' . $from, 'Content-Type: ' . $to, $text);
-    }
-
 }
