@@ -8,9 +8,9 @@ require_once 'Horde/iCalendar.php';
  * methods that vCard and iCalendar implementation can share and rely
  * on.
  *
- * $Horde: framework/Data/Data/imc.php,v 1.32.10.9 2007/01/02 13:54:12 jan Exp $
+ * $Horde: framework/Data/Data/imc.php,v 1.32.10.1 2005/01/03 12:18:57 jan Exp $
  *
- * Copyright 1999-2007 Jan Schneider <jan@horde.org>
+ * Copyright 1999-2005 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -25,7 +25,9 @@ class Horde_Data_imc extends Horde_Data {
 
     function importData($text)
     {
-        $this->_iCal = new Horde_iCalendar();
+
+        $this->_iCal = &new Horde_iCalendar();
+
         if (!$this->_iCal->parsevCalendar($text)) {
             return PEAR::raiseError(_("There was an error importing the iCalendar data."));
         }
@@ -37,21 +39,24 @@ class Horde_Data_imc extends Horde_Data {
      * Builds an iCalendar file from a given data structure and
      * returns it as a string.
      *
-     * @param array $data     An array containing Horde_iCalendar_vevent
-     *                        objects
-     * @param string $method  The iTip method to use.
+     * @access public
+     *
+     * @param array $data    An array containing Horde_iCalendar_vevent
+     *                       objects
+     * @param string $method (optional) The iTip method to use.
      *
      * @return string  The iCalendar data.
      */
     function exportData($data, $method = 'REQUEST')
     {
-        $this->_iCal = new Horde_iCalendar();
-        $this->_iCal->setAttribute('METHOD', $method);
+        global $prefs;
 
+        $this->_iCal = &new Horde_iCalendar();
+
+        $this->_iCal->setAttribute('METHOD', $method);
         foreach ($data as $event) {
             $this->_iCal->addComponent($event);
         }
-
         return $this->_iCal->exportvCalendar();
     }
 
@@ -60,6 +65,7 @@ class Horde_Data_imc extends Horde_Data {
      * triggers its download.  It DOES NOT exit the current script but
      * only outputs the correct headers and data.
      *
+     * @access public
      * @param string $filename   The name of the file to be downloaded.
      * @param array $data        An array containing Horde_iCalendar_vevents
      */
@@ -74,9 +80,12 @@ class Horde_Data_imc extends Horde_Data {
      * Takes all necessary actions for the given import step,
      * parameters and form values and returns the next necessary step.
      *
-     * @param integer $action  The current step. One of the IMPORT_* constants.
-     * @param array $param     An associative array containing needed
-     *                         parameters for the current step.
+     * @access public
+     *
+     * @param integer $action        The current step. One of the IMPORT_*
+     *                               constants.
+     * @param optional array $param  An associative array containing needed
+     *                               parameters for the current step.
      * @return mixed  Either the next step as an integer constant or imported
      *                data set after the final step.
      */
