@@ -16,9 +16,9 @@
  * action is attached to if the value of 'foo' is 1 or 2, and disable it
  * otherwise.
  *
- * $Horde: framework/Form/Form/Action/conditional_enable.php,v 1.4.10.4 2007/01/02 13:54:19 jan Exp $
+ * $Horde: framework/Form/Form/Action/conditional_enable.php,v 1.4.10.1 2005/01/03 12:19:00 jan Exp $
  *
- * Copyright 2002-2007 Matt Kynaston <matt@kynx.org>
+ * Copyright 2002-2005 Matt Kynaston <matt@kynx.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -42,11 +42,11 @@ class Horde_Form_Action_conditional_enable extends Horde_Form_Action {
         }
         $vals = $this->_params['values'];
         $vals = (is_array($vals)) ? $vals : array($vals);
-        $args = "'$varname', $enabled, '" . implode("','", $vals) . "'";
+        $args = "'$varname', $enabled, '" . join("','", $vals) . "'";
 
         return "if (addEvent(document.$form_name.$target, 'onchange', \"checkEnabled(this, $args);\")) { "
-            . "  checkEnabled(document.$form_name.$varname, $args); "
-            . '};';
+               ."  checkEnabled(document.$form_name.$varname, $args); "
+               ."};";
     }
 
 }
