@@ -3,7 +3,7 @@
  * The Horde_Form_Renderer class provides HTML and other renderings of
  * forms for the Horde_Form:: package.
  *
- * $Horde: framework/Form/Form/Renderer.php,v 1.185.4.9 2005/06/23 19:59:43 selsky Exp $
+ * $Horde: framework/Form/Form/Renderer.php,v 1.185.4.4 2005/03/22 11:45:19 jan Exp $
  *
  * Copyright 2001-2005 Robert E. Coyle <robertecoyle@hotmail.com>
  *
@@ -11,6 +11,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Robert E. Coyle <robertecoyle@hotmail.com>
+ * @version $Revision: 1.185.4.4 $
  * @package Horde_Form
  */
 class Horde_Form_Renderer {
@@ -30,7 +31,7 @@ class Horde_Form_Renderer {
      * doing any needed escaping/sanitization yourself. Otherwise the title
      * will be run through htmlspecialchars() before being output.
      *
-     * @var boolean
+     * @var boolean $_encodeTitle
      */
     var $_encodeTitle = true;
 
@@ -38,7 +39,7 @@ class Horde_Form_Renderer {
      * Width of the attributes column.
      *
      * @access private
-     * @var string
+     * @var string $_attrColumnWidth
      */
     var $_attrColumnWidth = '15%';
 
@@ -49,7 +50,7 @@ class Horde_Form_Renderer {
      *                       Possible keys:<code>
      *                       'varrenderer_driver': specifies the driver
      *                           parameter to Horde_UI_VarRenderer::factory().
-     *                       'encode_title': @see $_encodeTitle</code>
+     *                       'encode_title': @see $_encodeTitle
      */
     function Horde_Form_Renderer($params = array())
     {
@@ -148,18 +149,18 @@ class Horde_Form_Renderer {
         echo "\n" . '</script>';
 
         /* Loop through the sections and print out a tab for each. */
-        echo "<ul class=\"tabset\">\n";
+        echo '<ul class="tabset">';
         foreach ($form->_sections as $section => $val) {
             $class = ($section == $open_section) ? ' class="activeTab"' : '';
             $js = sprintf('onclick="sections_%s.toggle(\'%s\'); return false;"',
                           $form->getName(),
                           $section);
-            printf('<li><a id="_tab_' . $section . '"' . $class . '" href="#" %s>%s%s</a> </li>' . "\n",
+            printf('<li><a id="_tab_' . $section . '"' . $class . '" href="#" %s>%s%s</a> </li>',
                    $js,
                    $form->getSectionImage($section),
                    str_replace(' ', '&nbsp;', $form->getSectionDesc($section)));
         }
-        echo "</ul></td></tr></table>\n";
+        echo '</ul></td></tr></table>';
     }
 
     function _renderSectionBegin(&$form, $section)
@@ -412,7 +413,7 @@ try {
                 $link = '<a href="#" onclick="alert(\'' . addslashes(@htmlspecialchars($var->getHelp())) . '\');return false;">' . $this->_helpMarker . '</a>';
             }
             $class = $this->getRowClass(false);
-            echo "</td>\n  <td align=\"right\" class=\"" . $class . '">' . $link . '&nbsp;';
+            echo "</td>\n  <td align=\"right\" class=\"" . $class . '">' . $link . '&nbsp';
         }
 
         echo "</td>\n</tr>\n";
