@@ -6,10 +6,10 @@ require_once 'Horde/History.php';
 /**
  * The Group:: class provides the Horde groups system.
  *
- * $Horde: framework/Group/Group.php,v 1.67.2.16.2.1 2008/03/12 17:35:31 chuck Exp $
+ * $Horde: framework/Group/Group.php,v 1.67.2.1 2005/01/03 12:19:01 jan Exp $
  *
- * Copyright 1999-2007 Stephane Huther <shuther@bigfoot.com>
- * Copyright 2001-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Stephane Huther <shuther@bigfoot.com>
+ * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -23,8 +23,7 @@ class Group {
 
     /**
      * Pointer to a DataTree instance to manage the different groups.
-     *
-     * @var DataTree
+     * @var object DataTree $_datatree
      */
     var $_datatree;
 
@@ -48,21 +47,15 @@ class Group {
     /**
      * Return a new group object.
      *
-     * @param string $name    The group's name.
-     * @param string $parent  The group's parent's name.
+     * @param string $name The group's name.
      *
-     * @return DataTreeObject_Group  A new group object.
+     * @return object DataTreeObject_Group A new group object.
      */
-    function &newGroup($name, $parent = DATATREE_ROOT)
+    function &newGroup($name)
     {
         if (empty($name)) {
             return PEAR::raiseError(_("Group names must be non-empty"));
         }
-
-        if ($parent != DATATREE_ROOT) {
-            $name = $this->getGroupName($parent) . ':' . DataTree::encodeName($name);
-        }
-
         $group = &new DataTreeObject_Group($name);
         $group->setGroupOb($this);
         return $group;
@@ -98,7 +91,7 @@ class Group {
      * unique ID, with the users and other data retrieved
      * appropriately.
      *
-     * @param integer $cid  The unique ID of the group to retrieve.
+     * @param string $cid  The unique ID of the group to retrieve.
      */
     function &getGroupById($cid)
     {
@@ -112,7 +105,7 @@ class Group {
     /**
      * Get a globally unique ID for a group.
      *
-     * @param DataTreeObject_Group $group  The group.
+     * @param object DataTreeObject_Group $group  The group.
      *
      * @return string  A GUID referring to $group.
      */
@@ -126,7 +119,7 @@ class Group {
      * created with Group::newGroup(), and have any initial users
      * added to it, before this function is called.
      *
-     * @param DataTreeObject_Group $group  The new group object.
+     * @param object DataTreeObject_Group $group The new group object.
      */
     function addGroup($group)
     {
@@ -149,9 +142,10 @@ class Group {
     }
 
     /**
-     * Store updated data - users, etc. - of a group to the backend system.
+     * Store updated data - users, etc. - of a group to the backend
+     * system.
      *
-     * @param DataTreeObject_Group $group  The group to update.
+     * @param object DataTreeObject_Group $group   The group to update.
      */
     function updateGroup($group)
     {
@@ -180,8 +174,8 @@ class Group {
      * Change the name of a group without changing its contents or
      * where it is in the groups hierarchy.
      *
-     * @param DataTreeObject_Group $group  The group to rename.
-     * @param string $newName              The group's new name.
+     * @param object DataTreeObject_Group $group   The group to rename.
+     * @param string                      $newName The group's new name.
      */
     function renameGroup($group, $newName)
     {
@@ -202,8 +196,10 @@ class Group {
     /**
      * Remove a group from the groups system permanently.
      *
-     * @param DataTreeObject_Group $group  The group to remove.
-     * @param boolean $force               Force to remove every child.
+     * @param object DataTreeObject_Group $group  The group to remove.
+     *
+     * @param optional boolean force [default = false] Force to remove
+     *                         every child
      */
     function removeGroup($group, $force = false)
     {
@@ -220,35 +216,23 @@ class Group {
     /**
      * Retrieve the name of a group.
      *
-     * @param integer $gid  The id of the group to retrieve the name for.
+     * @param integer $groupId  The id of the group to retrieve the name for..
      *
      * @return string  The group's name.
      */
-    function getGroupName($gid)
+    function getGroupName($groupId)
     {
-        if (is_a($gid, 'DataTreeObject_Group')) {
-            return $this->_datatree->getName($gid->getId());
+        if (is_a($groupId, 'DataTreeObject_Group')) {
+            return $this->_datatree->getName($groupId->getId());
         } else {
-            return $this->_datatree->getName($gid);
+            return $this->_datatree->getName($groupId);
         }
     }
 
-    /**
-     * Strips all parent references off of the given group name.
-     *
-     * @param string $group  Name of the group.
-     *
-     * @return The name of the group without parents.
-     */
-    function getGroupShortName($group)
-    {
-        return $this->_datatree->getShortName($group);
-    }
-
     /**
      * Retrieve the ID of a group.
      *
-     * @param string $group  The group to retrieve the ID for.
+     * @param string $group  The group to retrieve the ID for..
      *
      * @return integer  The group's ID.
      */
@@ -264,9 +248,9 @@ class Group {
     /**
      * Check if a group exists in the system.
      *
-     * @param string $group  The group to check.
+     * @param string $group           The group to check.
      *
-     * @return boolean  True if the group exists, false otherwise.
+     * @return boolean true if the group exists, false otherwise.
      */
     function exists($group)
     {
@@ -276,54 +260,25 @@ class Group {
     /**
      * Get a list of the parents of a child group.
      *
-     * @param integer $gid The id of the child group.
+     * @param string $group The name of the child group.
      *
      * @return array
      */
-    function getGroupParents($gid)
+    function getGroupParents($group)
     {
-        $name = $this->getGroupName($gid);
-        return $this->_datatree->getParents($name);
-    }
-
-    /**
-     * Return the single parent of the given group.
-     *
-     * @param integer $gid  The DataTree ID of the child group.
-     *
-     * @return the parent of the given group.
-     */
-    function getGroupParent($gid)
-    {
-        return $this->_datatree->getParentById($gid);
-    }
-
-    /**
-     * Get a list of parents all the way up to the root object for $group.
-     *
-     * @param integer $gid  The id of the group.
-     *
-     * @return array  A flat list of all of the parents of $group,
-     *                hashed in $id => $name format.
-     */
-    function getGroupParentList($gid)
-    {
-        return $this->_datatree->getParentList($gid);
+        return $this->_datatree->getParents($group);
     }
 
     /**
      * Get a list of every group, in the format cid => groupname.
      *
-     * @param boolean $refresh  If true, the cached value is ignored and the group
-     *                          list is refreshed from the group backend.
-     *
      * @return array  CID => groupname hash.
      */
-    function listGroups($refresh = false)
+    function listGroups()
     {
         static $groups;
 
-        if ($refresh || is_null($groups)) {
+        if (is_null($groups)) {
             $groups = $this->_datatree->get(DATATREE_FORMAT_FLAT, DATATREE_ROOT, true);
             unset($groups[DATATREE_ROOT]);
         }
@@ -334,13 +289,14 @@ class Group {
     /**
      * Get a list of every user that is a part of this group ONLY.
      *
-     * @param integer $gid  The ID of the group.
+     * @param string $group  The name of the group.
      *
      * @return array  The user list.
+     * @access public
      */
-    function listUsers($gid)
+    function listUsers($group)
     {
-        $groupOb = &$this->getGroupById($gid);
+        $groupOb = &$this->getGroup($group);
         if (is_a($groupOb, 'PEAR_Error')) {
             return $groupOb;
         }
@@ -357,22 +313,24 @@ class Group {
      * Get a list of every user that is part of the specified group
      * and any of its subgroups.
      *
-     * @param integer $group  The ID of the parent group.
+     * @access public
+     *
+     * @param string $group  The name of the parent group.
      *
      * @return array  The complete user list.
      */
-    function listAllUsers($gid)
+    function listAllUsers($group)
     {
         // Get a list of every group that is a sub-group of $group.
-        $groups = $this->_datatree->get(DATATREE_FORMAT_FLAT, $this->getGroupName($gid), true);
+        $groups = $this->_datatree->get(DATATREE_FORMAT_FLAT, $group, true);
         if (is_a($groups, 'PEAR_Error')) {
             return $groups;
         }
 
-        $groups = array_keys($groups);
+        $groups = array($group) + $groups;
         $users = array();
-        foreach ($groups as $groupId) {
-            $users = array_merge($users, $this->listUsers($groupId));
+        foreach ($groups as $group) {
+            $users = array_merge($users, $this->listUsers($group));
         }
         return array_values(array_flip(array_flip($users)));
     }
@@ -397,8 +355,7 @@ class Group {
             $groups = $this->_datatree->getByAttributes($criteria);
 
             if (is_a($groups, 'PEAR_Error')) {
-                Horde::logMessage($groups, __FILE__, __LINE__, PEAR_LOG_ERR);
-                return false;
+                return $groups;
             }
 
             if ($parentGroups) {
@@ -420,58 +377,48 @@ class Group {
     /**
      * Say if a user is a member of a group or not.
      *
-     * @param string $user        The name of the user.
-     * @param integer $gid        The ID of the group.
-     * @param boolean $subgroups  Return true if the user is in any subgroups
-     *                            of group with ID $gid, also.
+     * @param          string  $user       The name of the user.
+     * @param          string  $group      The name of the group.
+     * @param optional boolean $subgroups  Return true if the user is in any subgroups
+     *                                     of $group, also.
      *
      * @return boolean
+     * @access public
      */
-    function userIsInGroup($user, $gid, $subgroups = true)
+    function userIsInGroup($user, $group, $subgroups = true)
     {
-        if (!$this->exists($this->getGroupName($gid))) {
+        if (!$this->exists($group)) {
             return false;
         } elseif ($subgroups) {
             $groups = $this->getGroupMemberships($user, true);
             if (is_a($groups, 'PEAR_Error')) {
-                Horde::logMessage($groups, __FILE__, __LINE__, PEAR_LOG_ERR);
-                return false;
+                return $groups;
             }
 
-            return !empty($groups[$gid]);
+            return !empty($groups[$this->getGroupId($group)]);
         } else {
-            $users = $this->listUsers($gid);
+            $users = $this->listUsers($group);
             if (is_a($users, 'PEAR_Error')) {
-                Horde::logMessage($users, __FILE__, __LINE__, PEAR_LOG_ERR);
-                return false;
+                return $users;
             }
             return in_array($user, $users);
         }
     }
 
-    /**
-     * Returns the DataTree level of the given group. 0 is returned for
-     * and object directly below DATATREE_ROOT.
-     *
-     * @param integer $gid  The DataTree ID of the group.
-     *
-     * @return The DataTree level of the group.
-     */
-    function getLevel($gid)
-    {
-        $name = $this->_datatree->getName($gid);
-        return substr_count($name, ':');
-    }
-
     /**
      * Attempts to return a concrete Group instance based on $driver.
      *
-     * @param mixed $driver  The type of concrete Group subclass to return.
-     * @param array $params  A hash containing any additional configuration or
-     *                       connection parameters a subclass might need.
+     * @access public
      *
-     * @return Group  The newly created concrete Group instance, or a
-     *                PEAR_Error object on an error.
+     * @param mixed $driver           The type of concrete Group subclass to
+     *                                return. The code is dynamically
+     *                                included.
+     * @param optional array $params  A hash containing any additional
+     *                                configuration or connection parameters a
+     *                                subclass might need.
+     *
+     * @return object Group   The newly created concrete Group instance, or a
+     *                        PEAR_Error object on an error.
      */
     function &factory($driver = '', $params = null)
     {
@@ -484,12 +431,10 @@ class Group {
         }
         $class = 'Group_' . $driver;
         if (class_exists($class)) {
-            $group = &new $class($params);
+            return $ret = &new $class($params);
         } else {
-            $group = PEAR::raiseError('Class definition of ' . $class . ' not found.');
+            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
-
-        return $group;
     }
 
     /**
@@ -499,7 +444,8 @@ class Group {
      *
      * This method must be invoked as: $var = &Group::singleton()
      *
-     * @return Group  The concrete Group reference, or false on an error.
+     * @return object Group  The concrete Group reference, or false on an
+     *                       error.
      */
     function &singleton()
     {
@@ -540,7 +486,7 @@ class DataTreeObject_Group extends DataTreeObject {
      * The Group object which this group is associated with - needed
      * for updating data in the backend to make changes stick, etc.
      *
-     * @var Group
+     * @var object Group $_groupOb
      */
     var $_groupOb;
 
@@ -548,7 +494,7 @@ class DataTreeObject_Group extends DataTreeObject {
      * This variable caches the users added or removed from the group
      * for History logging of user-groups relationship.
      *
-     * @var array
+     * @var array $_auditLog
      */
     var $_auditLog = array();
 
@@ -557,7 +503,7 @@ class DataTreeObject_Group extends DataTreeObject {
      * the parent constructor so that the group's name is set
      * properly.
      *
-     * @param string $name  The name of the group.
+     * @param string $name The name of the group.
      */
     function DataTreeObject_Group($name)
     {
@@ -567,7 +513,7 @@ class DataTreeObject_Group extends DataTreeObject {
     /**
      * Associates a Group object with this group.
      *
-     * @param Group $groupOb  The Group object.
+     * @param object Group $groupOb The Group object.
      */
     function setGroupOb(&$groupOb)
     {
@@ -589,8 +535,7 @@ class DataTreeObject_Group extends DataTreeObject {
      */
     function save()
     {
-        return $this->_groupOb->updateGroup($this);
-
+        $this->_groupOb->updateGroup($this);
     }
 
     /**
@@ -603,8 +548,8 @@ class DataTreeObject_Group extends DataTreeObject {
     {
         $this->data['users'][$username] = 1;
         $this->_auditLog[$username] = 'addUser';
-        if ($update && $this->_groupOb->exists($this->getName())) {
-            return $this->save();
+        if ($update && $this->_groupOb->_datatree->exists($this->getName())) {
+            $this->save();
         }
     }
 
@@ -619,7 +564,7 @@ class DataTreeObject_Group extends DataTreeObject {
         unset($this->data['users'][$username]);
         $this->_auditLog[$username] = 'deleteUser';
         if ($update) {
-            return $this->save();
+            $this->save();
         }
     }
 
@@ -627,22 +572,24 @@ class DataTreeObject_Group extends DataTreeObject {
      * Get a list of every user that is a part of this group
      * (and only this group)
      *
-     * @return array  The user list
+     * @return array The user list
+     * @access public
      */
     function listUsers()
     {
-        return $this->_groupOb->listUsers($this->getId());
+        return $this->_groupOb->listUsers($this->name);
     }
 
     /**
      * Get a list of every user that is a part of this group and
      * any of it's subgroups
      *
-     * @return array  The complete user list
+     * @return array The complete user list
+     * @access public
      */
     function listAllUsers()
     {
-        return $this->_groupOb->listAllUsers($this->getId());
+        return $this->_groupOb->listAllUsers($this->name);
     }
 
     /**
