@@ -2,19 +2,20 @@
 /**
  * The IMAP_Search:: class performs complex searching of an IMAP mailbox.
  *
- * Classes to help with complex searching of an IMAP mailbox.  The built-in
- * PHP search() function only allows IMAPv2 search queries (see RFC 1176).
- * This library allows more complex searches to be created (e.g. OR searches,
- * searching specific headers).
+ * Classes to help with complex searching of an IMAP mailbox.
+ * The built-in PHP search() function only allows IMAPv2 search queries
+ * (see RFC 1176).  This library allows more complex searches to be
+ * created (e.g. OR searches, searching specific headers).
  *
- * $Horde: framework/IMAP/IMAP/Search.php,v 1.29.10.27 2007/04/25 18:26:19 jan Exp $
+ * $Horde: framework/IMAP/IMAP/Search.php,v 1.29.10.6 2005/03/21 12:44:00 mdjukic Exp $
  *
- * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2003-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
- * See the enclosed file COPYING for license information (GPL). If you did not
- * receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (GPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @version $Revision: 1.29.10.6 $
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -23,48 +24,43 @@ class IMAP_Search {
     /**
      * The headers cache.
      *
-     * @var array
+     * @var array $_headers
      */
     var $_headers = array();
 
     /**
      * The results cache.
      *
-     * @var array
+     * @var array $_result
      */
     var $_result = array();
 
     /**
-     * The paramater list.
+     * Are we dealing with a POP3 connection?
      *
-     * @var array
+     * @var boolean $_pop3
      */
-    var $_params = array();
-
-    /**
-     * The charset of the search values.
-     *
-     * @var string
-     */
-    var $_charset;
+    var $_pop3 = false;
 
     /**
      * Internal flag used by searchMailbox().
      *
-     * @var integer
+     * @var integer $_searchflag
      */
     var $_searchflag = 0;
 
     /**
-     * Returns a reference to the global IMAP_Search object, only creating it
-     * if it doesn't already exist.
+     * Returns a reference to the global IMAP_Search object,
+     * only creating it if it doesn't already exist.
      *
-     * This method must be invoked as:<code>
-     *   $imap_search = &IMAP_Search::singleton();</code>
+     * This method must be invoked as:
+     *   $imap_search = &IMAP_Search::singleton();
      *
-     * @param array $params  Any parameters the constructor may need.
+     * @access public
      *
-     * @return IMAP_Search  The IMAP_Search instance.
+     * @param optional array $params  Any parameters the constructor may need.
+     *
+     * @return object IMAP_Search  The IMAP_Search instance.
      */
     function &singleton($params = array())
     {
@@ -78,35 +74,38 @@ class IMAP_Search {
     }
 
     /**
-     * Constructor.
+     * Constructor
      *
-     * @param array $params  A hash containing the following entries:<pre>
-     *                       'pop3' => boolean (using POP3 connection?)
-     *                       'charset' => string (charset of search values)
-     *                       'no_imap_search' => true if the IMAP server does
-     *                                           not support the charset in
-     *                                           the search command
-     *                       </pre>
+     * @access public
+     *
+     * @param optional array $params  A hash containing the following entries:
+     *                                'pop3' => boolean (using POP3
+     *                                                   connection?)
      */
     function IMAP_Search($params = array())
     {
-        $this->_params = $params;
+        if (isset($params['pop3'])) {
+            $this->_pop3 = $params['pop3'];
+        }
     }
 
     /**
-     * Searches messages by ALL headers (rather than the limited set provided
-     * by imap_search()).
+     * Searches messages by ALL headers (rather than the limited set
+     * provided by imap_search()).
      *
-     * @param IMAP_Search_Query $query  The search query.
-     * @param resource $imap            An IMAP resource stream.
-     * @param string $mbox              The name of the mailbox to search. For
-     *                                  POP3, this should be empty.
+     * @access public
+     *
+     * @param object IMAP_Search_Query $query  The search query.
+     * @param resource &$imap                  An IMAP resource stream.
+     * @param string $mbox                     The name of the mailbox to
+     *                                         search. For POP3, this should
+     *                                         be empty.
      *
      * @return array  The list of indices that match the search rules in the
      *                current mailbox.
      *                Returns PEAR_Error on error.
      */
-    function searchMailbox($query, $imap, $mbox)
+    function searchMailbox($query, &$imap, $mbox)
     {
         /* Check for IMAP extension. */
         if (!Util::extensionExists('imap')) {
@@ -114,10 +113,8 @@ class IMAP_Search {
         }
 
         /* Open to the correct mailbox. */
-        if (!$this->_params['pop3']) {
-            if (!@imap_reopen($imap, $mbox, OP_READONLY)) {
-                return array();
-            }
+        if (!$this->_pop3) {
+            @imap_reopen($imap, $mbox);
         }
 
         /* Clear the search flag. */
@@ -127,73 +124,54 @@ class IMAP_Search {
     }
 
     /**
-     * Searches the mailbox and sorts the results.
+     * Search the mailbox and sort the results.
      *
-     * @param IMAP_Search_Query $query  The search query.
-     * @param resource $imap            An IMAP resource stream.
-     * @param string $mbox              The name of the mailbox to search.
-     * @param integer $sortby           The criteria to sort by (see
-     *                                  imap_sort()).
-     * @param integer $sortdir          1 for reverse sorting.
+     * @access public
+     *
+     * @param object IMAP_Search_Query $query  The search query.
+     * @param resource &$imap                  An IMAP resource stream.
+     * @param string $mbox                     The name of the mailbox to
+     *                                         search.
+     * @param integer $criteria                The criteria to sort by
+     *                                         (see imap_sort()).
+     * @param optional integer $dir            1 for reverse sorting.
      *
      * @return array  The list of indices that match the search rules in the
      *                current mailbox and sorted.
      *                Returns PEAR_Error on error.
      */
-    function searchSortMailbox($query, $imap, $mbox, $sortby, $sortdir = 0)
+    function searchSortMailbox($query, &$imap, $mbox, $criteria, $dir = 0)
     {
         $indices = $this->searchMailbox($query, $imap, $mbox);
         if (is_a($indices, 'PEAR_Error')) {
             return $indices;
         } else {
-            $indices_sort = @imap_sort($imap, $sortby, $sortdir, SE_UID);
+            $indices_sort = @imap_sort($imap, $criteria, $dir, SE_UID);
             return array_values(array_intersect($indices_sort, $indices));
         }
     }
 
-    /**
-     * Internal wrapper method to imap_search that allows charset aware
-     * searches if available.
-     *
-     * @access private
-     */
-    function _imapSearch($imap, $criteria)
-    {
-        if (!empty($this->_params['charset'])) {
-            if (empty($this->_params['no_imap_charset']) &&
-                version_compare(phpversion(), '4.3.3', '>=')) {
-                return @imap_search($imap, $criteria, SE_UID, $this->_params['charset']);
-            } else {
-                $criteria = String::convertCharset($criteria, $this->_params['charset'], 'US-ASCII');
-            }
-        }
-
-        return @imap_search($imap, $criteria, SE_UID);
-    }
-
     /**
      * Internal function to search the mailbox.
      *
      * @access private
      */
-    function _searchMailbox($query, $imap, $mbox)
+    function _searchMailbox($query, &$imap, $mbox)
     {
         $indices = array();
 
-        $this->_searchflag = 0;
-
         /* Do the simple searches that imap_search() can handle. */
         if (($ob = $query->build())) {
             if ($ob->not) {
-                if (!($indices1 = $this->_imapSearch($imap, $ob->flags))) {
+                if (!($indices1 = @imap_search($imap, $ob->flags, SE_UID))) {
                     $indices1 = array();
                 }
-                if (!($indices2 = $this->_imapSearch($imap, $ob->query))) {
+                if (!($indices2 = @imap_search($imap, $ob->query, SE_UID))) {
                     $indices2 = array();
                 }
                 $indices = array_diff($indices1, $indices2);
             } else {
-                if (!($indices = $this->_imapSearch($imap, $ob->fullquery))) {
+                if (!($indices = @imap_search($imap, $ob->fullquery, SE_UID))) {
                     $indices = array();
                 }
             }
@@ -226,19 +204,14 @@ class IMAP_Search {
                     $result[] = $val->uid;
                 }
             }
-            if ($this->_searchflag == 0) {
-                $this->_searchflag = 1;
-            }
             $indices = array_values(array_intersect($indices, $result));
         }
 
         /* Process AND searches now. */
-        $indices = $this->_doAndOrSearch($query->andSearch(), $imap, $mbox,
-                                         'and', $indices);
+        $indices = $this->_doAndOrSearch($query->andSearch(), $imap, $mbox, 'and', $indices);
 
         /* Process OR searches now. */
-        $indices = $this->_doAndOrSearch($query->orSearch(), $imap, $mbox,
-                                         'or', $indices);
+        $indices = $this->_doAndOrSearch($query->orSearch(), $imap, $mbox, 'or', $indices);
 
         return $indices;
     }
@@ -248,7 +221,7 @@ class IMAP_Search {
      *
      * @access private
      */
-    function _doAndOrSearch($query, $imap, $mbox, $mode, $indices,
+    function _doAndOrSearch($query, &$imap, $mbox, $mode, $indices,
                             $base = false)
     {
         if (empty($query)) {
@@ -257,7 +230,6 @@ class IMAP_Search {
 
         foreach ($query as $val) {
             if (is_a($val, 'IMAP_Search_Query')) {
-                $prevsearch = (empty($indices) && ($this->_searchflag == 0));
                 $result = $this->_searchMailbox($val, $imap, $mbox);
                 if ($mode == 'and') {
                     /* If the result is empty in an AND search, we know that
@@ -267,13 +239,13 @@ class IMAP_Search {
                         return array();
                     }
 
-                    /* If we have reached this point, and have not performed a
-                       search yet, we must use the results as the indices
+                    /* If we have reached this point, and have not performed
+                       a search yet, we must use the results as the indices
                        list. Without this check, the indices list will always
                        be empty if an AND search is the first search. */
-                    if ($prevsearch) {
+                    if (empty($indices) && ($this->_searchflag == 1)) {
                         $indices = $result;
-                        $this->_searchflag = 1;
+                        $this->_searchflag = 2;
                     } else {
                         $indices = array_values(array_intersect($indices, $result));
                     }
@@ -289,18 +261,18 @@ class IMAP_Search {
     }
 
     /**
-     * Uses PHP based functions to perform the search.
+     * Use a PHP based functions to perform the search.
      *
      * @access private
      *
-     * @param stdClass $imap_query  Search query.
-     * @param string $flags         Any additional flags.
-     * @param resource $imap        An IMAP resource stream.
-     * @param string $mbox          The name of the search mailbox.
+     * @param object stdClass $imap_query  The search query.
+     * @param string $flags                Any additional flags.
+     * @param resource &$imap              An IMAP resource stream.
+     * @param string $mbox                 The name of the search mailbox.
      *
      * @return array  The list of indices that match.
      */
-    function _searchPHP($imap_query, $flags, $imap, $mbox)
+    function _searchPHP($imap_query, $flags, &$imap, $mbox)
     {
         $indices = array();
 
@@ -308,15 +280,15 @@ class IMAP_Search {
             $flags = 'ALL';
         }
 
-        if (!empty($this->_params['pop3'])) {
+        if ($this->_pop3) {
             $mbox = 'POP3';
         }
 
         $cache_key = $mbox . '|' . $flags;
 
-        /* We have to use parseMIMEHeaders() to get each header and see if any
-         * field matches. Use imap_search() to get the list of message indices
-         * or return empty list if no search results. */
+        /* We have to use parseMIMEHeaders() to get each header and see if
+           any field matches. Use imap_search() to get the list of message
+           indices or return empty list if no search results. */
         if (!isset($this->_result[$cache_key])) {
             $this->_result[$cache_key] = @imap_search($imap, $flags, SE_UID);
         }
@@ -342,10 +314,10 @@ class IMAP_Search {
             }
             $h = &$this->_headers[$mbox][$index];
 
-            /* We need to do a case insensitive search on text because, for
-             * example, e-mail addresses may not be caught correctly
-             * (filtering for example@example.com will not catch
-             * exAmple@example.com). */
+            /* We need to do a case insensitive search on text because,
+               for example, e-mail addresses may not be caught correctly
+               (filtering for example@example.com will not catch
+                exAmple@example.com). */
             $match_success = false;
             if (isset($h[$key])) {
                 $hdr_array = (is_array($h[$key])) ? $h[$key] : array($h[$key]);
@@ -368,10 +340,11 @@ class IMAP_Search {
 }
 
 /**
- * The IMAP_Search_Object:: class is used to formulate queries to be used with
- * the IMAP_Search:: class.
+ * The IMAP_Search_Object:: class is used to formulate queries to be used
+ * with the IMAP_Search:: class.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @version $Revision: 1.29.10.6 $
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -391,7 +364,7 @@ class IMAP_Search_Query {
     }
 
     /**
-     * Returns any extended searches.
+     * Return any extended searches.
      */
     function extendedSearch()
     {
@@ -406,7 +379,7 @@ class IMAP_Search_Query {
     }
 
     /**
-     * Returns the parameters for a size search.
+     * Return the parameters for a size search.
      */
     function sizeSearch()
     {
@@ -421,7 +394,7 @@ class IMAP_Search_Query {
     }
 
     /**
-     * Returns any AND searches.
+     * Return any AND searches.
      */
     function andSearch()
     {
@@ -429,7 +402,7 @@ class IMAP_Search_Query {
     }
 
     /**
-     * Returns any OR searches.
+     * Return any OR searches.
      */
     function orSearch()
     {
@@ -437,7 +410,7 @@ class IMAP_Search_Query {
     }
 
     /**
-     * Returns the flags.
+     * Return the flags.
      */
     function flags()
     {
@@ -445,7 +418,7 @@ class IMAP_Search_Query {
     }
 
     /**
-     * Builds the IMAP search query.
+     * Build the IMAP search query.
      */
     function build()
     {
@@ -455,7 +428,7 @@ class IMAP_Search_Query {
         $search->flags = $this->flags();
 
         if (empty($this->_query)) {
-            if (!empty($this->_or)) {
+            if (empty($search->flags)) {
                 return '';
             }
             $search->query = 'ALL';
@@ -466,7 +439,7 @@ class IMAP_Search_Query {
             }
             $search->query = $this->_query;
         }
-        $search->fullquery = (!empty($search->flags) ? $search->flags . ' ' : '') . $search->query;
+        $search->fullquery = $search->flags . ' ' . $search->query;
 
         return $search;
     }
@@ -493,8 +466,7 @@ class IMAP_Search_Query {
     /* IMAP Search Flags. */
     /* There is no need to support the KEYWORD/UNKEYWORD query since the
        individual keywords have identical functionality. */
-    function _imapFlags($flag, $cmd)
-    {
+    function _imapFlags($flag, $cmd) {
         $cmd = ($flag) ? $cmd : 'UN' . $cmd;
         $this->_flags[] = $cmd;
     }
@@ -530,13 +502,12 @@ class IMAP_Search_Query {
     }
 
     /* IMAP Header Search. */
-    function header($header, $query, $not = false)
-    {
+    function header($header, $query, $not = false) {
         $header = ucfirst(rtrim($header, ':'));
         $stdHdrs = array('To', 'Cc', 'From', 'Subject');
         if ($query != '') {
             if (in_array($header, $stdHdrs)) {
-                $this->_query = String::upper($header) . ' "' . str_replace('"', '\"', $query) . '"';
+                $this->_query = String::upper($header) . ' "' . addslashes($query) . '"';
             } else {
                 $this->_extendedSearch[$header] = $query;
             }
