@@ -2,7 +2,7 @@
 /**
  * IMAP_Thread provides functions for working with imap_thread() output.
  *
- * $Horde: framework/IMAP/IMAP/Thread.php,v 1.4.10.1 2005/01/03 12:19:02 jan Exp $
+ * $Horde: framework/IMAP/IMAP/Thread.php,v 1.4.10.6 2005/03/16 02:43:42 slusarz Exp $
  *
  * Copyright 2004-2005 Michael Slusarz <slusarz@curecanti.org>
  *
@@ -10,7 +10,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Michael Slusarz <slusarz@curecanti.org>
- * @version $Revision: 1.4.10.1 $
+ * @version $Revision: 1.4.10.6 $
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -71,7 +71,8 @@ class IMAP_Thread {
      */
     function getThreadIndent($index)
     {
-        if ($key = $this->_getKey($index)) {
+        $key = $this->_getKey($index);
+        if (!is_null($key)) {
             if (isset($this->_thread[$key]['level'])) {
                 return $this->_thread[$key]['level'];
             }
@@ -93,7 +94,8 @@ class IMAP_Thread {
      */
     function getThreadBase($index)
     {
-        if ($key = $this->_getKey($index)) {
+        $key = $this->_getKey($index);
+        if (!is_null($key)) {
             if (!empty($this->_thread[$key]['base'])) {
                 return $this->_thread[$key]['base'];
             }
@@ -115,7 +117,8 @@ class IMAP_Thread {
      */
     function lastInLevel($index)
     {
-        if ($key = $this->_getKey($index)) {
+        $key = $this->_getKey($index);
+        if (!is_null($key)) {
             if (!empty($this->_thread[$key]['last'])) {
                 return $this->_thread[$key]['last'];
             }
@@ -131,11 +134,11 @@ class IMAP_Thread {
      *
      * @param integer $index  The IMAP message index.
      *
-     * @return mixed  The array index value.
+     * @return mixed  The array index value or null if no index.
      */
     function _getKey($index)
     {
-        return (isset($this->_lookup[$index])) ? $this->_lookup[$index] : false;
+        return (isset($this->_lookup[$index])) ? $this->_lookup[$index] : null;
     }
 
     /**
@@ -165,15 +168,15 @@ class IMAP_Thread {
     {
         /* Find the beginning of the thread. */
         $begin = $this->getThreadBase($index);
-        if (empty($begin) ||
-            !($key = $this->_getKey($begin))) {
+        $key = $this->_getKey($begin);
+        if (is_null($key) || empty($begin)) {
             return array($index);
         }
 
         /* Work forward from the first thread element to find the end of the
          * thread. */
         $thread_list = array($this->_thread[$key]['index']);
-        while ($key++) {
+        while (++$key) {
             if (!isset($this->_thread[$key])) {
                 break;
             }
@@ -195,8 +198,8 @@ class IMAP_Thread {
      */
     function _processStructure()
     {
-        $last_index = $thread_base = null;
-        $ignore_list = $indices = array();
+        $container = $container_base = $last_index = $thread_base = $thread_base_idx = null;
+        $indices = array();
         $i = $last_i = $level = 0;
 
         foreach ($this->_threadarray as $key => $val) {
@@ -204,20 +207,15 @@ class IMAP_Thread {
             $index = substr($key, 0, $pos);
             $type = substr($key, $pos + 1);
 
-            if (isset($ignore_list[$index])) {
-                continue;
-            }
-
             switch ($type) {
             case 'num':
-                if (($val === 0) ||
-                    (!empty($this->_ignore) &&
-                     in_array($val, $this->_ignore))) {
-                    $ignore_list[$index] = 1;
+                if ($val === 0) {
+                    $container = $index;
                 } else {
                     $i++;
-                    if (empty($level)) {
+                    if (is_null($container) && empty($level)) {
                         $thread_base = $val;
+                        $thread_base_idx = $index;
                     }
                     $this->_lookup[$val] = $index;
                     $this->_thread[$index] = array();
@@ -226,16 +224,33 @@ class IMAP_Thread {
                 break;
 
             case 'next':
-                $i++;
-                $this->_thread[$index]['base'] = (!empty($val) || !empty($level)) ? $thread_base : null;
-                $level++;
+                if (!is_null($container) && ($container === $index)) {
+                    $container_base = $this->_threadarray[$val . '.num'];
+                } else {
+                    $i++;
+                    if (!is_null($container)) {
+                        $this->_thread[$index]['base'] = $container_base;
+                    } else {
+                        $this->_thread[$index]['base'] = (!empty($level) || ($val != 0)) ? $thread_base : null;
+                    }
+                    $level++;
+                }
                 break;
 
             case 'branch':
-                $this->_thread[$index]['level'] = $level--;
-                $this->_thread[$index]['last'] = true;
-                if (!empty($level)) {
-                    $this->_thread[$last_index]['last'] = ($last_i == ($i - 1));
+                if ($container === $index) {
+                    $container = $container_base = null;
+                    $this->_thread[$last_index]['last'] = true;
+                } else {
+                    $this->_thread[$index]['level'] = $level--;
+                    $this->_thread[$index]['last'] = !(!is_null($container) && empty($level));
+                    if ($index === $thread_base_idx) {
+                        $index = null;
+                    } elseif (!empty($level) &&
+                              !is_null($last_index) &&
+                              isset($this->_thread[$last_index])) {
+                        $this->_thread[$last_index]['last'] = ($last_i == ($i - 1));
+                    }
                 }
                 $last_index = $index;
                 $last_i = $i++;
