@@ -4,16 +4,17 @@
  * MIME type for various content, if it provided with different
  * levels of information.
  *
- * $Horde: framework/MIME/MIME/Magic.php,v 1.52.8.13 2007/01/02 13:54:25 jan Exp $
+ * $Horde: framework/MIME/MIME/Magic.php,v 1.52.8.2 2005/02/14 16:27:21 jan Exp $
  *
- * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
- * Copyright 2002-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @version $Revision: 1.52.8.2 $
  * @since   Horde 1.3
  * @package Horde_MIME
  */
@@ -63,6 +64,8 @@ class MIME_Magic {
      * we fall back to a custom MIME handler 'x-extension/$ext', which
      * can be used as a normal MIME type internally throughout Horde.
      *
+     * @access public
+     *
      * @param string $ext  The file extension to be mapped to a MIME type.
      *
      * @return string  The MIME type of the file extension.
@@ -91,13 +94,18 @@ class MIME_Magic {
     }
 
     /**
-     * Attempt to convert a filename to a MIME type, based on the global Horde
-     * and application specific config files.
+     * Attempt to convert a filename to a MIME type, based on the
+     * global Horde and application specific config files.
      *
-     * @param string $filename  The filename to be mapped to a MIME type.
-     * @param boolean $unknown  How should unknown extensions be handled? If
-     *                          true, will return 'x-extension/*' types.  If
-     *                          false, will return 'application/octet-stream'.
+     * @access public
+     *
+     * @param string $filename           The filename to be mapped to a MIME
+     *                                   type.
+     * @param optional boolean $unknown  How should unknown extensions be
+     *                                   handled?  If true, will return
+     *                                   'x-extension/*' types.  If false,
+     *                                   will return
+     *                                   'application/octet-stream'.
      *
      * @return string  The MIME type of the filename.
      */
@@ -129,6 +137,8 @@ class MIME_Magic {
      *
      * If we cannot map the type to a file extension, we return false.
      *
+     * @access public
+     *
      * @param string $type  The MIME type to be mapped to a file extension.
      *
      * @return string  The file extension of the MIME type.
@@ -158,41 +168,30 @@ class MIME_Magic {
      * Uses variants of the UNIX "file" command to attempt to determine the
      * MIME type of an unknown file.
      *
-     * @param string $path      The path to the file to analyze.
-     * @param string $magic_db  Path to the mime magic database.
+     * @access public
      *
-     * @return string  The MIME type of the file.  Returns false if the file
-     *                 type isn't recognized or an error happened.
+     * @param string $path  The path to the file to analyze.
+     *
+     * @return string  The MIME type of the file.  Returns false if either
+     *                 the file type isn't recognized or the file command is
+     *                 not available.
      */
-    function analyzeFile($path, $magic_db = null)
+    function analyzeFile($path)
     {
         /* If the PHP Mimetype extension is available, use that. */
         if (Util::extensionExists('fileinfo')) {
-            if (empty($magic_db)) {
-                $res = @finfo_open(FILEINFO_MIME);
-            } else {
-                $res = @finfo_open(FILEINFO_MIME, $magic_db);
+            $res = finfo_open(FILEINFO_MIME);
+            $type = finfo_file($res, $path);
+            finfo_close($res);
+
+            /* Remove any character set information. */
+            $pos = strpos($type, ';');
+            if ($pos !== false) { 
+                $type = rtrim(substr($type, 0, $pos));
             }
-            if ($res) {
-                $type = finfo_file($res, $path);
-                finfo_close($res);
-
-                /* Remove any additional information. */
-                foreach (array(';', ',', '\\0') as $separator) {
-                    $pos = strpos($type, $separator);
-                    if ($pos !== false) {
-                        $type = rtrim(substr($type, 0, $pos));
-                    }
-                }
-
-                if (preg_match('|^[a-z0-9]+/[.-a-z0-9]+$|i', $type)) {
-                    return $type;
-                }
-            }
-        }
-
-        if (Util::extensionExists('mime_magic')) {
-            return trim(mime_content_type($path));
+            return $type;
+        } elseif (Util::extensionExists('mime_magic')) {
+            return mime_content_type($path);
         } else {
             /* Use a built-in magic file. */
             $mime_magic = &MIME_Magic::_getMimeMagicFile();
@@ -220,40 +219,16 @@ class MIME_Magic {
      * Uses variants of the UNIX "file" command to attempt to determine the
      * MIME type of an unknown byte stream.
      *
-     * @param string $data      The file data to analyze.
-     * @param string $magic_db  Path to the mime magic database.
+     * @access public
      *
-     * @return string  The MIME type of the file.  Returns false if the file
-     *                 type isn't recognized or an error happened.
+     * @param string $data  The file data to analyze.
+     *
+     * @return string  The MIME type of the file.  Returns false if either
+     *                 the file type isn't recognized or the file command is
+     *                 not available.
      */
-    function analyzeData($data, $magic_db = null)
+    function analyzeData($data)
     {
-        /* If the PHP Mimetype extension is available, use that. */
-        if (Util::extensionExists('fileinfo')) {
-            if (empty($magic_db)) {
-                $res = @finfo_open(FILEINFO_MIME);
-            } else {
-                $res = @finfo_open(FILEINFO_MIME, $magic_db);
-            }
-            if (!$res) {
-                return false;
-            }
-
-            $type = finfo_buffer($res, $data);
-            finfo_close($res);
-
-            /* Remove any additional information. */
-            $pos = strpos($type, ';');
-            if ($pos !== false) {
-                $type = rtrim(substr($type, 0, $pos));
-            }
-            $pos = strpos($type, ',');
-            if ($pos !== false) {
-                $type = rtrim(substr($type, 0, $pos));
-            }
-            return $type;
-        }
-
         /* Use a built-in magic file. */
         $mime_magic = &MIME_Magic::_getMimeMagicFile();
         foreach ($mime_magic as $offset => $odata) {
