@@ -6,7 +6,7 @@ require_once dirname(__FILE__) . '/Part.php';
  * The MIME_Message:: class provides methods for creating and manipulating
  * MIME email messages.
  *
- * $Horde: framework/MIME/MIME/Message.php,v 1.76.10.9 2005/09/22 05:26:38 slusarz Exp $
+ * $Horde: framework/MIME/MIME/Message.php,v 1.76.10.2 2005/03/23 01:13:50 jan Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
@@ -16,6 +16,7 @@ require_once dirname(__FILE__) . '/Part.php';
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * @version $Revision: 1.76.10.2 $
  * @since   Horde 1.3
  * @package Horde_MIME
  */
@@ -24,22 +25,24 @@ class MIME_Message extends MIME_Part {
     /**
      * Has the message been parsed via buildMessage()?
      *
-     * @var boolean
+     * @var boolean $_build
      */
     var $_build = false;
 
     /**
      * The server to default unqualified addresses to.
      *
-     * @var string
+     * @var string $_defaultServer
      */
     var $_defaultServer = null;
 
     /**
      * Constructor - creates a new MIME email message.
      *
-     * @param string $defaultServer  The server to default unqualified
-     *                               addresses to.
+     * @access public
+     *
+     * @param optional string $defaultServer  The server to default
+     *                                        unqualified addresses to.
      */
     function MIME_Message($defaultServer = null)
     {
@@ -55,11 +58,13 @@ class MIME_Message extends MIME_Part {
      * This function can be called statically via:
      *    MIME_Message::convertMIMEPart();
      *
-     * @param MIME_Part &$mime_part  The MIME_Part object.
-     * @param string $server         The server to default unqualified
-     *                               addresses to.
+     * @access public
      *
-     * @return MIME_Message  The new MIME_Message object.
+     * @param object MIME_Part &$mime_part  The MIME_Part object.
+     * @param optional string $server       The server to default unqualified
+     *                                      addresses to.
+     *
+     * @return object MIME_Message  The new MIME_Message object.
      */
     function &convertMIMEPart(&$mime_part, $server = null)
     {
@@ -77,6 +82,8 @@ class MIME_Message extends MIME_Part {
     /**
      * Sends this message.
      *
+     * @access public
+     *
      * @param string $email    The address list to send to.
      * @param mixed &$headers  The MIME_Headers object holding this message's
      *                         headers, or a hash with header->value mappings.
@@ -118,6 +125,8 @@ class MIME_Message extends MIME_Part {
     /**
      * Take a set of headers and make sure they are encoded properly.
      *
+     * @access public
+     *
      * @param array $headers   The headers to encode.
      * @param string $charset  The character set to use.
      *
@@ -131,9 +140,6 @@ class MIME_Message extends MIME_Part {
         foreach ($headers as $key => $val) {
             if (in_array($key, $addressKeys)) {
                 $text = MIME::encodeAddress($val, $charset, $this->_defaultServer);
-                if (is_a($text, 'PEAR_Error')) {
-                    $text = $val;
-                }
             } else {
                 $text = MIME::encode($val, $charset);
             }
@@ -146,7 +152,9 @@ class MIME_Message extends MIME_Part {
     /**
      * Add the proper set of MIME headers for this message to an array.
      *
-     * @param array $headers  The headers to add the MIME headers to.
+     * @access public
+     *
+     * @param optional array $headers  The headers to add the MIME headers to.
      *
      * @return array  The full set of headers including MIME headers.
      */
@@ -166,6 +174,8 @@ class MIME_Message extends MIME_Part {
     /**
      * Return the entire message contents, including headers, as a string.
      *
+     * @access public
+     *
      * @return string  The encoded, generated message.
      */
     function toString()
@@ -180,6 +190,8 @@ class MIME_Message extends MIME_Part {
 
     /**
      * Build message from current contents.
+     *
+     * @access public
      */
     function buildMessage()
     {
@@ -208,6 +220,8 @@ class MIME_Message extends MIME_Part {
     /**
      * Get a list of all MIME subparts.
      *
+     * @access public
+     *
      * @return array  An array of the MIME_Part subparts.
      */
     function getParts()
@@ -225,7 +239,9 @@ class MIME_Message extends MIME_Part {
      * return a reference to make sure that the whole MIME_Message
      * object isn't accidentally modified.
      *
-     * @return MIME_Message  The base MIME_Part of the message.
+     * @access public
+     *
+     * @return object MIME_Message  The base MIME_Part of the message.
      */
     function getBasePart()
     {
@@ -236,33 +252,21 @@ class MIME_Message extends MIME_Part {
     /**
      * Retrieve a specific MIME part.
      *
+     * @access public
+     *
      * @param string $id  The MIME_Part ID string.
      *
-     * @return MIME_Part  The MIME_Part requested, or false if the part
-     *                    doesn't exist.
+     * @return object MIME_Part  The MIME_Part requested.  Returns false if
+     *                           the part doesn't exist.
      */
-    function &getPart($id)
+    function getPart($id)
     {
         if ($this->_build) {
-            $part = parent::getPart($id);
+            return parent::getPart($id);
         } else {
             $this->buildMessage();
-            $part = $this->getPart($id);
+            return $this->getPart($id);
         }
-        if (is_a($part, 'MIME_Message')) {
-            $newpart = &new MIME_Part();
-            $skip = array('_build', '_defaultServer');
-            foreach (array_keys(get_object_vars($part)) as $key) {
-                /* Ignore local variables that aren't a part of the original
-                 * class. */
-                if (!in_array($key, $skip)) {
-                    $newpart->$key = &$part->$key;
-                }
-            }
-            return $newpart;
-        } else {
-            return $part;
-       }
     }
 
 }
