@@ -26,7 +26,7 @@ define('MIME_DEFAULT_ENCODING', '7bit');
  * The MIME_Part:: class provides a wrapper around MIME parts and methods
  * for dealing with them.
  *
- * $Horde: framework/MIME/MIME/Part.php,v 1.177.4.1 2005/01/03 12:19:05 jan Exp $
+ * $Horde: framework/MIME/MIME/Part.php,v 1.177.4.3 2005/02/22 07:45:50 slusarz Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
@@ -36,7 +36,6 @@ define('MIME_DEFAULT_ENCODING', '7bit');
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.177.4.1 $
  * @since   Horde 1.3
  * @package Horde_MIME
  */
@@ -358,7 +357,7 @@ class MIME_Part {
      */
     function getCanonicalContents()
     {
-        return $this->replaceEOL($this->getContents(), MIME_PART_RFC_EOL);
+        return $this->replaceEOL($this->_contents, MIME_PART_RFC_EOL);
     }
 
     /**
@@ -390,7 +389,7 @@ class MIME_Part {
            like reset the internal bytes field, even though we shouldn't do
            that (the user has their reasons to set the bytes field to a
            non-zero value without putting the contents into this part. */
-        if (!empty($contents)) {
+        if (strlen($contents)) {
             $this->setContents($contents, $this->_currentEncoding);
         }
     }
@@ -724,7 +723,13 @@ class MIME_Part {
      */
     function &_partFind($id, &$parts, $retarray = false)
     {
-        if (empty($this->_idmap)) {
+        /* Pointers don't persist through sessions; therefore, we must make
+         * sure that the IdMap is destroyed at the end of each request.
+         * How can we do this? We check to see if $_idmap contains an array
+         * of MIME_Parts or an array of arrays. */
+        $check = reset($this->_idmap);
+        if (empty($check) || !is_a($check, 'MIME_Part')) {
+            $this->_idmap = array();
             $this->_generateIdMap($this->_parts);
         }
 
@@ -949,7 +954,7 @@ class MIME_Part {
            compliant. */
         if (($ptype == 'message') &&
             (($stype == 'rfc822') || ($stype == 'partial')) &&
-            (strpos($this->getContents(), 'MIME-Version: 1.0') !== false)) {
+            (strpos($this->_contents, 'MIME-Version: 1.0') !== false)) {
             $headers['MIME-Version'] = '1.0';
         }
 
@@ -996,9 +1001,9 @@ class MIME_Part {
     {
         $eol = $this->getEOL();
         $ptype = $this->getPrimaryType();
-        $text = '';
 
         if ($headers) {
+            $text = '';
             foreach ($this->header() as $key => $val) {
                 $text .= $key . ': ' . $val . $eol;
             }
@@ -1009,15 +1014,23 @@ class MIME_Part {
            contents themself. Simply output the contents of the part
            directly and return. */
         if ($ptype == 'message') {
-            return $text . $this->getContents();
+            if (isset($text)) {
+                return $text . $this->_contents;
+            } else {
+                return $this->_contents;
+            }
         }
 
-        $text .= $this->transferEncode();
+        if (isset($text)) {
+            $text .= $this->transferEncode();
+        } else {
+            $text = $this->transferEncode();
+        }
 
         /* Deal with multipart messages. */
         if ($ptype == 'multipart') {
             $boundary = trim($this->getContentTypeParameter('boundary'), '"');
-            if (!($this->getContents())) {
+            if (!strlen($this->_contents)) {
                 $text .= 'This message is in MIME format.' . $eol;
             }
             foreach ($this->getParts() as $part) {
@@ -1074,7 +1087,7 @@ class MIME_Part {
     {
         $encoding = $this->_transferEncoding;
         $ptype = $this->getPrimaryType();
-        $text = str_replace($this->getEOL(), ' ', $this->getContents());
+        $text = str_replace($this->getEOL(), ' ', $this->_contents);
 
         /* If there are no contents, return whatever the current value of
            $_transferEncoding is. */
@@ -1143,7 +1156,6 @@ class MIME_Part {
      */
     function transferEncode()
     {
-        $contents = $this->getContents();
         $encoding = $this->getTransferEncoding();
         $eol = $this->getEOL();
 
@@ -1153,9 +1165,9 @@ class MIME_Part {
 
         /* If contents are empty, or contents are already encoded to the
            correct encoding, return now. */
-        if (empty($contents) ||
+        if (!strlen($this->_contents) ||
             ($encoding == $this->_currentEncoding)) {
-            return $contents;
+            return $this->_contents;
         }
 
         switch ($encoding) {
@@ -1163,12 +1175,12 @@ class MIME_Part {
         case 'base64':
             /* Keeping these two lines separate seems to use much less
                memory than combining them (as of PHP 4.3). */
-            $encoded_contents = base64_encode($contents);
+            $encoded_contents = base64_encode($this->_contents);
             return chunk_split($encoded_contents, 76, $eol);
 
         /* Quoted-Printable Encoding: See RFC 2045, section 6.7 */
         case 'quoted-printable':
-            $output = MIME::quotedPrintableEncode($contents, $eol);
+            $output = MIME::quotedPrintableEncode($this->_contents, $eol);
             if (($eollength = String::length($eol))) {
                 return substr($output, 0, $eollength * -1);
             } else {
@@ -1176,7 +1188,7 @@ class MIME_Part {
             }
 
         default:
-            return $this->replaceEOL($contents);
+            return $this->replaceEOL($this->_contents);
         }
     }
 
@@ -1190,23 +1202,22 @@ class MIME_Part {
      */
     function transferDecode()
     {
-        $contents = $this->getContents();
         $encoding = $this->getCurrentEncoding();
 
         /* If the contents are empty, return now. */
-        if (empty($contents)) {
+        if (!strlen($this->_contents)) {
             $this->_flags['lastTransferDecode'] = $encoding;
-            return $contents;
+            return $this->_contents;
         }
 
         switch ($encoding) {
         case 'base64':
-            $message = base64_decode($contents);
+            $message = base64_decode($this->_contents);
             $this->_flags['lastTransferDecode'] = '8bit';
             break;
 
         case 'quoted-printable':
-            $message = preg_replace("/=\r?\n/", '', $contents);
+            $message = preg_replace("/=\r?\n/", '', $this->_contents);
             $message = $this->replaceEOL($message);
             $message = quoted_printable_decode($message);
             $this->_flags['lastTransferDecode'] = (MIME::is8bit($message)) ? '8bit' : '7bit';
@@ -1218,7 +1229,7 @@ class MIME_Part {
         case 'x-uuencode':
         case 'x-uue':
             require_once 'Mail/mimeDecode.php';
-            $files = &Mail_mimeDecode::uudecode($contents);
+            $files = &Mail_mimeDecode::uudecode($this->_contents);
             $message = $files[0]['filedata'];
             $this->_flags['lastTransferDecode'] = '8bit';
             break;
@@ -1226,9 +1237,9 @@ class MIME_Part {
         default:
             if (isset($this->_flags['lastTransferDecode']) &&
                 ($this->_flags['lastTransferDecode'] != $encoding)) {
-                $message = $this->replaceEOL($contents);
+                $message = $this->replaceEOL($this->_contents);
             } else {
-                $message = $contents;
+                $message = $this->_contents;
             }
             $this->_flags['lastTransferDecode'] = $encoding;
             break;
@@ -1256,14 +1267,14 @@ class MIME_Part {
             return false;
         }
 
-        if (!($contents = $this->getContents())) {
+        if (!strlen($this->_contents)) {
             return false;
         }
 
         $eol = $this->getEOL();
         $retvalue = false;
 
-        foreach (explode($eol, $contents) as $line) {
+        foreach (explode($eol, $this->_contents) as $line) {
             $pos = strpos($line, '--' . $boundary);
             if (($pos === false) && isset($part_ptr)) {
                 $data[] = $line;
@@ -1346,9 +1357,9 @@ class MIME_Part {
             }
         } else {
             if ($this->getPrimaryType() == 'text') {
-                $bytes = String::length($this->getContents(), $this->getCharset());
+                $bytes = String::length($this->_contents, $this->getCharset());
             } else {
-                $bytes = strlen($this->getContents());
+                $bytes = strlen($this->_contents);
             }
         }
 
