@@ -15,7 +15,7 @@
  * environment, that is we do CRLF conversion even if <nofill> is
  * specified in the text, but we're close at least.
  *
- * $Horde: framework/MIME/MIME/Viewer/enriched.php,v 1.23.10.1 2005/01/03 12:19:05 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/enriched.php,v 1.23.10.2 2005/01/18 23:32:21 jan Exp $
  *
  * Copyright 2001-2005 Eric Rostetter <eric.rostetter@physics.utexas.edu>
  *
@@ -23,7 +23,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Eric Rostetter <eric.rostetter@physics.utexas.edu>
- * @version $Revision: 1.23.10.1 $
+ * @version $Revision: 1.23.10.2 $
  * @since   Horde 2.1
  * @package Horde_MIME_Viewer
  */
@@ -157,7 +157,7 @@ class MIME_Viewer_enriched extends MIME_Viewer {
      */
     function getType()
     {
-        return 'text/html';
+        return 'text/html; charset=' . NLS::getCharset();
     }
 
 }
