@@ -6,7 +6,7 @@ require_once dirname(__FILE__) . '/source.php';
  * The MIME_Viewer_enscript class renders out various content
  * in HTML format by using GNU Enscript.
  *
- * $Horde: framework/MIME/MIME/Viewer/enscript.php,v 1.39.10.1 2005/01/03 12:19:05 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/enscript.php,v 1.39.10.2 2005/02/07 22:17:54 chuck Exp $
  *
  * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
  *
@@ -14,7 +14,6 @@ require_once dirname(__FILE__) . '/source.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.39.10.1 $
  * @since   Horde 1.3
  * @package Horde_MIME_Viewer
  */
@@ -50,7 +49,7 @@ class MIME_Viewer_enscript extends MIME_Viewer_source {
         fwrite($fh, $contents, strlen($contents));
         fclose($fh);
 
-        /* Execute the enscript command */
+        /* Execute the enscript command. */
         $lang = escapeshellarg($this->_typeToLang($this->mime_part->getType()));
         $results = shell_exec($mime_drivers['horde']['enscript']['location'] . " -E$lang --language=html --color --output=- < $tmpin");
 
@@ -110,6 +109,7 @@ class MIME_Viewer_enscript extends MIME_Viewer_source {
             return 'pascal';
 
         case 'al':
+        case 'cgi':
         case 'pl':
         case 'pm':
             return 'perl';
