@@ -3,7 +3,7 @@
  * The MIME_Viewer_rfc822 class renders out messages from the
  * message/rfc822 content type.
  *
- * $Horde: framework/MIME/MIME/Viewer/rfc822.php,v 1.8.10.1 2005/01/03 12:19:06 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/rfc822.php,v 1.8.10.2 2005/01/18 23:32:21 jan Exp $
  *
  * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
@@ -11,7 +11,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.8.10.1 $
+ * @version $Revision: 1.8.10.2 $
  * @since   Horde 3.0
  * @package Horde_MIME_Viewer
  */
@@ -105,7 +105,7 @@ class MIME_Viewer_rfc822 extends MIME_Viewer {
      */
     function getType()
     {
-        return 'text/plain';
+        return 'text/plain; charset=' . NLS::getCharset();
     }
 
 }
