@@ -2,7 +2,7 @@
 /**
  * The MIME_Viewer_tgz class renders out plain or gzipped tarballs in HTML.
  *
- * $Horde: framework/MIME/MIME/Viewer/tgz.php,v 1.37.10.9 2005/08/24 14:04:37 selsky Exp $
+ * $Horde: framework/MIME/MIME/Viewer/tgz.php,v 1.37.10.4 2005/03/04 11:07:18 jan Exp $
  *
  * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
  * Copyright 2002-2005 Michael Cochrane <mike@graftonhall.co.nz>
@@ -12,6 +12,7 @@
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
  * @author  Michael Cochrane <mike@graftonhall.co.nz>
+ * @version $Revision: 1.37.10.4 $
  * @since   Horde 1.3
  * @package Horde_MIME_Viewer
  */
@@ -20,7 +21,9 @@ class MIME_Viewer_tgz extends MIME_Viewer {
     /**
      * Render out the currently set tar file contents.
      *
-     * @param array $params  Any parameters the Viewer may need.
+     * @access public
+     *
+     * @param optional array $params  Any parameters the Viewer may need.
      *
      * @return string  The rendered contents.
      */
@@ -33,11 +36,10 @@ class MIME_Viewer_tgz extends MIME_Viewer {
         /* Only decompress gzipped files. */
         $subtype = $this->mime_part->getSubType();
         if (($subtype == 'x-compressed-tar') ||
+            ($subtype == 'x-gzip-compressed') ||
             ($subtype == 'tgz') ||
             ($subtype == 'x-tgz') ||
-            ($subtype == 'gzip') ||
             ($subtype == 'x-gzip') ||
-            ($subtype == 'x-gzip-compressed') ||
             ($subtype == 'x-gtar')) {
             $gzip = &Horde_Compress::singleton('gzip');
             $contents = $gzip->decompress($contents);
@@ -51,14 +53,12 @@ class MIME_Viewer_tgz extends MIME_Viewer {
         if ($subtype == 'gzip' ||
             $subtype == 'x-gzip' ||
             $subtype == 'x-gzip-compressed') {
-            global $conf;
             require_once 'Horde/MIME/Magic.php';
-            $mime_type = MIME_Magic::analyzeData($contents, isset($conf['mime']['magic_db']) ? $conf['mime']['magic_db'] : null);
+            $mime_type = MIME_Magic::analyzeData($contents);
             if (!$mime_type) {
                 return '<pre>' . $contents . '</pre>';
             }
             $mime_part = &new MIME_Part($mime_type, $contents);
-            $mime_part->setName($this->mime_part->getName());
             $mime_viewer = &MIME_Viewer::factory($mime_part, $mime_type);
             return '<pre>' . $mime_viewer->render() . '</pre>';
         }
@@ -75,7 +75,7 @@ class MIME_Viewer_tgz extends MIME_Viewer {
 
         include_once 'Horde/Text.php';
 
-        $text  = '<b>' . htmlspecialchars(sprintf(_("Contents of \"%s\""), $this->mime_part->getName())) . ':</b>' . "\n";
+        $text  = '<b>' . htmlspecialchars(sprintf(_("Contents of '%s'"), $this->mime_part->getName())) . ':</b>' . "\n";
         $text .= '<table><tr><td align="left"><tt><span class="fixed">';
         $text .= Text::htmlAllSpaces(_("Archive Name") . ':  ' . $this->mime_part->getName()) . "\n";
         $text .= Text::htmlAllSpaces(_("Archive File Size") . ': ' . strlen($contents) . ' bytes') . "\n";
@@ -108,6 +108,8 @@ class MIME_Viewer_tgz extends MIME_Viewer {
     /**
      * Return the content-type
      * 
+     * @access public
+     *
      * @return string  The content-type of the output.
      */ 
     function getType()
