@@ -3,16 +3,17 @@
  * The MIME_Viewer_zip class renders out the contents of ZIP files in HTML
  * format.
  *
- * $Horde: framework/MIME/MIME/Viewer/zip.php,v 1.30.10.10 2006/02/10 13:54:04 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/zip.php,v 1.30.10.1 2005/01/03 12:19:06 jan Exp $
  *
- * Copyright 2000-2006 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2002-2006 Michael Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2000-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2005 Michael Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Michael Cochrane <mike@graftonhall.co.nz>
+ * @version $Revision: 1.30.10.1 $
  * @since   Horde 2.0
  * @package Horde_MIME_Viewer
  */
@@ -21,7 +22,9 @@ class MIME_Viewer_zip extends MIME_Viewer {
     /**
      * Render out the current zip contents.
      *
-     * @param array $params  Any parameters the Viewer may need.
+     * @access public
+     *
+     * @param optional array $params  Any parameters the Viewer may need.
      *
      * @return string  The rendered contents.
      */
@@ -35,9 +38,9 @@ class MIME_Viewer_zip extends MIME_Viewer {
      *
      * @access private
      *
-     * @param string $contents  The contents of the zip archive.
-     * @param mixed $callback   The callback function to use on the zipfile
-     *                          information.
+     * @param string $contents          The contents of the zip archive.
+     * @param optional mixed $callback  The callback function to use on the
+     *                                  zipfile information.
      *
      * @return string  The file list.
      */
@@ -52,15 +55,12 @@ class MIME_Viewer_zip extends MIME_Viewer {
             return '<pre>' . _("This does not appear to be a valid zip file.") . '</pre>';
         }
 
-        $zipInfo = $zip->decompress($contents, array('action' => HORDE_COMPRESS_ZIP_LIST));
-        if (is_a($zipInfo, 'PEAR_Error')) {
-            return $zipInfo->getMessage();
-        }
+        $zipInfo = &$zip->decompress($contents, array('action' => HORDE_COMPRESS_ZIP_LIST));
         $fileCount = count($zipInfo);
-
+ 
         require_once 'Horde/Text.php';
 
-        $text = '<strong>' . htmlspecialchars(sprintf(_("Contents of \"%s\""), $this->mime_part->getName())) . ':</strong>' . "\n";
+        $text = '<b>' . htmlspecialchars(sprintf(_("Contents of '%s'"), $this->mime_part->getName())) . ':</b>' . "\n";
         $text .= '<table><tr><td align="left"><tt><span class="fixed">';
         $text .= Text::htmlAllSpaces(_("Archive Name") . ': ' . $this->mime_part->getName()) . "\n";
         $text .= Text::htmlAllSpaces(_("Archive File Size") . ': ' . strlen($contents) . ' bytes') . "\n";
@@ -69,11 +69,11 @@ class MIME_Viewer_zip extends MIME_Viewer {
         $text .= Text::htmlAllSpaces(
                      str_pad(_("File Name"),      50, ' ', STR_PAD_RIGHT) .
                      str_pad(_("Attributes"),     10, ' ', STR_PAD_LEFT) .
-                     str_pad(_("Size"),           10, ' ', STR_PAD_LEFT) .
-                     str_pad(_("Modified Date"),  19, ' ', STR_PAD_LEFT) .
-                     str_pad(_("Method"),         10, ' ', STR_PAD_LEFT) .
-                     str_pad(_("CRC"),            10, ' ', STR_PAD_LEFT) .
-                     str_pad(_("Ratio"),           7, ' ', STR_PAD_LEFT)
+                     str_pad(_("Size") ,          10, ' ', STR_PAD_LEFT) .
+                     str_pad(_("Modified Date") , 19, ' ', STR_PAD_LEFT) .
+                     str_pad(_("Method") ,        10, ' ', STR_PAD_LEFT) .
+                     str_pad(_("CRC") ,           10, ' ', STR_PAD_LEFT) .
+                     str_pad(_("Ratio") ,          7, ' ', STR_PAD_LEFT)
                  ) . "\n";
 
         $text .= str_repeat('-', 116) . "\n";
@@ -83,7 +83,7 @@ class MIME_Viewer_zip extends MIME_Viewer {
 
             $val['name'] = str_pad($val['name'], 50, ' ', STR_PAD_RIGHT);
             $val['attr'] = str_pad($val['attr'], 10, ' ', STR_PAD_LEFT);
-            $val['size'] = str_pad($val['size'], 10, ' ', STR_PAD_LEFT);
+            $val['size'] = str_pad($val['size'], 10, ' ', STR_PAD_LEFT); 
             $val['date'] = str_pad(strftime("%d-%b-%Y %H:%M", $val['date']), 19, ' ', STR_PAD_LEFT);
             $val['method'] = str_pad($val['method'], 10, ' ', STR_PAD_LEFT);
             $val['crc'] = str_pad($val['crc'], 10, ' ', STR_PAD_LEFT);
@@ -108,9 +108,11 @@ class MIME_Viewer_zip extends MIME_Viewer {
 
     /**
      * Return the content-type
+     * 
+     * @access public
      *
      * @return string  The content-type of the output.
-     */
+     */ 
     function getType()
     {
         return 'text/html; charset=' . NLS::getCharset();
