@@ -43,15 +43,15 @@ $GLOBALS['intervals'] = &$intervals;
  * The Maintenance:: class provides a set of methods for dealing with
  * maintenance operations run upon login to Horde applications.
  *
- * $Horde: framework/Maintenance/Maintenance.php,v 1.52 2004/10/21 19:18:56 chuck Exp $
+ * $Horde: framework/Maintenance/Maintenance.php,v 1.52.10.2 2005/01/03 12:19:06 jan Exp $
  *
- * Copyright 2001-2004 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2001-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.52 $
+ * @version $Revision: 1.52.10.2 $
  * @since   Horde 1.3.5
  * @package Horde_Maintenance
  */
@@ -381,11 +381,11 @@ class Maintenance {
 
             /* Determine if this task has already been confirmed/set via some
                sort of admin setting. Also, if the user/admin has set the
-               'confirm_maintenance' flag, use the preferences value. */
+               'confirm_maintenance' flag, skip confirmation. */
             $confirmed = false;
             if ($prefs->isLocked($key) ||
                 !$prefs->getValue('confirm_maintenance')) {
-                $confirmed = (bool)$prefs->getValue($key);
+                $confirmed = true;
             }
 
             /* Add the task to the tasklist. */
@@ -545,13 +545,13 @@ class Maintenance {
  * The Maintenance_Tasklist:: class is used to store the list of maintenance
  * tasks that need to be run during this login.
  *
- * Copyright 2002-2004 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2002-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.52 $
+ * @version $Revision: 1.52.10.2 $
  * @since   Horde 3.0
  * @package Horde_Maintenance
  */
@@ -813,13 +813,13 @@ class Maintenance_Tasklist {
  *     text. doMaintenance() will ALWAYS be run.
  *     * This style will be displayed on its own, separate maintenance page. *
  *
- * Copyright 2001-2004 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2001-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.52 $
+ * @version $Revision: 1.52.10.2 $
  * @since   Horde 1.3.5
  * @package Horde_Maintenance
  */
