@@ -13,7 +13,7 @@ define('HORDE_MENU_MASK_ALL',     15);
  * The Menu:: class provides standardized methods for creating menus in
  * Horde applications.
  *
- * $Horde: framework/Horde/Horde/Menu.php,v 1.35.2.7 2005/07/03 05:41:24 selsky Exp $
+ * $Horde: framework/Horde/Horde/Menu.php,v 1.35.2.3 2005/01/03 17:48:53 jan Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -31,19 +31,21 @@ class Menu {
     /**
      * Menu array.
      *
-     * @var array
+     * @var array $_menu
      */
     var $_menu = array();
 
     /**
      * Mask defining what general Horde links are shown in this Menu.
      *
-     * @var integer
+     * @var integer $_mask
      */
     var $_mask;
 
     /**
      * Constructor
+     *
+     * @access public
      */
     function Menu($mask = HORDE_MENU_MASK_ALL)
     {
@@ -97,17 +99,20 @@ class Menu {
     /**
      * Add an item to the menu array.
      *
-     * @param string $url        String containing the value for the hyperlink.
-     * @param string $text       String containing the label for this menu
-     *                           item.
-     * @param string $icon       String containing the filename of the image
-     *                           icon to display for this menu item.
-     * @param string $icon_path  If the icon lives in a non-default directory,
-     *                           where is it?
-     * @param string $target     If the link needs to open in another frame or
-     *                           window, what is its name?
-     * @param string $onclick    Onclick javascript, if desired.
-     * @param string $class      CSS class for the menu item.
+     * @param string $url                  String containing the value for
+     *                                     the hyperlink.
+     * @param string $text                 String containing the label for
+     *                                     this menu item.
+     * @param optional string $icon        String containing the filename of
+     *                                     the image icon to display for this
+     *                                     menu item.
+     * @param optional string $icon_path   If the icon lives in a non-default
+     *                                     directory, where is it?
+     * @param optional string $target      If the link needs to open in
+     *                                     another frame or window, what is
+     *                                     its name?
+     * @param optional string $onclick     Onclick javascript, if desired.
+     * @param optional string $class       CSS class for the menu item.
      *
      * @return integer  The id (NOT guaranteed to be an array index) of the item
      *                  just added to the menu.
@@ -138,11 +143,12 @@ class Menu {
     }
 
     /**
-     * Return the unordered list representing the list of menu items. Styling
-     * is done through CSS.
+     * Return the unordered list representing the list of menu
+     * items. Styling is done through CSS.
      *
-     * @return string  An unordered list of menu elements that can be entirely
-     *                 styled with CSS.
+     * @access public
+     *
+     * @return string  An unordered list of menu elements that can be entirely styled with CSS.
      */
     function render()
     {
@@ -237,7 +243,7 @@ class Menu {
                                 isset($m['onclick']) ? $m['onclick'] : '',
                                 '', $accesskey);
 
-            $output .= sprintf("\n<li>%s%s<br />%s</a></li>",
+            $output .= sprintf("<li>%s%s<br />%s</a></li>\n",
                                $link, $icon, ($menu_view != 'icon') ? Horde::highlightAccessKey($m['text'], $accesskey) : '');
         }
 
@@ -245,8 +251,11 @@ class Menu {
     }
 
     /**
-     * Any links to other Horde applications defined in an application's config
-     * file by the $conf['menu']['apps'] array are added to the menu array.
+     * Any links to other Horde applications defined in an application's
+     * config file by the $conf['menu']['apps'] array are added to the menu
+     * array.
+     *
+     * @access public
      */
     function addAppLinks()
     {
@@ -265,8 +274,10 @@ class Menu {
     }
 
     /**
-     * Add any other links found in $this->_menufile to be included in the
-     * menu.
+     * Add any other links found in $this->_menufile to be included in
+     * the menu.
+     *
+     * @access public
      */
     function addSiteLinks()
     {
@@ -283,6 +294,8 @@ class Menu {
     /**
      * Checks to see if the current url matches the given url.
      *
+     * @access public
+     *
      * @return boolean  Whether the given URL is the current location.
      */
     function isSelected($url)
