@@ -1,33 +1,36 @@
 <?php
 
-require_once 'Horde/Notification/Listener/status.php';
+require_once 'Horde/Notification/Listener.php';
 
 /**
  * The Notification_Listener_mobile:: class provides functionality for
  * displaying messages from the message stack on mobile devices.
  *
- * $Horde: framework/Notification/Notification/Listener/mobile.php,v 1.8.10.9 2007/01/02 13:54:34 jan Exp $
+ * $Horde: framework/Notification/Notification/Listener/mobile.php,v 1.8.10.2 2005/03/29 05:44:53 slusarz Exp $
  *
- * Copyright 2003-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
+ * @version $Revision: 1.8.10.2 $
  * @since   Horde 3.0
  * @package Horde_Notification
  */
-class Notification_Listener_mobile extends Notification_Listener_status {
+class Notification_Listener_mobile extends Notification_Listener {
 
     /**
      * The Horde_Mobile:: object that status lines should be added to.
      *
-     * @var Horde_Mobile
+     * @var object Horde_Mobile $_mobile
      */
     var $_mobile = null;
 
     /**
      * Constructor
+     *
+     * @access public
      */
     function Notification_Listener_mobile()
     {
@@ -40,7 +43,8 @@ class Notification_Listener_mobile extends Notification_Listener_status {
     /**
      * Associate a Horde_Mobile:: object with the listener.
      *
-     * @param Horde_Mobile  The Horde_Mobile:: object to send status lines to.
+     * @param object Horde_Mobile  The Horde_Mobile:: object to send
+     *                             status lines to.
      */
     function setMobileObject(&$mobile)
     {
@@ -50,6 +54,8 @@ class Notification_Listener_mobile extends Notification_Listener_status {
     /**
      * Return a unique identifier for this listener.
      *
+     * @access public
+     *
      * @return string  Unique id.
      */
     function getName()
@@ -61,16 +67,14 @@ class Notification_Listener_mobile extends Notification_Listener_status {
      * Outputs the status line if there are any messages on the 'mobile'
      * message stack.
      *
-     * @param array &$messageStack  The stack of messages.
-     * @param array $options        An array of options. Options: 'nospace'
+     * @access public
+     *
+     * @param array &$messageStack     The stack of messages.
+     * @param optional array $options  An array of options.
+     *                                 Options: 'nospace'
      */
     function notify(&$messageStack, $options = array())
     {
-        if (!$this->_mobile) {
-            parent::Notification_Listener_status();
-            return parent::notify($messageStack, $options);
-        }
-
         if (count($messageStack)) {
             while ($message = array_shift($messageStack)) {
                 $this->getMessage($message);
@@ -83,15 +87,12 @@ class Notification_Listener_mobile extends Notification_Listener_status {
     /**
      * Outputs one message.
      *
+     * @access public
+     *
      * @param array $message  One message hash from the stack.
      */
     function getMessage($message)
     {
-        if (!$this->_mobile) {
-            parent::Notification_Listener_status();
-            return parent::getMessage($message);
-        }
-
         $event = $this->getEvent($message);
         $this->_mobile->add(new Horde_Mobile_text(sprintf(_("%s: %s"), $this->_handles[$message['type']], strip_tags($event->getMessage()))));
     }
