@@ -21,35 +21,28 @@ define('PERMS_ALL', PERMS_SHOW | PERMS_READ | PERMS_EDIT | PERMS_DELETE);
 /**
  * The Perms:: class provides the Horde permissions system.
  *
- * $Horde: framework/Perms/Perms.php,v 1.80.10.10 2007/01/02 13:54:34 jan Exp $
+ * $Horde: framework/Perms/Perms.php,v 1.80.10.1 2005/01/03 12:19:10 jan Exp $
  *
- * Copyright 2001-2007 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2004-2007 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2004-2005 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jan Schneider <jan@horde.org>
+ * @version $Revision: 1.80.10.1 $
  * @since   Horde 2.1
  * @package Horde_Perms
  */
 class Perms {
 
-    /**
-     * Caches information about application permissions.
-     *
-     * @var array
-     */
-    var $_applicationPermissions;
-
     /**
      * Returns the available permissions for a given level.
      *
      * @param string $name  The permission's name.
      *
-     * @return array  An array of available permissions and their titles or
-     *                false if not sub permissions exist for this level.
+     * @return array  An array of available permissions and their titles.
      */
     function getAvailable($name)
     {
@@ -59,14 +52,12 @@ class Perms {
             /* No name passed, so top level permissions are requested. These
              * can only be applications. */
             $apps = $registry->listApps(array('notoolbar', 'active', 'hidden'), true);
-            foreach (array_keys($apps) as $app) {
-                $apps[$app] = $registry->get('name', $app) . ' (' . $app . ')';
-            }
             asort($apps);
             return $apps;
         } else {
-            /* Name has been passed, explode the name to get all the levels in
-             * permission being requisted, with the app as the first level. */
+            /* Name has been passed, explode the name to get all the
+             * levels in permission being requisted, with the app as
+             * the first level. */
             $levels = array();
             $levels = explode(':', $name);
 
@@ -76,25 +67,21 @@ class Perms {
             /* Return empty if no app defined API method for providing
              * permission information. */
             if (!$registry->hasMethod('perms', $app)) {
-                return false;
+                return '';
             }
 
-            /* Call the app's permission function to return the permissions
-             * specific to this app. */
-            $perms = $this->getApplicationPermissions($app);
-            if (is_a($perms, 'PEAR_Error')) {
-                return $perms;
-            }
+            /* Call the app's permission function to return the
+             * permissions specific to this app. */
+            $perms = $registry->callByPackage($app, 'perms');
 
             require_once 'Horde/Array.php';
-            /* Get the part of the app's permissions based on the permission
-             * name requested. */
+            /* Get the part of the app's permissions based on the
+             * permission name requested. */
             $children = Horde_Array::getElement($perms['tree'], $levels);
-            if ($children === false ||
-                !is_array($children) ||
-                !count($children)) {
-                /* No array of children available for this permission name. */
-                return false;
+            if ($children === false || !is_array($children)) {
+                /* No array of children available for this permission
+                 * name. */
+                return $children;
             }
 
             $perms_list = array();
@@ -106,8 +93,10 @@ class Perms {
     }
 
     /**
-     * Returns the short name of an object, the last portion of the full name.
+     * Returns the short name of an object, the last portion of the full
+     * name.
      *
+     * @access public
      * @static
      *
      * @param string $name  The name of the object.
@@ -119,8 +108,7 @@ class Perms {
         /* If there are several components to the name, explode and
          * get the last one, otherwise just return the name. */
         if (strpos($name, ':') !== false) {
-            $tmp = explode(':', $name);
-            return array_pop($tmp);
+            return array_pop(explode(':', $name));
         } else {
             return $name;
         }
@@ -140,42 +128,24 @@ class Perms {
 
         $levels = explode(':', $name);
         if (count($levels) == 1) {
-            return $registry->get('name', $name) . ' (' . $name . ')';
+            return $name;
         }
         $perm = array_pop($levels);
 
         /* First level is always app. */
         $app = $levels[0];
 
-        /* Return empty if no app defined API method for providing permission
-         * information. */
+        /* Return empty if no app defined API method for providing
+         * permission information. */
         if (!$registry->hasMethod('perms', $app)) {
             return Perms::getShortName($name);
         }
 
-        $app_perms = $this->getApplicationPermissions($app);
+        /* Call the app's permission function to return the
+         * permissions specific to this app. */
+        $perms = $registry->callByPackage($app, 'perms');
 
-        return isset($app_perms['title'][$name])
-            ? $app_perms['title'][$name] . ' (' . DataTree::getShortName($name) . ')'
-            : DataTree::getShortName($name);
-    }
-
-    /**
-     * Returns information about permissions implemented by an application.
-     *
-     * @since Horde 3.1
-     *
-     * @param string $app  An application name.
-     *
-     * @return array  Hash with permissions information.
-     */
-    function getApplicationPermissions($app)
-    {
-        if (!isset($this->_applicationPermissions[$app])) {
-            $this->_applicationPermissions[$app] = $GLOBALS['registry']->callByPackage($app, 'perms');
-        }
-
-        return $this->_applicationPermissions[$app];
+        return isset($perms['title'][$name]) ? $perms['title'][$name] : $name;
     }
 
     /**
@@ -271,7 +241,7 @@ class Perms {
      * @param string  $permission  The permission to check.
      * @param string  $user        The user to check for.
      * @param integer $perm        The permission level needed for access.
-     * @param string  $creator     The creator of the event
+     * @param string $creator      The creator of the event
      *
      * @return boolean  True if the user has the specified permissions.
      */
@@ -364,24 +334,22 @@ class Perms {
      *                        perms driver ($driver).  The code is
      *                        dynamically included.
      *
-     * @return Perms|boolean  The newly created concrete Perms instance, or
-     *                        false on an error.
+     * @return Perms|bool  The newly created concrete Perms instance, or
+     *                     false on an error.
      */
     function &factory($driver = null)
     {
         if (is_null($driver)) {
-            $perms = &new Perms();
-        } else {
-            include_once 'Horde/Perms/' . $driver . '.php';
-            $class = 'Perms_' . $driver;
-            if (class_exists($class)) {
-                $perms = &new $class();
-            } else {
-                $perms = false;
-            }
+            return $perms = &new Perms();
         }
 
-        return $perms;
+        include_once 'Horde/Perms/' . $driver . '.php';
+        $class = 'Perms_' . $driver;
+        if (class_exists($class)) {
+            return $perms = &new $class();
+        } else {
+            return false;
+        }
     }
 
     /**
@@ -391,7 +359,7 @@ class Perms {
      *
      * This method must be invoked as: $var = &Perms::singleton()
      *
-     * @return Perms|boolean  The concrete Perm reference, or false on error.
+     * @return Perms|bool  The concrete Perm reference, or false on an error.
      */
     function &singleton()
     {
