@@ -3,7 +3,7 @@
  * Class for auto-generating the preferences user interface and
  * processing the forms.
  *
- * $Horde: framework/Prefs/Prefs/UI.php,v 1.63.2.10 2005/09/27 16:24:26 selsky Exp $
+ * $Horde: framework/Prefs/Prefs/UI.php,v 1.63.2.4 2005/03/26 16:11:37 chuck Exp $
  *
  * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -19,6 +19,8 @@ class Prefs_UI {
     /**
      * Determine whether or not a preferences group is editable.
      *
+     * @access public
+     *
      * @param string $group  The preferences group to check.
      *
      * @return boolean  Whether or not the group is editable.
@@ -167,7 +169,9 @@ class Prefs_UI {
      * Generate the UI for the preferences interface, either for a
      * specific group, or the group selection interface.
      *
-     * @param string $group  The group to generate the UI for.
+     * @access public
+     *
+     * @param optional string $group  The group to generate the UI for.
      */
     function generateUI($group = null)
     {
@@ -187,12 +191,6 @@ class Prefs_UI {
             array_unshift($GLOBALS['language_options'], _("Default"));
         }
 
-        /* If there's only one prefGroup, just show it. */
-        if (empty($group) && count($prefGroups) == 1) {
-            $group = array_keys($prefGroups);
-            $group = array_pop($group);
-        }
-
         if (!empty($group) && Prefs_UI::groupIsEditable($group)) {
             foreach ($prefGroups[$group]['members'] as $pref) {
                 if (!$prefs->isLocked($pref)) {
@@ -242,7 +240,9 @@ class Prefs_UI {
      * Generates the the full header of a preference screen including
      * menu and navigation bars.
      *
-     * @param string $group  The group to generate the header for.
+     * @access public
+     *
+     * @param optional string $group  The group to generate the header for.
      */
     function generateHeader($group = null)
     {
@@ -294,20 +294,16 @@ class Prefs_UI {
          * applications. */
         require $registry->get('templates', 'horde') . '/prefs/app.inc';
 
-        /* If there's only one prefGroup, just show it. */
-        if (empty($group) && count($prefGroups) == 1) {
-            $group = array_keys($prefGroups);
-            $group = array_pop($group);
-        }
-
         if (!empty($group) && Prefs_UI::groupIsEditable($group)) {
             require $registry->get('templates', 'horde') . '/prefs/begin.inc';
         }
     }
 
     /**
-     * Generate the content of the title bar navigation cell (previous | next
-     * option group).
+     * Generate the content of the title bar navigation cell (previous
+     * | next option group).
+     *
+     * @access public
      *
      * @param          string $group        Current option group.
      * @param optional string $attributes   The optional <td> attributes.
