@@ -7,7 +7,7 @@ require_once 'Horde/Prefs/ldap.php';
  * Prefs_ldap LDAP authentication object, and simply provides parameters to it
  * based on the global Kolab configuration.
  *
- * $Horde: framework/Prefs/Prefs/kolab.php,v 1.1.10.1 2005/01/03 12:19:11 jan Exp $
+ * $Horde: framework/Prefs/Prefs/kolab.php,v 1.1.10.2 2005/01/31 14:45:35 stuart Exp $
  *
  * Copyright 2004-2005 Stuart Binge <s.binge@codefusion.co.za>
  *
@@ -15,7 +15,7 @@ require_once 'Horde/Prefs/ldap.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Stuart Binge <s.binge@codefusion.co.za>
- * @version $Revision: 1.1.10.1 $
+ * @version $Revision: 1.1.10.2 $
  * @since   Horde 1.3
  * @package Horde_Prefs
  */
@@ -42,7 +42,7 @@ class Prefs_kolab extends Prefs_ldap {
         $params['basedn'] = $GLOBALS['conf']['kolab']['ldap']['basedn'];
         $params['rootdn'] = $GLOBALS['conf']['kolab']['ldap']['binddn'];
         $params['password'] = $GLOBALS['conf']['kolab']['ldap']['bindpw'];
-        $params['uid'] = 'mail';
+        $params['uid'] = array('mail', 'uid');
 
         parent::Prefs_ldap($user, $password, $scope, $params, $caching);
     }
