@@ -3,14 +3,15 @@
  * The Horde_RPC_soap class provides an SOAP implementation of the
  * Horde RPC system.
  *
- * $Horde: framework/RPC/RPC/soap.php,v 1.13.10.7 2006/01/01 21:28:33 jan Exp $
+ * $Horde: framework/RPC/RPC/soap.php,v 1.13.10.1 2005/01/03 12:19:12 jan Exp $
  *
- * Copyright 2003-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2005 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
+ * @version $Revision: 1.13.10.1 $
  * @since   Horde 3.0
  * @package Horde_RPC
  */
@@ -18,15 +19,13 @@ class Horde_RPC_soap extends Horde_RPC {
 
     /**
      * Resource handler for the RPC server.
-     *
-     * @var object
+     * @var object $_server
      */
     var $_server;
 
     /**
      * Hash holding all methods' signatures.
-     *
-     * @var array
+     * @var array $__dispatch_map
      */
     var $__dispatch_map = array();
 
@@ -34,6 +33,7 @@ class Horde_RPC_soap extends Horde_RPC {
      * SOAP server constructor
      *
      * @access private
+     * @return object   An RPC server instance
      */
     function Horde_RPC_soap($params = null)
     {
@@ -114,7 +114,7 @@ class Horde_RPC_soap extends Horde_RPC {
         $method = str_replace('.', '/', $method);
 
         if (!$registry->hasMethod($method)) {
-            return sprintf(_("Method \"%s\" is not defined"), $method);
+            return sprintf(_("Method '%s' is not defined"), $method);
         }
 
         $this->_server->bindWSDL(Horde::url($registry->get('webroot', 'horde') . '/rpc.php?wsdl', true, false));
@@ -125,9 +125,9 @@ class Horde_RPC_soap extends Horde_RPC {
      * Takes an RPC request and returns the result.
      *
      * @param string  The raw request string.
-     * @param string  String specifying what kind of data to return. Defaults
-     *                to SOAP request. Possible other values: "wdsl" and
-     *                "disco".
+     * @param string  (optional) String specifying what kind of data to
+     *                return. Defaults to SOAP request. Possible other values:
+     *                "wdsl" and "disco".
      *
      * @return string  The XML encoded response from the server.
      */
@@ -161,10 +161,10 @@ class Horde_RPC_soap extends Horde_RPC {
      *
      * This statically called method is actually the SOAP client.
      *
-     * @param string $url     The path to the SOAP server on the called host.
-     * @param string $method  The method to call.
-     * @param array $params   A hash containing any necessary parameters for
-     *                        the method call.
+     * @param string $url       The path to the SOAP server on the called host.
+     * @param string $method    The method to call.
+     * @param array $params     (optional) A hash containing any necessary
+     *                          parameters for the method call.
      * @param $options  Optional associative array of parameters which can be:
      *                  user                - Basic Auth username
      *                  pass                - Basic Auth password
