@@ -11,7 +11,7 @@ define('HORDE_SESSION_READONLY', 2);
  * between Horde applications and keeping track of application
  * configuration information.
  *
- * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.11.2.2 2005/10/27 11:08:41 jan Exp $
+ * $Horde: framework/Horde/Horde/Registry.php,v 1.243.2.4 2005/02/14 18:06:12 jan Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -31,14 +31,14 @@ class Registry {
     /**
      * Hash storing all of the known services and callbacks.
      *
-     * @var array
+     * @var array $_apiCache
      */
     var $_apiCache = array();
 
     /**
      * Hash storing all known data types.
      *
-     * @var array
+     * @var array $_typeCache
      */
     var $_typeCache = array();
 
@@ -46,42 +46,42 @@ class Registry {
      * Hash storing all of the registered interfaces that applications
      * provide.
      *
-     * @var array
+     * @var array $_interfaces
      */
     var $_interfaces = array();
 
     /**
      * Hash storing information on each registry-aware application.
      *
-     * @var array
+     * @var array $applications
      */
     var $applications = array();
 
     /**
      * Stack of in-use applications.
      *
-     * @var array
+     * @var array $_appStack
      */
     var $_appStack = array();
 
     /**
      * Quick pointer to the current application.
      *
-     * @var string
+     * @var $_currentApp
      */
     var $_currentApp = null;
 
     /**
      * Cache of $prefs objects
      *
-     * @var array
+     * @var array $_prefsCache
      */
     var $_prefsCache = array();
 
     /**
      * Cache of application configurations.
      *
-     * @var array
+     * @var array $_confCache
      */
     var $_confCache = array();
 
@@ -91,9 +91,9 @@ class Registry {
      *
      * This method must be invoked as: $registry = &Registry::singleton()
      *
-     * @param integer $session_flags  Any session flags.
+     * @param optional integer $session_flags  Any session flags.
      *
-     * @return Registry  The Horde Registry instance.
+     * @return object Registry  The Horde Registry instance.
      */
     function &singleton($session_flags = 0)
     {
@@ -110,7 +110,7 @@ class Registry {
      * Create a new registry instance. Should never be called except
      * by &Registry::singleton().
      *
-     * @param integer $session_flags  Any session flags.
+     * @param optional integer $session_flags  Any session flags.
      *
      * @access private
      */
@@ -201,11 +201,14 @@ class Registry {
      *
      * @since Horde 2.2
      *
-     * @param array   $filter      An array of the statuses that should be
-     *                             returned. Defaults to non-hidden.
-     * @param boolean $assoc       Associative array with app names as keys.
-     * @param integer $permission  The permission level to check for in the
-     *                             list. Defaults to PERMS_SHOW.
+     * @access public
+     *
+     * @param array   $filter      (optional) An array of the statuses that
+     *                             should be returned. Defaults to non-hidden.
+     * @param boolean $assoc       (optional) Associative array with app names
+     *                             as keys.
+     * @param integer $permission  (optional) The permission level to check
+     *                             for in the list. Defaults to PERMS_SHOW.
      *
      * @return array  List of apps registered with Horde. If no
      *                applications are defined returns an empty array.
@@ -230,6 +233,8 @@ class Registry {
     /**
      * Returns all available registry APIs.
      *
+     * @access public
+     *
      * @return array  The API list.
      */
     function listAPIs()
@@ -248,8 +253,10 @@ class Registry {
      * Returns all of the available registry methods, or alternately
      * only those for a specified API.
      *
-     * @param string $api  Defines the API for which the methods shall be
-     *                     returned.
+     * @access public
+     *
+     * @param optional string $api  Defines the API for which the methods
+     *                              shall be returned.
      *
      * @return array  The method list.
      */
@@ -291,6 +298,8 @@ class Registry {
     /**
      * Returns all of the available registry data types.
      *
+     * @access public
+     *
      * @return array  The data type list.
      */
     function listTypes()
@@ -302,6 +311,8 @@ class Registry {
     /**
      * Returns a method's signature.
      *
+     * @access public
+     *
      * @param string $method  The full name of the method to check for.
      *
      * @return array  A two dimensional array. The first element contains an
@@ -324,7 +335,10 @@ class Registry {
     }
 
     /**
-     * Determine if an interface is implemented by an active application.
+     * Determine if an interface is implemented by an active
+     * application.
+     *
+     * @access public
      *
      * @param string $interface  The interface to check for.
      *
@@ -341,8 +355,10 @@ class Registry {
     /**
      * Determine if a method has been registered with the registry.
      *
-     * @param string $method  The full name of the method to check for.
-     * @param string $app     Only check this application.
+     * @access public
+     *
+     * @param string  $method      The full name of the method to check for.
+     * @param string  $app         (optional) Only check this application.
      *
      * @return mixed  The application implementing $method if we have it,
      *                false if the method doesn't exist.
@@ -373,8 +389,10 @@ class Registry {
      * parameter. $method is a string consisting of
      * "packagetype/methodname".
      *
-     * @param string $method  The method to call.
-     * @param array $args     Arguments to the method.
+     * @access public
+     *
+     * @param string $method        The method to call.
+     * @param optional array $args  Arguments to the method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -397,9 +415,11 @@ class Registry {
     /**
      * Output the hook corresponding to the specific package named.
      *
-     * @param string $app   The application being called.
-     * @param string $call  The method to call.
-     * @param array $args   Arguments to the method.
+     * @access public
+     *
+     * @param string $app           The application being called.
+     * @param string $call          The method to call.
+     * @param optional array $args  Arguments to the method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -447,9 +467,12 @@ class Registry {
      * parameter. $method is a string consisting of
      * "packagetype/methodname".
      *
-     * @param string $method  The method to link to.
-     * @param array $args     Arguments to the method.
-     * @param mixed $extra    Extra, non-standard arguments to the method.
+     * @access public
+     *
+     * @param string $method         The method to link to.
+     * @param optional array $args   Arguments to the method.
+     * @param optional mixed $extra  Extra, non-standard arguments to the
+     *                               method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -472,10 +495,13 @@ class Registry {
     /**
      * Output the hook corresponding to the specific package named.
      *
-     * @param string $app   The application being called.
-     * @param string $call  The method to link to.
-     * @param array $args   Arguments to the method.
-     * @param mixed $extra  Extra, non-standard arguments to the method.
+     * @access public
+     *
+     * @param string $app            The application being called.
+     * @param string $call           The method to link to.
+     * @param optional array $args   Arguments to the method.
+     * @param optional mixed $extra  Extra, non-standard arguments to the
+     *                               method.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -535,11 +561,13 @@ class Registry {
     }
 
     /**
-     * Replace any %application% strings with the filesystem path to the
-     * application.
+     * Replace any %application% strings with the filesystem path to
+     * the application.
      *
-     * @param string $path  The application string.
-     * @param string $app   The application being called.
+     * @access public
+     *
+     * @param string $path          The application string.
+     * @param optional string $app  The application being called.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -551,17 +579,20 @@ class Registry {
         }
 
         if (!isset($this->applications[$app])) {
-            return PEAR::raiseError(sprintf(_("\"%s\" is not configured in the Horde Registry."), $app));
+            return PEAR::raiseError(sprintf(_("'%s' is not configured in the Horde Registry."), $app));
         }
 
         return str_replace('%application%', $this->applications[$app]['fileroot'], $path);
     }
 
     /**
-     * Replace any %application% strings with the web path to the application.
+     * Replace any %application% strings with the web path to the
+     * application.
      *
-     * @param string $path  The application string.
-     * @param string $app   The application being called.
+     * @access public
+     *
+     * @param string $path          The application string.
+     * @param optional string $app  The application being called.
      *
      * @return  TODO
      *          Returns PEAR_Error on error.
@@ -583,12 +614,14 @@ class Registry {
      * pushApp() also reads the application's configuration file and
      * sets up its global $conf hash.
      *
+     * @access public
+     *
      * @param string  $app         The name of the application to push.
-     * @param boolean $checkPerms  Make sure that the current user has
-     *                             permissions to the application being loaded
-     *                             Defaults to true. Should ONLY be disabled by
-     *                             system scripts (cron jobs, etc.) and scripts
-     *                             that handle login.
+     * @param boolean $checkPerms  (optional) Make sure that the current user
+     *                             has permissions to the application being
+     *                             loaded. Defaults to true. Should ONLY
+     *                             be disabled by system scripts (cron jobs,
+     *                             etc.) and scripts that handle login.
      *
      * @return boolean  Whether or not the _appStack was modified.
      *                  Return PEAR_Error on error.
@@ -641,15 +674,18 @@ class Registry {
 
         /* Once we know everything succeeded and is in a consistent
          * state again, push the new application onto the stack. */
-        $this->_appStack[] = $app;
+        array_push($this->_appStack, $app);
         $this->_currentApp = $app;
 
         return true;
     }
 
     /**
-     * Remove the current app from the application stack, setting the current
-     * app to whichever app was current before this one took over.
+     * Remove the current app from the application stack, setting the
+     * current app to whichever app was current before this one took
+     * over.
+     *
+     * @access public
      *
      * @return string  The name of the application that was popped.
      */
@@ -676,8 +712,10 @@ class Registry {
     }
 
     /**
-     * Return the current application - the app at the top of the application
-     * stack.
+     * Return the current application - the app at the top of the
+     * application stack.
+     *
+     * @access public
      *
      * @return string  The current application.
      */
@@ -689,19 +727,22 @@ class Registry {
     /**
      * Check permissions on an application.
      *
+     * @access public
+     *
      * @return boolean  Whether or not access is allowed.
      */
     function hasPermission($app, $permission = PERMS_READ)
     {
-        return Auth::isAdmin() ||
-            ($GLOBALS['perms']->exists($app)
-             ? $GLOBALS['perms']->hasPermission($app, Auth::getAuth(), $permission)
-             : (bool)Auth::getAuth());
+        return Auth::isAdmin() || ($GLOBALS['perms']->exists($app) ?
+                                   $GLOBALS['perms']->hasPermission($app, Auth::getAuth(), $permission) :
+                                   (bool)Auth::getAuth());
     }
 
     /**
-     * Reads the configuration values for the given application and imports
-     * them into the global $conf variable.
+     * Reads the configuration values for the given application and
+     * imports them into the global $conf variable.
+     *
+     * @access public
      *
      * @param string $app  The name of the application.
      *
@@ -761,8 +802,10 @@ class Registry {
     }
 
     /**
-     * Loads the preferences for the current user for the current application
-     * and imports them into the global $prefs variable.
+     * Loads the preferences for the current user for the current
+     * application and imports them into the global $prefs variable.
+     *
+     * @access public
      *
      * @param string $app  The name of the application.
      */
@@ -808,8 +851,10 @@ class Registry {
      * After unloading, if there is an application on the app stack to
      * load preferences from, then we reload a fresh set.
      *
-     * @param string $app  The application to unload prefrences for. If null,
-     *                     ALL preferences are reset.
+     * @access public
+     *
+     * @param string $app  (optional) The application to unload prefrences for.
+     *                     If null, ALL preferences are reset.
      */
     function unloadPrefs($app = null)
     {
@@ -834,8 +879,10 @@ class Registry {
      * Horde-wide value is used instead. If that is not present, we
      * return null.
      *
-     * @param string $parameter  The configuration value to retrieve.
-     * @param string $app        The application to get the value for.
+     * @access public
+     *
+     * @param string $parameter     The configuration value to retrieve.
+     * @param optional string $app  The application to get the value for.
      *
      * @return string  The requested parameter, or null if it is not set.
      */
@@ -863,12 +910,14 @@ class Registry {
     }
 
     /**
-     * Function to work out an application's graphics URI, taking into account
-     * any themes directories that may be set up.
+     * Function to work out an application's graphics URI, taking into
+     * account any themes directories that may be set up.
      *
-     * @param string $app  The application for which to get the image
-     *                     directory. If blank will default to current
-     *                     application.
+     * @access public
+     *
+     * @param optional string $app  The application for which to get the
+     *                              image directory. If blank will default
+     *                              to current application.
      *
      * @return string  The image directory uri path.
      */
@@ -886,15 +935,11 @@ class Registry {
         /* This is the default location for the graphics. */
         $img_dir[$app] = $this->get('themesuri', $app) . '/graphics';
 
-        static $theme_icons;
-
         /* Figure out if this is going to be overridden by any theme
          * settings. */
-        if (isset($GLOBALS['prefs']) &&
-            ($theme = $GLOBALS['prefs']->getValue('theme')) &&
-            (isset($theme_icons) ||
-             ((@include $this->get('themesfs', 'horde') . '/' . $theme . '/info.php') &&
-              isset($theme_icons))) &&
+        if (isset($GLOBALS['prefs']) && ($theme = $GLOBALS['prefs']->getValue('theme')) &&
+            (@include $this->get('themesfs', 'horde') . '/' . $theme . '/info.php') &&
+            isset($theme_icons) &&
             in_array($app, $theme_icons)) {
             $img_dir[$app] = $this->get('themesuri', $app) . '/' . $theme . '/graphics';
         }
@@ -916,10 +961,13 @@ class Registry {
     }
 
     /**
-     * Query the initial page for an application - the webroot, if there is no
-     * initial_page set, and the initial_page, if it is set.
+     * Query the initial page for an application - the webroot, if
+     * there is no initial_page set, and the initial_page, if it is
+     * set.
      *
-     * @param string $app  The name of the application.
+     * @access public
+     *
+     * @param optional string $app  The name of the application.
      *
      * @return string  URL pointing to the inital page of the application.
      *                 Returns PEAR_Error on error.
@@ -931,7 +979,7 @@ class Registry {
         }
 
         if (!isset($this->applications[$app])) {
-            return PEAR::raiseError(sprintf(_("\"%s\" is not configured in the Horde Registry."), $app));
+            return PEAR::raiseError(sprintf(_("'%s' is not configured in the Horde Registry."), $app));
         }
         return $this->applications[$app]['webroot'] . '/' . (isset($this->applications[$app]['initial_page']) ? $this->applications[$app]['initial_page'] : '');
     }
