@@ -6,14 +6,15 @@
  * The Secret:: functions use the Horde Cipher:: class if mcrypt is not
  * available.
  *
- * $Horde: framework/Secret/Secret.php,v 1.45.10.12 2008/08/08 04:39:37 chuck Exp $
+ * $Horde: framework/Secret/Secret.php,v 1.45.10.1 2005/01/03 12:19:13 jan Exp $
  *
- * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
+ * @version $Revision: 1.45.10.1 $
  * @since   Horde 1.3
  * @package Horde_Secret
  */
@@ -22,6 +23,8 @@ class Secret {
     /**
      * Take a small piece of data and encrypt it with a key.
      *
+     * @access public
+     *
      * @param string $key      The key to use for encryption.
      * @param string $message  The plaintext message.
      *
@@ -29,22 +32,37 @@ class Secret {
      */
     function write($key, $message)
     {
-        if (!strlen($key)) {
-            return false;
+        if (Util::extensionExists('mcrypt')) {
+            $td = @mcrypt_module_open(MCRYPT_GOST, '', MCRYPT_MODE_ECB, '');
+            if ($td) {
+                $iv = @mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
+                @mcrypt_generic_init($td, $key, $iv);
+                $encrypted_data = @mcrypt_generic($td, $message);
+                @mcrypt_generic_deinit($td);
+
+                return $encrypted_data;
+            }
         }
 
-        $ret = Secret::_getMcryptData($key, $message, 'encrypt');
-        if ($ret !== false) {
-            return $ret;
+        static $cipherCache = array();
+        $cacheIdx = md5($key);
+
+        if (!isset($cipherCache[$cacheIdx])) {
+            require_once 'Horde/Cipher.php';
+
+            $cipherCache[$cacheIdx] = &Horde_Cipher::factory('blowfish');
+            $cipherCache[$cacheIdx]->setBlockMode('ofb64');
+            $cipherCache[$cacheIdx]->setKey($key);
         }
 
-        $ptr = Secret::_getCipherOb($key);
-        return $ptr->encrypt($message);
+        return $cipherCache[$cacheIdx]->encrypt($message);
     }
 
     /**
      * Decrypt a message encrypted with Secret::write().
      *
+     * @access public
+     *
      * @param string $key      The key to use for decryption.
      * @param string $message  The ciphertext message.
      *
@@ -52,54 +70,31 @@ class Secret {
      */
     function read($key, $ciphertext)
     {
-        $ret = Secret::_getMcryptData($key, $ciphertext, 'decrypt');
-        if ($ret !== false) {
-            return rtrim($ret, "\0");
-        }
-
-        $ptr = Secret::_getCipherOb($key);
-        return $ptr->decrypt($ciphertext);
-    }
-
-    /**
-     * @access private
-     */
-    function _getMcryptData($key, $text, $type)
-    {
-        $ret = false;
-
         if (Util::extensionExists('mcrypt')) {
-            $old_error = error_reporting(0);
-            $td = mcrypt_module_open(MCRYPT_GOST, '', MCRYPT_MODE_ECB, '');
+            $td = @mcrypt_module_open(MCRYPT_GOST, '', MCRYPT_MODE_ECB, '');
             if ($td) {
-                $iv = mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
-                mcrypt_generic_init($td, $key, $iv);
-                $ret = ($type == 'encrypt') ? mcrypt_generic($td, $text) : mdecrypt_generic($td, $text);
-                mcrypt_generic_deinit($td);
+                $iv = @mcrypt_create_iv(mcrypt_enc_get_iv_size($td), MCRYPT_RAND);
+                @mcrypt_generic_init($td, $key, $iv);
+                $decrypted_data = @mdecrypt_generic($td, $ciphertext);
+                @mcrypt_generic_deinit($td);
+
+                // Strip padding characters.
+                return rtrim($decrypted_data, "\0");
             }
-            error_reporting($old_error);
         }
 
-        return $ret;
-    }
-
-    /**
-     * @access private
-     */
-    function _getCipherOb($key)
-    {
-        static $cache = array();
+        static $cipherCache;
         $cacheIdx = md5($key);
 
-        if (!isset($cache[$cacheIdx])) {
+        if (!is_array($cipherCache) || !isset($cipherCache[$cacheIdx])) {
             require_once 'Horde/Cipher.php';
 
-            $cache[$cacheIdx] = &Horde_Cipher::factory('blowfish');
-            $cache[$cacheIdx]->setBlockMode('ofb64');
-            $cache[$cacheIdx]->setKey($key);
+            $cipherCache[$cacheIdx] = &Horde_Cipher::factory('blowfish');
+            $cipherCache[$cacheIdx]->setBlockMode('ofb64');
+            $cipherCache[$cacheIdx]->setKey($key);
         }
 
-        return $cache[$cacheIdx];
+        return $cipherCache[$cacheIdx]->decrypt($ciphertext);
     }
 
     /**
@@ -107,7 +102,9 @@ class Secret {
      * md5 string and storing it in a cookie if the user has cookies
      * enabled, or munging some known values if they don't.
      *
-     * @param string $keyname  The name of the key to set.
+     * @access public
+     *
+     * @param optional string $keyname  The name of the key to set.
      *
      * @return string  The secret key that has been generated.
      */
@@ -121,11 +118,11 @@ class Secret {
             } else {
                 $key = md5(mt_rand());
                 $_COOKIE[$keyname . '_key'] = $key;
-                Secret::_setCookie($keyname, $key);
+                @setcookie($keyname . '_key', $key, $conf['session']['timeout'], $conf['cookie']['path'], $conf['cookie']['domain'], $conf['use_ssl'] == 1 ? 1 : 0);
             }
         } else {
             $key = session_id();
-            Secret::_setCookie($keyname, $key);
+            @setcookie($keyname . '_key', $key, $conf['session']['timeout'], $conf['cookie']['path'], $conf['cookie']['domain'], $conf['use_ssl'] == 1 ? 1 : 0);
         }
 
         return $key;
@@ -136,7 +133,9 @@ class Secret {
      * isn't there, assume we are using a munged version of a known
      * base value.
      *
-     * @param string $keyname  The name of the key to get.
+     * @access public
+     *
+     * @param optional string $keyname  The name of the key to get.
      *
      * @return string  The secret key.
      */
@@ -148,48 +147,13 @@ class Secret {
             if (isset($_COOKIE[$keyname . '_key'])) {
                 $keycache[$keyname] = $_COOKIE[$keyname . '_key'];
             } else {
+                global $conf;
                 $keycache[$keyname] = session_id();
-                Secret::_setCookie($keyname, $keycache[$keyname]);
+                @setcookie($keyname . '_key', $keycache[$keyname], $conf['session']['timeout'], $conf['cookie']['path'], $conf['cookie']['domain'], $conf['use_ssl'] == 1 ? 1 : 0);
             }
         }
 
         return $keycache[$keyname];
     }
 
-    /**
-     * @access private
-     */
-    function _setCookie($keyname, $key)
-    {
-        global $conf;
-
-        $old_error = error_reporting(0);
-        setcookie(
-            $keyname . '_key',
-            $key,
-            $conf['session']['timeout'] ? time() + $conf['session']['timeout'] : 0,
-            $conf['cookie']['path'],
-            $conf['cookie']['domain'],
-            $conf['use_ssl'] == 1 ? 1 : 0
-        );
-        error_reporting($old_error);
-    }
-
-    /**
-     * Clears a secret key entry from the current cookie.
-     *
-     * @param string $keyname  The name of the key to clear.
-     *
-     * @return boolean  True if key existed, false if not.
-     */
-    function clearKey($keyname = 'generic')
-    {
-        if (isset($_COOKIE[$GLOBALS['conf']['session']['name']]) &&
-            isset($_COOKIE[$keyname . '_key'])) {
-            unset($_COOKIE[$keyname . '_key']);
-            return true;
-        }
-        return false;
-    }
-
 }
