@@ -5,9 +5,9 @@
  *
  * No additional configuration parameters needed.
  *
- * $Horde: framework/SessionHandler/SessionHandler/dbm.php,v 1.9.12.7 2006/01/01 21:28:34 jan Exp $
+ * $Horde: framework/SessionHandler/SessionHandler/dbm.php,v 1.9.12.2 2005/02/01 19:07:15 chuck Exp $
  *
- * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -21,17 +21,23 @@ class SessionHandler_dbm extends SessionHandler {
     /**
      * Our pointer to the DBM file, if open.
      *
-     * @var resource
+     * @var resource $_dbm
      */
     var $_dbm;
 
     /**
-     * Open the SessionHandler backend.
+     * Constructs a new DBM SessionHandler object.
      *
-     * @param string $save_path     The path to the session object.
-     * @param string $session_name  The name of the session.
+     * @access public
      *
-     * @return boolean  True on success, false otherwise.
+     * @param optional array $params  [Unused].
+     */
+    function SessionHandler_dbm($params = array())
+    {
+    }
+
+    /**
+     * TODO
      */
     function open($save_path, $session_name)
     {
@@ -40,9 +46,7 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * Close the SessionHandler backend.
-     *
-     * @return boolean  True on success, false otherwise.
+     * TODO
      */
     function close()
     {
@@ -50,12 +54,7 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * Read the data for a particular session identifier from the
-     * SessionHandler backend.
-     *
-     * @param string $id  The session identifier.
-     *
-     * @return string  The session data.
+     * TODO
      */
     function read($id)
     {
@@ -67,12 +66,7 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * Write session data to the SessionHandler backend.
-     *
-     * @param string $id            The session identifier.
-     * @param string $session_data  The session data.
-     *
-     * @return boolean  True on success, false otherwise.
+     * TODO
      */
     function write($id, $session_data)
     {
@@ -80,12 +74,7 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * Destroy the data for a particular session identifier in the
-     * SessionHandler backend.
-     *
-     * @param string $id  The session identifier.
-     *
-     * @return boolean  True on success, false otherwise.
+     * TODO
      */
     function destroy($id)
     {
@@ -98,13 +87,9 @@ class SessionHandler_dbm extends SessionHandler {
     }
 
     /**
-     * Garbage collect stale sessions from the SessionHandler backend.
-     *
-     * @param integer $maxlifetime  The maximum age of a session.
-     *
-     * @return boolean  True on success, false otherwise.
+     * TODO
      */
-    function gc($maxlifetime = 300)
+    function gc($maxlifetime = 300) 
     {
         $expired = time() - $maxlifetime;
         $id = dbmfirstkey($this->_dbm);
