@@ -1,14 +1,16 @@
 <?php
 
+require_once 'Horde/Util.php';
+
 $GLOBALS['_HORDE_STRING_CHARSET'] = 'iso-8859-1';
 
 /**
  * The String:: class provides static methods for charset and locale safe
  * string manipulation.
  *
- * $Horde: framework/Util/String.php,v 1.43.6.14 2007/01/02 13:54:47 jan Exp $
+ * $Horde: framework/Util/String.php,v 1.43.6.4 2005/01/31 20:47:24 jan Exp $
  *
- * Copyright 2003-2007 Jan Schneider <jan@horde.org>
+ * Copyright 2003-2005 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -19,26 +21,6 @@ $GLOBALS['_HORDE_STRING_CHARSET'] = 'iso-8859-1';
  */
 class String {
 
-    /**
-     * Caches the result of extension_loaded() calls.
-     *
-     * @param string $ext  The extension name.
-     *
-     * @return boolean  Is the extension loaded?
-     *
-     * @see Util::extensionExists()
-     */
-    function extensionExists($ext)
-    {
-        static $cache = array();
-
-        if (!isset($cache[$ext])) {
-            $cache[$ext] = extension_loaded($ext);
-        }
-
-        return $cache[$ext];
-    }
-
     /**
      * Sets a default charset that the String:: methods will use if none is
      * explicitely specified.
@@ -48,7 +30,7 @@ class String {
     function setDefaultCharset($charset)
     {
         $GLOBALS['_HORDE_STRING_CHARSET'] = $charset;
-        if (String::extensionExists('mbstring') &&
+        if (Util::extensionExists('mbstring') &&
             function_exists('mb_regex_encoding')) {
             @mb_regex_encoding($charset);
         }
@@ -62,16 +44,18 @@ class String {
      * The original string is returned if conversion failed or none
      * of the extensions were available.
      *
-     * @param mixed $input  The data to be converted. If $input is an an array,
-     *                      the array's values get converted recursively.
-     * @param string $from  The string's current charset.
-     * @param string $to    The charset to convert the string to. If not
-     *                      specified, the global variable
-     *                      $_HORDE_STRING_CHARSET will be used.
+     * @param mixed $input     The data to be converted. If $input is an an
+     *                         array, the array's values get converted
+     *                         recursively.
+     * @param string $from     The string's current charset.
+     * @param string $to       The charset to convert the string to. If not
+     *                         specified, the global variable
+     *                         $_HORDE_STRING_CHARSET will be used.
+     * @param bool $recursion  Internally used.
      *
      * @return string  The converted string.
      */
-    function convertCharset($input, $from, $to = null)
+    function convertCharset($input, $from, $to = null, $recursion = false)
     {
         /* Get the user's default character set if none passed in. */
         if (is_null($to)) {
@@ -79,8 +63,10 @@ class String {
         }
 
         /* If the from and to character sets are identical, return now. */
-        $from = String::lower($from);
-        $to = String::lower($to);
+        if (!$recursion) {
+            $from = String::lower($from);
+            $to = String::lower($to);
+        }
         if ($from == $to) {
             return $input;
         }
@@ -88,14 +74,14 @@ class String {
         if (is_array($input)) {
             $tmp = array();
             foreach ($input as $key => $val) {
-                $tmp[String::_convertCharset($key, $from, $to)] = String::convertCharset($val, $from, $to);
+                $tmp[String::convertCharset($key, $from, $to, true)] = String::convertCharset($val, $from, $to, true);
             }
             return $tmp;
         }
         if (is_object($input)) {
             $vars = get_object_vars($input);
             foreach ($vars as $key => $val) {
-                $input->$key = String::convertCharset($val, $from, $to);
+                $input->$key = String::convertCharset($val, $from, $to, true);
             }
             return $input;
         }
@@ -104,23 +90,7 @@ class String {
             return $input;
         }
 
-        return String::_convertCharset($input, $from, $to);
-    }
-
-    /**
-     * Internal function used to do charset conversion.
-     *
-     * @access private
-     *
-     * @param mixed $input  See String::convertCharset().
-     * @param string $from  See String::convertCharset().
-     * @param string $to    See String::convertCharset().
-     *
-     * @return string  The converted string.
-     */
-    function _convertCharset($input, $from, $to)
-    {
-        $output = '';
+        $output = false;
 
         /* Use utf8_[en|de]code() if possible. */
         $from_check = (($from == 'iso-8859-1') || ($from == 'us-ascii'));
@@ -134,25 +104,29 @@ class String {
         }
 
         /* First try iconv with transliteration. */
-        if (($from != 'utf7-imap') &&
-            ($to != 'utf7-imap') &&
-            String::extensionExists('iconv')) {
+        if ($from != 'utf7-imap' &&
+            $to != 'utf7-imap' &&
+            Util::extensionExists('iconv')) {
+            ini_set('track_errors', 1);
             /* We need to tack an extra character temporarily because
              * of a bug in iconv() if the last character is not a 7
              * bit ASCII character. */
-            ini_set('track_errors', 1);
             $output = @iconv($from, $to . '//TRANSLIT', $input . 'x');
-            $output = (isset($php_errormsg)) ? false :  String::substr($output, 0, -1, $to);
+            if (isset($php_errormsg)) {
+                $output = false;
+            } else {
+                $output = String::substr($output, 0, -1, $to);
+            }
             ini_restore('track_errors');
         }
 
         /* Next try mbstring. */
-        if (!$output && String::extensionExists('mbstring')) {
+        if (!$output && Util::extensionExists('mbstring')) {
             $output = @mb_convert_encoding($input, $to, $from);
         }
 
         /* At last try imap_utf7_[en|de]code if appropriate. */
-        if (!$output && String::extensionExists('imap')) {
+        if (!$output && Util::extensionExists('imap')) {
             if ($from_check && ($to == 'utf7-imap')) {
                 return @imap_utf7_encode($input);
             }
@@ -161,7 +135,7 @@ class String {
             }
         }
 
-        return (!$output) ? $input : $output;
+        return !$output ? $input : $output;
     }
 
     /**
@@ -181,7 +155,7 @@ class String {
 
         if ($locale) {
             /* The existence of mb_strtolower() depends on the platform. */
-            if (String::extensionExists('mbstring') &&
+            if (Util::extensionExists('mbstring') &&
                 function_exists('mb_strtolower')) {
                 if (is_null($charset)) {
                     $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
@@ -277,18 +251,17 @@ class String {
     /**
      * Returns part of a string.
      *
-     * @param string $string   The string to be converted.
-     * @param integer $start   The part's start position, zero based.
-     * @param integer $length  The part's length.
-     * @param string $charset  The charset to use when calculating the part's
-     *                         position and length, defaults to current
-     *                         charset.
+     * @param string $string  The string to be converted.
+     * @param int $start      The part's start position, zero based.
+     * @param int $length     The part's length.
+     * @param string $charset The charset to use when calculating the part's
+     *                        position and length, defaults to current charset.
      *
      * @return string  The string's part.
      */
     function substr($string, $start, $length = null, $charset = null)
     {
-        if (String::extensionExists('mbstring')) {
+        if (Util::extensionExists('mbstring')) {
             if (is_null($charset)) {
                 $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
             }
@@ -317,14 +290,10 @@ class String {
      */
     function length($string, $charset = null)
     {
-        if (is_null($charset)) {
-            $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
-        }
-        $charset = String::lower($charset);
-        if ($charset == 'utf-8' || $charset == 'utf8') {
-            return strlen(utf8_decode($string));
-        }
-        if (String::extensionExists('mbstring')) {
+        if (Util::extensionExists('mbstring')) {
+            if (is_null($charset)) {
+                $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
+            }
             $ret = @mb_strlen($string, $charset);
             if (!empty($ret)) {
                 return $ret;
@@ -339,16 +308,16 @@ class String {
      *
      * @param string $haystack  The string to search through.
      * @param string $needle    The string to search for.
-     * @param integer $offset   Allows to specify which character in haystack
+     * @param int $offset       Allows to specify which character in haystack
      *                          to start searching.
      * @param string $charset   The charset to use when searching for the
      *                          $needle string.
      *
-     * @return integer  The position of first occurrence.
+     * @return int  The position of first occurrence.
      */
     function pos($haystack, $needle, $offset = 0, $charset = null)
     {
-        if (String::extensionExists('mbstring')) {
+        if (Util::extensionExists('mbstring')) {
             if (is_null($charset)) {
                 $charset = $GLOBALS['_HORDE_STRING_CHARSET'];
             }
@@ -368,7 +337,7 @@ class String {
      * This method behaves exactly like str_pad but is multibyte safe.
      *
      * @param string $input    The string to be padded.
-     * @param integer $length  The length of the resulting string.
+     * @param int $length      The length of the resulting string.
      * @param string $pad      The string to pad the input string with. Must
      *                         be in the same charset like the input string.
      * @param const $type      The padding type. One of STR_PAD_LEFT,
@@ -421,14 +390,20 @@ class String {
      *
      * @todo Make multibyte-save.
      *
-     * @param string $text        String containing the text to wrap.
-     * @param integer $length     Wrap $text at this number of characters.
-     * @param string $break_char  Character(s) to use when breaking lines.
-     * @param string $charset     Character set to use when breaking lines.
-     * @param boolean $quote      Ignore lines that are wrapped with the '>'
-     *                            character (RFC 2646)? If true, we don't
-     *                            remove any padding whitespace at the end of
-     *                            the string.
+     * @access public
+     *
+     * @param string $text                 String containing the text to wrap.
+     * @param optional integer $length     Wrap $text at this number of
+     *                                     characters.
+     * @param optional string $break_char  Character(s) to use when breaking
+     *                                     lines.
+     * @param optional string $charset     Character set to use when breaking
+     *                                     lines.
+     * @param optional boolean $quote      Ignore lines that are wrapped with
+     *                                     the '>' character (RFC 2646)? If
+     *                                     true, we don't remove any padding
+     *                                     whitespace at the end of the
+     *                                     string.
      *
      * @return string  String containing the wrapped text.
      */
@@ -468,7 +443,7 @@ class String {
      */
     function isAlpha($string, $charset = null)
     {
-        if (String::extensionExists('mbstring')) {
+        if (Util::extensionExists('mbstring')) {
             $old_charset = mb_regex_encoding();
             if ($charset != $old_charset) {
                 @mb_regex_encoding($charset);
@@ -513,37 +488,4 @@ class String {
                 String::isAlpha($string, $charset));
     }
 
-    /**
-     * Performs a multibyte safe regex match search on the text provided.
-     *
-     * @since Horde 3.1
-     *
-     * @param string $text     The text to search.
-     * @param array $regex     The regular expressions to use, without perl
-     *                         regex delimiters (e.g. '/' or '|').
-     * @param string $charset  The character set of the text.
-     *
-     * @return array  The matches array from the first regex that matches.
-     */
-    function regexMatch($text, $regex, $charset = null)
-    {
-        if (!empty($charset)) {
-            $regex = String::convertCharset($regex, $charset, 'utf-8');
-            $text = String::convertCharset($text, $charset, 'utf-8');
-        }
-
-        $matches = array();
-        foreach ($regex as $val) {
-            if (preg_match('/' . $val . '/u', $text, $matches)) {
-                break;
-            }
-        }
-
-        if (!empty($charset)) {
-            $matches = String::convertCharset($matches, 'utf-8', $charset);
-        }
-
-        return $matches;
-    }
-
 }
