@@ -5,7 +5,7 @@ include_once 'Horde/SyncML/State.php';
 /**
  * The Horde_SyncML_Command class provides a super class fo SyncBody commands.
  *
- * $Horde: framework/SyncML/SyncML/Command.php,v 1.4.10.4 2005/07/07 18:22:47 selsky Exp $
+ * $Horde: framework/SyncML/SyncML/Command.php,v 1.4.10.1 2005/01/03 12:19:14 jan Exp $
  *
  * Copyright 2003-2005 Anthony Mills <amills@pyramid6.com>
  *
@@ -13,26 +13,16 @@ include_once 'Horde/SyncML/State.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anthony Mills <amills@pyramid6.com>
+ * @version $Revision: 1.4.10.1 $
  * @since   Horde 3.0
  * @package Horde_SyncML
  */
 class Horde_SyncML_Command {
 
-    /**
-     * @var integer
-     */
     var $_cmdID;
 
-    /**
-     * Internal structure used during XML parsing.
-     *
-     * @var array
-     */
-    var $_Stack = array();
+    var $_xmlStack;
 
-    /**
-     * @var string
-     */
     var $_chars;
 
     function &factory($command, $params = null)
@@ -42,9 +32,8 @@ class Horde_SyncML_Command {
         if (class_exists($class)) {
             return $cmd = &new $class($params);
         } else {
-            $GLOBALS['backend']->logMessage('Class definition of ' . $class . ' not found.',
-                                            __FILE__, __LINE__, PEAR_LOG_ERR);
-            include_once 'PEAR.php';
+            Horde::logMessage('SyncML: Class definition of ' . $class . ' not found.', __FILE__, __LINE__, PEAR_LOG_ERR);
+            require_once 'PEAR.php';
             return PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
     }
@@ -55,12 +44,12 @@ class Horde_SyncML_Command {
 
     function startElement($uri, $localName, $attrs)
     {
-        $this->_Stack[] = $localName;
+        $this->_xmlStack++;
     }
 
     function endElement($uri, $element)
     {
-        switch (count($this->_Stack)) {
+        switch ($this->_xmlStack) {
         case 2:
             if ($element == 'CmdID') {
                 $this->_cmdID = intval(trim($this->_chars));
@@ -68,13 +57,20 @@ class Horde_SyncML_Command {
             break;
         }
 
-        $this->_chars = '';
-        array_pop($this->_Stack);
+        if (isset($this->_chars)) {
+            unset($this->_chars);
+        }
+
+        $this->_xmlStack--;
     }
 
     function characters($str)
     {
-        $this->_chars .= $str;
+        if (isset($this->_chars)) {
+            $this->_chars = $this->_chars . $str;
+        } else {
+            $this->_chars = $str;
+        }
     }
 
 }
