@@ -127,15 +127,15 @@ define('NAME_SPACE_URI_DEVINF_1_1', 'syncml:devinf1.1');
 /**
  * The Horde_SyncML_State class provides a SyncML state object.
  *
- * $Horde: framework/SyncML/SyncML/State.php,v 1.17 2004/12/07 19:26:18 chuck Exp $
+ * $Horde: framework/SyncML/SyncML/State.php,v 1.17.2.2 2005/01/21 11:22:54 jan Exp $
  *
- * Copyright 2003-2004 Anthony Mills <amills@pyramid6.com>
+ * Copyright 2003-2005 Anthony Mills <amills@pyramid6.com>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anthony Mills <amills@pyramid6.com>
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.17.2.2 $
  * @since   Horde 3.0
  * @package Horde_SyncML
  */
@@ -394,7 +394,6 @@ class Horde_SyncML_State {
     {
         $this->dieOnError($type, __FILE__, __LINE__);
         $this->dieOnError($locid, __FILE__, __LINE__);
-        $this->dieOnError($locid, __FILE__, __LINE__);
         $this->dieOnError($this->_locName, __FILE__, __LINE__);
         $this->dieOnError($this->_sourceURI, __FILE__, __LINE__);
 
