@@ -1,13 +1,12 @@
 <?php
 
-require_once 'Horde/Text/Filter.php';
 require_once 'Text/reST.php';
 require_once 'Text/reST/Formatter.php';
 
 /**
  * The Text_Filter_rst:: class converts reStructuredText to HTML.
  *
- * $Horde: framework/Text_Filter/Filter/rst.php,v 1.9.10.1 2005/01/03 12:19:16 jan Exp $
+ * $Horde: framework/Text_Filter/Filter/rst.php,v 1.9.10.2 2005/01/11 20:44:48 chuck Exp $
  *
  * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
  *
@@ -15,7 +14,6 @@ require_once 'Text/reST/Formatter.php';
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jason M. Felice <jfelice@cronosys.com>
- * @version $Revision: 1.9.10.1 $
  * @package Horde_Text
  */
 class Text_Filter_rst extends Text_Filter {
