@@ -1,4 +1,7 @@
 <?php
+
+require_once 'Horde.php';
+
 /**
  * Turn text into HTML with varying levels of parsing.  For no html
  * whatsoever, use htmlspecialchars() instead.
@@ -29,7 +32,7 @@
  *                              Included for completeness.
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/text2html.php,v 1.4.2.1 2005/01/03 12:19:16 jan Exp $
+ * $Horde: framework/Text_Filter/Filter/text2html.php,v 1.4.2.2 2005/01/11 20:44:49 chuck Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2004-2005 Jan Schneider <jan@horde.org>
@@ -39,7 +42,6 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.4.2.1 $
  * @package Horde_Text
  */
 class Text_Filter_text2html extends Text_Filter {
