@@ -7,9 +7,10 @@ require_once 'PEAR.php';
  * various token generation mediums. It also includes all of the
  * functions for retrieving, storing, and checking tokens.
  *
- * $Horde: framework/Token/Token.php,v 1.33.6.13 2008/06/06 04:17:21 chuck Exp $
+ * $Horde: framework/Token/Token.php,v 1.33.6.2 2005/01/09 02:51:39 chuck Exp $
  *
- * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 1999-2005 Max Kalika <max@horde.org>
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -23,22 +24,10 @@ class Horde_Token {
 
     /**
      * Hash of parameters necessary to use the chosen backend.
-     *
-     * @var array
+     * @var array $_params
      */
     var $_params = array();
 
-    /**
-     * Constructor.
-     *
-     * @param array $params  A hash containing parameters.
-     */
-    function Horde_Token($params = array())
-    {
-    }
-
-    /**
-     */
     function encodeRemoteAddress()
     {
         if (isset($_SERVER['REMOTE_ADDR'])) {
@@ -59,7 +48,7 @@ class Horde_Token {
      */
     function generateId($seed = '')
     {
-        return md5(microtime() . $seed . (isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : ''));
+        return md5(time() . '][' . $seed . '][' . Horde_Token::encodeRemoteAddress());
     }
 
     /**
@@ -76,10 +65,7 @@ class Horde_Token {
     function verify($token)
     {
         $this->purge();
-        $exists = $this->exists($token);
-        if (is_a($exists, 'PEAR_Error')) {
-            return $exists;
-        } elseif ($exists) {
+        if ($this->exists($token)) {
             return false;
         } else {
             return $this->add($token);
@@ -117,17 +103,20 @@ class Horde_Token {
     }
 
     /**
-     * Attempts to return a concrete Horde_Token instance based on $driver.
+     * Attempts to return a concrete Horde_Token instance based on
+     * $driver.
      *
-     * @param mixed $driver  The type of concrete Horde_Token subclass to
-     *                       return. If $driver is an array, then we will look
-     *                       in $driver[0]/lib/Token/ for the subclass
-     *                       implementation named $driver[1].php.
-     * @param array $params  A hash containing any additional configuration or
-     *                       connection parameters a subclass might need.
+     * @param mixed $driver  The type of concrete Horde_Token subclass to return.
+     *                       This is based on the storage driver ($driver). The
+     *                       code is dynamically included. If $driver is an array,
+     *                       then we will look in $driver[0]/lib/Token/ for
+     *                       the subclass implementation named $driver[1].php.
+     * @param array $params  (optional) A hash containing any additional
+     *                       configuration or connection parameters a subclass
+     *                       might need.
      *
-     * @return Horde_Token  The newly created concrete Horde_Token instance, or
-     *                      false an error.
+     * @return object Horde_Token  The newly created concrete Horde_Token instance, or
+     *                             false an error.
      */
     function &factory($driver, $params = array())
     {
@@ -136,57 +125,53 @@ class Horde_Token {
         }
 
         $driver = basename($driver);
-        if ($driver == 'none') {
-            $class = 'Horde_Token';
-        } else {
-            $class = 'Horde_Token_' . $driver;
-        }
-        if (!class_exists($class)) {
-            if (!empty($app)) {
-                require_once $app . '/lib/Token/' . $driver . '.php';
-            } else {
-                include_once 'Horde/Token/' . $driver . '.php';
-            }
-        }
 
+        if (!empty($app)) {
+            require_once $app . '/lib/Token/' . $driver . '.php';
+        } elseif (@file_exists(dirname(__FILE__) . '/Token/' . $driver . '.php')) {
+            require_once dirname(__FILE__) . '/Token/' . $driver . '.php';
+        } else {
+            @include_once 'Horde/Token/' . $driver . '.php';
+        }
+        $class = 'Horde_Token_' . $driver;
         if (class_exists($class)) {
-            $token = new $class($params);
+            return $token = &new $class($params);
         } else {
-            /* If driver class doesn't exist or the driver is not
-             * available just default to the parent class, and it is
-             * not necessary to warn about degraded service. */
-            $token = new Horde_Token($params);
+            return $token = &new Horde_Token($params);
         }
-
-        return $token;
     }
 
     /**
-     * Attempts to return a reference to a concrete Horde_Token instance based
-     * on $driver.
+     * Attempts to return a reference to a concrete Horde_Token
+     * instance based on $driver. It will only create a new instance
+     * if no Horde_Token instance with the same parameters currently
+     * exists.
      *
-     * It will only create a new instance if no Horde_Token instance with the
-     * same parameters currently exists.
+     * This should be used if multiple types of token generators (and,
+     * thus, multiple Horde_Token instances) are required.
      *
-     * This should be used if multiple types of token generators (and, thus,
-     * multiple Horde_Token instances) are required.
+     * This method must be invoked as: $var = &Horde_Token::singleton()
      *
-     * This method must be invoked as:
-     * <code>$var = &Horde_Token::singleton();</code>
+     * @param mixed $driver  The type of concrete Horde_Token subclass to return.
+     *                       This is based on the storage driver ($driver). The
+     *                       code is dynamically included. If $driver is an array,
+     *                       then we will look in $driver[0]/lib/Token/ for
+     *                       the subclass implementation named $driver[1].php.
+     * @param array $params  (optional) A hash containing any additional
+     *                       configuration or connection parameters a subclass
+     *                       might need.
      *
-     * @param mixed $driver  The type of concrete Horde_Token subclass to
-     *                       return. If $driver is an array, then we will look
-     *                       in $driver[0]/lib/Token/ for the subclass
-     *                       implementation named $driver[1].php.
-     * @param array $params  A hash containing any additional configuration or
-     *                       connection parameters a subclass might need.
+     * @return object Horde_Token  The concrete Horde_Token reference, or false on an
+     *                             error.
      *
-     * @return Horde_Token  The concrete Horde_Token reference, or false on
-     *                      error.
+     * @since Horde 2.2
      */
     function &singleton($driver, $params = array())
     {
-        static $instances = array();
+        static $instances;
+        if (!isset($instances)) {
+            $instances = array();
+        }
 
         $signature = serialize(array($driver, $params));
         if (!isset($instances[$signature])) {
