@@ -3,12 +3,13 @@
  * The Horde_UI_Language:: class provides a widget for changing the
  * currently selected language.
  *
- * $Horde: framework/UI/UI/Language.php,v 1.5.10.4 2005/05/18 11:38:34 jan Exp $
+ * $Horde: framework/UI/UI/Language.php,v 1.5.10.1 2005/01/03 12:19:19 jan Exp $
  *
  * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
  *
  * See the enclosed file LICENSE for license information (LGPL).
  *
+ * @version $Revision: 1.5.10.1 $
  * @since   Horde_UI 0.0.1
  * @package Horde_UI
  */
@@ -19,8 +20,8 @@ class Horde_UI_Language {
      *
      * @abstract
      *
-     * @param boolean $form  Return the selection box as an complete standalone
-     *                       form.
+     * @param optional bool $form  Return the selection box as an complete
+     *                             standalone form.
      *
      * @return string  The HTML selection box.
      */
@@ -32,7 +33,7 @@ class Horde_UI_Language {
             $_SESSION['horde_language'] = NLS::select();
             $html = sprintf('<form name="language" action="%s">',
                             Horde::url($GLOBALS['registry']->get('webroot', 'horde') . '/services/language.php', false, -1));
-            $html .= '<input type="hidden" name="url" value="' . @htmlspecialchars(Horde::selfUrl(false, false, true)) . '" />';
+            $html .= '<input type="hidden" name="url" value="' . Horde::selfUrl(false, false, true) . '" />';
             $html .= '<select name="new_lang" onchange="document.language.submit()">';
             foreach ($GLOBALS['nls']['languages'] as $key => $val) {
                 $sel = ($key == $_SESSION['horde_language']) ? ' selected="selected"' : '';
