@@ -2,7 +2,7 @@
 /**
  * The Horde_UI_VarRenderer_html:: class renders variables to HTML.
  *
- * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.12 2005/09/23 13:30:28 jan Exp $
+ * $Horde: framework/UI/UI/VarRenderer/html.php,v 1.98.2.5 2005/03/06 18:59:19 jan Exp $
  *
  * Copyright 2003-2005 Jason M. Felice <jfelice@cronosys.com>
  *
@@ -240,7 +240,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
             /* Keep also original if it has been requested. */
             if ($var->type->_show_keeporig) {
-                $html .= sprintf('<input type="checkbox" class="checkbox" name="%s"%s />%s' . "\n",
+                $html .= sprintf('<input type="checkbox" name="%s"%s />%s' . "\n",
                        $varname . '[keep_orig]',
                        !empty($image['keep_orig']) ? ' checked="checked"' : '',
                        _("Keep original?"));
@@ -328,7 +328,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $time = $var->type->getTimeParts($var->getValue($vars));
 
         /* Output hours. */
-        $hours = array('' => _("hh"));
+        $hours = array('' => _("HH"));
         for ($i = 0; $i <= 23; $i++) {
             $hours[sprintf('%02d', $i)] = $i;
         }
@@ -339,7 +339,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                         $this->_getActionScripts($form, $var));
 
         /* Output minutes. */
-        $minutes = array('' => _("mm"));
+        $minutes = array('' => _("MM"));
         for ($i = 0; $i <= 59; $i++) {
             $minutes[sprintf('%02d', $i)] = $i;
         }
@@ -355,7 +355,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         }
 
         /* Output seconds. */
-        $seconds = array('' => _("ss"));
+        $seconds = array('' => _("SS"));
         for ($i = 0; $i <= 59; $i++) {
             $seconds[sprintf('%02d', $i)] = $i;
         }
@@ -485,19 +485,22 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
         Horde::addScriptFile('sorter.js', 'horde', true);
 
-        return '<input type="hidden" name="' . $varname .
-            '[array]" value="" ' . $this->_genID($varname . '[array]') . '/>' .
-            '<select class="leftFloat" multiple="multiple" size="' .
-            $var->type->getSize() . '" name="' . $varname .
-            '[list]" onchange="' . $instance . '.deselectHeader();" ' .
-            $this->_genID($varname . '[list]') . '>' .
-            $var->type->getOptions($var->getValue($vars)) . '</select><div class="leftFloat">' .
-            Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnUp(); return false;') . Horde::img('nav/up.png', _("Move up"), '', $registry->getImageDir('horde')) . '</a><br />' .
-            Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnDown(); return false;') . Horde::img('nav/down.png', _("Move down"), '', $registry->getImageDir('horde')) . '</a></div>' .
-            '<script language="JavaScript" type="text/javascript">' . "\n" .
-            sprintf('%1$s = new Horde_Form_Sorter(\'%1$s\', \'%2$s\', \'%3$s\');' . "\n",
-                    $instance, $varname, $var->type->getHeader()) .
-            sprintf("%s.setHidden();\n</script>\n", $instance);
+        $html = '<input type="hidden" name="' . $varname .
+                '[array]" value="" ' . $this->_genID($varname . '[array]') .
+                ' /><table cellspacing="0"><tr>' .
+                '<td><select multiple="multiple" size="' .
+                $var->type->getSize() . '" name="' . $varname .
+                '[list]" onchange="' . $instance . '.deselectHeader();" ' .
+                $this->_genID($varname . '[list]') . '>';
+        $html .= $var->type->getOptions($var->getValue($vars)) . '</select></td><td>';
+        $html .= Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnUp(); return false;') . Horde::img('nav/up.png', _("Move up"), '', $registry->getImageDir('horde')) . '</a><br />';
+        $html .= Horde::link('#', _("Move up"), '', '', $instance . '.moveColumnDown(); return false;') . Horde::img('nav/down.png', _("Move down"), '', $registry->getImageDir('horde')) . '</a></td></tr></table>';
+        $html .= '<script language="JavaScript" type="text/javascript">' . "\n";
+        $html .= sprintf('%1$s = new Horde_Form_Sorter(\'%1$s\', \'%2$s\', \'%3$s\');' . "\n",
+               $instance, $varname, $var->type->getHeader());
+
+        $html .= sprintf("%s.setHidden();\n</script>\n", $instance);
+        return $html;
     }
 
     function _renderVarInput_assign(&$form, &$var, &$vars)
@@ -548,7 +551,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $prompt = $var->type->getPrompt();
         $htmlchars = $var->getOption('htmlchars');
         if (!empty($prompt)) {
-            $prompt = '<option value="">' . ($htmlchars ? $prompt : @htmlspecialchars($prompt, ENT_QUOTES, NLS::getCharset())) . '</option>';
+            $prompt = '<option value="">' . ($htmlchars ? @htmlspecialchars($prompt, ENT_QUOTES, NLS::getCharset()) : $prompt) . '</option>';
         }
         return sprintf('<select name="%s" %s%s>%s%s</select>',
                $var->getVarName(),
@@ -695,7 +698,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             }
             $html .= ' </td>';
             foreach ($cols as $col_id => $col_title) {
-                $html .= sprintf('<td align="center"><input type="checkbox" class="checkbox" name="%s[n][v][%s]" /></td>', $varname, $col_id);
+                $html .= sprintf('<td align="center"><input type="checkbox" name="%s[n][v][%s]" /></td>', $varname, $col_id);
             }
             $html .= '<td> </td></tr>';
         }
@@ -704,7 +707,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         foreach ($rows as $row_id => $row_title) {
             $html .= sprintf('<tr><td>%s</td>', $row_title);
             foreach ($cols as $col_id => $col_title) {
-                $html .= sprintf('<td align="center"><input type="checkbox" class="checkbox" name="%s[r][%s][%s]"%s /></td>', $varname, $row_id, $col_id, (!empty($matrix[$row_id][$col_id]) ? ' checked="checked"' : ''));
+                $html .= sprintf('<td align="center"><input type="checkbox" name="%s[r][%s][%s]"%s /></td>', $varname, $row_id, $col_id, (!empty($matrix[$row_id][$col_id]) ? ' checked="checked"' : ''));
             }
             $html .= '<td> </td></tr>';
         }
@@ -753,7 +756,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
     {
         $varName = $var->getVarName();
 
-        $html = '<input type="checkbox" class="checkbox" name="' .  $varName . '"' .
+        $html = '<input type="checkbox" name="' .  $varName . '"' .
             ($var->getValue($vars) ? ' checked="checked"' : '');
         if ($var->hasAction()) {
             $html .= $this->_genActionScript($form, $var->_action,
@@ -966,8 +969,6 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
 
     function _renderVarDisplay_address(&$form, &$var, &$vars)
     {
-        global $registry;
-
         $address = $var->getValue($vars);
 
         if (preg_match('/(.*)\n(.*)\s*,\s*(\w+)\.?\s+(\d+|[a-zA-Z]\d[a-zA-Z]\s?\d[a-zA-Z]\d)/', $address, $addressParts)) {
@@ -1003,7 +1004,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             if (!empty($addressParts[1])) {
                 $mapurl2 .= '&addr=' . urlencode($addressParts[1]);
             }
-            /* Give precedence to zipcode over city/state */
+            /* give precedence on zipcode over city/state */
             if (empty($addressParts[4]) && !empty($addressParts[2]) && !empty($addressParts[3])) {
                 $mapurl2 .= '&csz=' . urlencode($addressParts[2] . ' ' . $addressParts[3]);
             }
@@ -1049,7 +1050,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                 }
             }
 
-            /* Mapquest generated map. */
+            /* Mapquest generated map */
             $mapurl2 = 'http://www.mapquest.com/maps/map.adp?country=' . String::upper($country);
             $desc2 = _("MapQuest map");
             $icon2 = 'map_eu.png';
@@ -1063,15 +1064,14 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
                 $mapurl2 .= '&city=' . urlencode($addressParts[4]);
             }
         }
-
         $html = nl2br(@htmlspecialchars($var->getValue($vars), ENT_QUOTES, NLS::getCharset()));
         if (!empty($mapurl)) {
-            $html .= '&nbsp;&nbsp;' . Horde::link(Horde::externalUrl($mapurl), $desc, null, '_blank') . Horde::img($icon, $desc, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
+            global $registry;
+            $html .= '&nbsp;&nbsp;' . Horde::link($mapurl, $desc, null, '_blank') . Horde::img($icon, $desc, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
         }
         if (!empty($mapurl2)) {
-            $html .= '&nbsp;' . Horde::link(Horde::externalUrl($mapurl2), $desc2, null, '_blank') . Horde::img($icon2, $desc2, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
+            $html .= '&nbsp;' . Horde::link($mapurl2, $desc2, null, '_blank') . Horde::img($icon2, $desc2, 'align="middle"', $registry->getImageDir('horde')) . '</a>';
         }
-
         return $html;
     }
 
@@ -1106,6 +1106,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
             $values = array($values);
         }
 
+
         $count = count($values);
         $html = '';
         for ($i = 0; $i < $count; $i++) {
@@ -1174,28 +1175,21 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         return $html;
     }
 
-    function _selectOptions(&$values, $selectedValue = false,
-                            $htmlchars = false)
+    function _selectOptions(&$values, $selectedValue = false, $htmlchars = true)
     {
         $result = '';
         $sel = false;
         foreach ($values as $value => $display) {
-            if (!is_null($selectedValue) && !$sel &&
-                $value == $selectedValue &&
-                strlen($value) == strlen($selectedValue)) {
+            if (!is_null($selectedValue) && !$sel && $value == $selectedValue && strlen($value) == strlen($selectedValue)) {
                 $selected = ' selected="selected"';
                 $sel = true;
             } else {
                 $selected = '';
             }
             $result .= ' <option value="';
-            $result .= $htmlchars
-                ? $value
-                : @htmlspecialchars($value, ENT_QUOTES, NLS::getCharset());
+            $result .= ($htmlchars) ? @htmlspecialchars($value, ENT_QUOTES, NLS::getCharset()) : $value;
             $result .= '"' . $selected . '>';
-            $result .= $htmlchars
-                ? $display
-                : @htmlspecialchars($display, ENT_QUOTES, NLS::getCharset());
+            $result .= ($htmlchars) ? htmlspecialchars($display) : $display;
             $result .= "</option>\n";
         }
 
@@ -1227,7 +1221,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $i = 0;
         foreach ($values as $value => $display) {
             $checked = (in_array($value, $checkedValues)) ? ' checked="checked"' : '';
-            $result .= sprintf('<input id="%s%s" type="checkbox" class="checkbox" name="%s[]" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
+            $result .= sprintf('<input id="%s%s" type="checkbox" name="%s[]" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
                                $name,
                                $i,
                                $name,
@@ -1249,7 +1243,7 @@ class Horde_UI_VarRenderer_html extends Horde_UI_VarRenderer {
         $i = 0;
         foreach ($values as $value => $display) {
             $checked = (!is_null($checkedValue) && $value == $checkedValue) ? ' checked="checked"' : '';
-            $result .= sprintf('<input id="%s%s" type="radio" class="checkbox" name="%s" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
+            $result .= sprintf('<input id="%s%s" type="radio" name="%s" value="%s"%s%s /><label for="%s%s">&nbsp;%s</label><br />',
                                $name,
                                $i,
                                $name,
