@@ -13,9 +13,10 @@ define('HORDE_ERROR_DRIVER_CONFIG', 2);
 /**
  * The Util:: class provides generally useful methods of different kinds.
  *
- * $Horde: framework/Util/Util.php,v 1.384.6.30 2008/09/12 10:00:19 jan Exp $
+ * $Horde: framework/Util/Util.php,v 1.384.6.3 2005/01/12 15:54:42 chuck Exp $
  *
- * Copyright 1999-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -36,20 +37,12 @@ class Util {
      */
     function &cloneObject(&$obj)
     {
-        /* Cloning does *not* currently work if using PHP 5.
-         * This is a known PHP issue: http://bugs.php.net/bug.php?id=27268
-         * Therefore, work around this issue by using the PHP 4
-         * serialize/unserialize clone hack. */
-        /*
         if (version_compare(zend_version(), '2', '>')) {
             return clone($obj);
         } else {
             $newObj = $obj;
             return $newObj;
         }
-        */
-        $ret = unserialize(serialize($obj));
-        return $ret;
     }
 
     /**
@@ -57,6 +50,8 @@ class Util {
      * highlight_string(), that prints the output directly, so that instead it
      * can be returned as a string and used.
      *
+     * @access public
+     *
      * @param string $function  The function to run.
      * @param mixed $arg1       First argument to $function().
      * @param mixed $arg2       Second argument to $function().
@@ -70,7 +65,7 @@ class Util {
         if (func_num_args() == 0) {
             return false;
         }
-        $include = false;
+        $eval = false;
         $args = func_get_args();
         $function = array_shift($args);
         if (is_array($function)) {
@@ -81,36 +76,24 @@ class Util {
                   ($function == 'include_once') ||
                   ($function == 'require') ||
                   ($function == 'require_once')) {
-            $include = true;
-        } elseif (!function_exists($function)) {
+            $eval = true;
+        } elseif (!function_exists($function) &&
+                  ($function != 'eval')) {
             return false;
         }
 
         ob_start();
-        if ($include) {
-            $file = implode(',', $args);
-            switch ($function) {
-            case 'include':
-                include $file;
-                break;
-
-            case 'include_once':
-                include_once $file;
-                break;
-
-            case 'require':
-                require $file;
-                break;
-
-            case 'require_once':
-                require_once $file;
-                break;
-            }
+        if ($eval) {
+            eval($function . " '" . implode(',', $args) . "';");
+        } elseif ($function == 'eval') {
+            eval($args[0]);
         } else {
             call_user_func_array($function, $args);
         }
+        $output = ob_get_contents();
+        ob_end_clean();
 
-        return ob_get_clean();
+        return $output;
     }
 
     /**
@@ -118,22 +101,21 @@ class Util {
      * POST, or cookie input. The value being checked MUST be in the global
      * scope.
      *
-     * @param string $varname  The variable name to check.
-     * @param mixed $default   Default value if the variable isn't present
-     *                         or was specified by the user. Defaults to null.
-     *                         @since Horde 3.1
+     * @access public
      *
-     * @return mixed  $default if the var is in user input or not present,
-     *                the variable value otherwise.
+     * @param string $varname  The variable name to check.
+     *
+     * @return mixed  Null if the var is in user input, the variable value
+     *                otherwise.
      */
-    function nonInputVar($varname, $default = null)
+    function nonInputVar($varname)
     {
         if (isset($_GET[$varname]) ||
             isset($_POST[$varname]) ||
             isset($_COOKIE[$varname])) {
-            return $default;
+            return null;
         } else {
-            return isset($GLOBALS[$varname]) ? $GLOBALS[$varname] : $default;
+            return isset($GLOBALS[$varname]) ? $GLOBALS[$varname] : null;
         }
     }
 
@@ -142,6 +124,8 @@ class Util {
      * there are existing parameters and whether to use ?, & or &amp; as the
      * glue.  All data will be urlencoded.
      *
+     * @access public
+     *
      * @param string $url       The URL to modify
      * @param mixed $parameter  Either the name=value pair to add
      *                          (DEPRECATED) -or-
@@ -149,9 +133,12 @@ class Util {
      *                          an array of name/value pairs.
      * @param string $value     If specified, the value part ($parameter is
      *                          then assumed to just be the parameter name).
-     * @param boolean $encode   Encode the argument separator?
+     * @param boolean $encode   If true, and we don't have argument separators
+     *                          yet, the argument separator gets encoded.
      *
      * @return string  The modified URL.
+     *
+     * @since Horde 2.1
      */
     function addParameter($url, $parameter, $value = null, $encode = true)
     {
@@ -159,54 +146,53 @@ class Util {
             return $url;
         }
 
-        $add = array();
+        if (!is_array($parameter)) {
+            /* This is deprecated should be removed in the future. */
+            if (is_null($value)) {
+                @list($parameter, $value) = explode('=', $parameter, 2);
+            }
+            $add = array($parameter => $value);
+        } else {
+            $add = $parameter;
+        }
+
         $arg = $encode ? '&amp;' : '&';
-
-        if (strpos($url, '?') !== false) {
-            list($url, $query) = explode('?', $url);
-
+        if (($pos = strpos($url, '?')) === false) {
+            $glue = '?';
+        } else {
             /* Check if the argument separator has been already
              * htmlentities-ized in the URL. */
+            $query = substr($url, $pos + 1);
             if (preg_match('/=.*?&amp;.*?=/', $query)) {
-                $query = html_entity_decode($query);
                 $arg = '&amp;';
+                $query = strtr($query, array_flip(get_html_translation_table(HTML_ENTITIES)));
             } elseif (preg_match('/=.*?&.*?=/', $query)) {
                 $arg = '&';
             }
-            $pairs = explode('&', $query);
+            $pairs = explode($arg, $query);
+            $params = array();
             foreach ($pairs as $pair) {
-                $pair = explode('=', urldecode($pair), 2);
-                $pair_val = (count($pair) == 2) ? $pair[1] : '';
-                if (substr($pair[0], -2) == '[]') {
-                    $name = substr($pair[0], 0, -2);
-                    if (!isset($add[$name])) {
-                        $add[$name] = array();
-                    }
-                    $add[$name][] = $pair_val;
-                } else {
-                    $add[$pair[0]] = $pair_val;
-                }
+                $pair = explode('=', $pair, 2);
+                $params[$pair[0]] = count($pair) == 2 ? $pair[1] : '';
             }
-        }
-        if (is_array($parameter)) {
-            $add = array_merge($add, $parameter);
-        } else {
-            $add[$parameter] = $value;
+            $glue = $arg;
         }
 
         $url_params = array();
         foreach ($add as $parameter => $value) {
-            if (is_array($value)) {
-                foreach ($value as $val) {
-                    $url_params[] = urlencode($parameter) . '[]=' . urlencode($val);
+            if (!isset($params[$parameter])) {
+                if (is_array($value)) {
+                    foreach ($value as $val) {
+                        $url_params[] = urlencode($parameter) . '[]=' . urlencode($val);
+                    }
+                } else {
+                    $url_params[] = urlencode($parameter) . '=' . urlencode($value);
                 }
-            } else {
-                $url_params[] = urlencode($parameter) . '=' . urlencode($value);
             }
         }
 
         if (count($url_params)) {
-            return $url . '?' . implode($arg, $url_params);
+            return $url . $glue . implode($arg, $url_params);
         } else {
             return $url;
         }
@@ -215,11 +201,15 @@ class Util {
     /**
      * Removes name=value pairs from a URL.
      *
+     * @access public
+     *
      * @param string $url    The URL to modify.
      * @param mixed $remove  Either a single parameter to remove or an array
      *                       of parameters to remove.
      *
      * @return string  The modified URL.
+     *
+     * @since Horde 2.2
      */
     function removeParameter($url, $remove)
     {
@@ -239,7 +229,7 @@ class Util {
          * htmlentities-ized in the URL. */
         if (preg_match('/=.*?&amp;.*?=/', $query)) {
             $entities = true;
-            $query = html_entity_decode($query);
+            $query = strtr($query, array_flip(get_html_translation_table(HTML_ENTITIES)));
         }
 
         /* Get the list of parameters. */
@@ -284,13 +274,13 @@ class Util {
      * Returns a url with the 'nocache' parameter added, if the browser is
      * buggy and caches old URLs.
      *
-     * @param string $url       The URL to modify.
-     * @param boolean $encode   Encode the argument separator? (since
-     *                          Horde 3.2)
+     * @access public
+     *
+     * @param string $url  The URL to modify.
      *
      * @return string  The requested URI.
      */
-    function nocacheUrl($url, $encode = true)
+    function nocacheUrl($url)
     {
         static $rand_num;
 
@@ -303,7 +293,7 @@ class Util {
             if (!isset($rand_num)) {
                 $rand_num = base_convert(microtime(), 10, 36);
             }
-            return Util::addParameter($url, 'nocache', $rand_num, $encode);
+            return Util::addParameter($url, 'nocache', $rand_num);
         } else {
             return $url;
         }
@@ -312,6 +302,8 @@ class Util {
     /**
      * Returns a hidden form input containing the session name and id.
      *
+     * @access public
+     *
      * @param boolean $append_session  0 = only if needed, 1 = always.
      *
      * @return string  The hidden form input, if needed/requested.
@@ -329,6 +321,8 @@ class Util {
     /**
      * Prints a hidden form input containing the session name and id.
      *
+     * @access public
+     *
      * @param boolean $append_session  0 = only if needed, 1 = always.
      */
     function pformInput($append_session = 0)
@@ -339,6 +333,8 @@ class Util {
     /**
      * If magic_quotes_gpc is in use, run stripslashes() on $var.
      *
+     * @access public
+     *
      * @param string &$var  The string to un-quote, if necessary.
      *
      * @return string  $var, minus any magic quotes.
@@ -368,6 +364,8 @@ class Util {
      * POST data, the value from the POST data will be returned and the GET
      * value will be ignored.
      *
+     * @access public
+     *
      * @param string $var      The name of the form variable to look for.
      * @param string $default  The value to return if the variable is not
      *                         there.
@@ -384,11 +382,15 @@ class Util {
      * Gets a form variable from GET data, stripped of magic quotes if
      * necessary. This function will NOT return a POST variable.
      *
+     * @access public
+     *
      * @param string $var      The name of the form variable to look for.
      * @param string $default  The value to return if the variable is not
      *                         there.
      *
      * @return string  The cleaned form variable, or $default.
+     *
+     * @since Horde 2.2
      */
     function getGet($var, $default = null)
     {
@@ -401,11 +403,15 @@ class Util {
      * Gets a form variable from POST data, stripped of magic quotes if
      * necessary. This function will NOT return a GET variable.
      *
+     * @access public
+     *
      * @param string $var      The name of the form variable to look for.
      * @param string $default  The value to return if the variable is not
      *                         there.
      *
      * @return string  The cleaned form variable, or $default.
+     *
+     * @since Horde 2.2
      */
     function getPost($var, $default = null)
     {
@@ -417,6 +423,8 @@ class Util {
     /**
      * Determines the location of the system temporary directory.
      *
+     * @access public
+     *
      * @return string  A directory name which can be used for temp files.
      *                 Returns false if one could not be found.
      */
@@ -475,20 +483,22 @@ class Util {
 
         $tmp_file = tempnam($tmp_dir, $prefix);
 
-        /* If the file was created, then register it for deletion and return. */
+        /* If the file was created, then register it for deletion and return */
         if (empty($tmp_file)) {
             return false;
+        } else {
+            if ($delete) {
+                Util::deleteAtShutdown($tmp_file, true, $secure);
+            }
+            return $tmp_file;
         }
-
-        if ($delete) {
-            Util::deleteAtShutdown($tmp_file, true, $secure);
-        }
-        return $tmp_file;
     }
 
     /**
      * Creates a temporary directory in the system's temporary directory.
      *
+     * @access public
+     *
      * @param boolean $delete   Delete the temporary directory at the end of
      *                          the request?
      * @param string $temp_dir  Use this temporary directory as the directory
@@ -510,63 +520,18 @@ class Util {
         /* Get the first 8 characters of a random string to use as a temporary
            directory name. */
         do {
-            $new_dir = $temp_dir . '/' . substr(base_convert(mt_rand() . microtime(), 10, 36), 0, 8);
-        } while (file_exists($new_dir));
+            $temp_dir .= '/' . substr(base_convert(mt_rand() . microtime(), 10, 36), 0, 8);
+        } while (file_exists($temp_dir));
 
         $old_umask = umask(0000);
-        if (!mkdir($new_dir, 0700)) {
-            $new_dir = false;
+        if (!mkdir($temp_dir, 0700)) {
+            $temp_dir = false;
         } elseif ($delete) {
-            Util::deleteAtShutdown($new_dir);
+            Util::deleteAtShutdown($temp_dir);
         }
         umask($old_umask);
 
-        return $new_dir;
-    }
-
-    /**
-     * Returns the canonical path of the string.  Like PHP's built-in
-     * realpath() except the directory need not exist on the local server.
-     *
-     * Algorithim loosely based on code from the Perl File::Spec::Unix module
-     * (version 1.5).
-     *
-     * @since Horde 3.0.5
-     *
-     * @param string $path  A file path.
-     *
-     * @return string  The canonicalized file path.
-     */
-    function realPath($path)
-    {
-        /* Standardize on UNIX directory separators. */
-        if (!strncasecmp(PHP_OS, 'WIN', 3)) {
-            $path = str_replace('\\', '/', $path);
-        }
-
-        /* xx////xx -> xx/xx
-         * xx/././xx -> xx/xx */
-        $path = preg_replace(array("|/+|", "@(/\.)+(/|\Z(?!\n))@"), array('/', '/'), $path);
-
-        /* ./xx -> xx */
-        if ($path != './') {
-            $path = preg_replace("|^(\./)+|", '', $path);
-        }
-
-        /* /../../xx -> xx */
-        $path = preg_replace("|^/(\.\./?)+|", '/', $path);
-
-        /* xx/ -> xx */
-        if ($path != '/') {
-            $path = preg_replace("|/\Z(?!\n)|", '', $path);
-        }
-
-        /* /xx/.. -> / */
-        while (strpos($path, '/..') !== false) {
-            $path = preg_replace("|/[^/]+/\.\.|", '', $path);
-        }
-
-        return empty($path) ? '/' : $path;
+        return $temp_dir;
     }
 
     /**
@@ -586,6 +551,8 @@ class Util {
      * The second parameter allows the unregistering of previously registered
      * elements.
      *
+     * @access public
+     *
      * @param string $filename   The filename to be deleted at the end of the
      *                           request.
      * @param boolean $register  If true, then register the element for
@@ -599,7 +566,7 @@ class Util {
         static $dirs, $files, $securedel;
 
         /* Initialization of variables and shutdown functions. */
-        if (is_null($dirs)) {
+        if (is_null($dirs)){
             $dirs = array();
             $files = array();
             $securedel = array();
@@ -649,20 +616,16 @@ class Util {
 
         foreach ($files as $file => $val) {
             /* Delete files */
-            if ($val && file_exists($file)) {
-                /* Should we securely delete the file by overwriting the data
-                   with a random string? */
+            if ($val && @file_exists($file)) {
+                /* Should we securely delete the file by overwriting the
+                   data with a random string? */
                 if (isset($secure[$file])) {
-                    $filesize = filesize($file);
-                    /* See http://www.cs.auckland.ac.nz/~pgut001/pubs/secure_del.html.
-                     * We save the random overwrites for efficiency reasons. */
-                    $patterns = array("\x55", "\xaa", "\x92\x49\x24", "\x49\x24\x92", "\x24\x92\x49", "\x00", "\x11", "\x22", "\x33", "\x44", "\x55", "\x66", "\x77", "\x88", "\x99", "\xaa", "\xbb", "\xcc", "\xdd", "\xee", "\xff", "\x92\x49\x24", "\x49\x24\x92", "\x24\x92\x49", "\x6d\xb6\xdb", "\xb6\xdb\x6d", "\xdb\x6d\xb6");
-                    $fp = fopen($file, 'r+');
-                    foreach ($patterns as $pattern) {
-                        $pattern = substr(str_repeat($pattern, floor($filesize / strlen($pattern)) + 1), 0, $filesize);
-                        fwrite($fp, $pattern);
-                        fseek($fp, 0);
+                    $random_str = '';
+                    for ($i = 0; $i < filesize($file); $i++) {
+                        $random_str .= chr(mt_rand(0, 255));
                     }
+                    $fp = fopen($file, 'r+');
+                    fwrite($fp, $random_str);
                     fclose($fp);
                 }
                 @unlink($file);
@@ -671,7 +634,7 @@ class Util {
 
         foreach ($dirs as $dir => $val) {
             /* Delete directories */
-            if ($val && file_exists($dir)) {
+            if ($val && @file_exists($dir)) {
                 /* Make sure directory is empty. */
                 $dir_class = dir($dir);
                 while (false !== ($entry = $dir_class->read())) {
@@ -688,13 +651,15 @@ class Util {
     /**
      * Outputs javascript code to close the current window.
      *
-     * @param string $code  Any additional javascript code to run before
+     * @access public
+     *
+     * @param string $code  Any addtional javascript code to run before
      *                      closing the window.
      */
     function closeWindowJS($code = '')
     {
-        echo '<script type="text/javascript">//<![CDATA[' . "\n"
-            . $code . 'window.close();' . "\n//]]></script>\n";
+        echo '<script language="JavaScript" type="text/javascript">' . $code .
+            'window.close();</script>';
     }
 
     /**
@@ -739,7 +704,7 @@ class Util {
             return false;
         }
 
-        if (!strncasecmp(PHP_OS, 'WIN', 3)) {
+        if (substr(PHP_OS, 0, 3) == 'WIN') {
             $suffix = 'dll';
         } else {
             switch (PHP_OS) {
@@ -793,7 +758,7 @@ class Util {
         foreach ($fields as $field) {
             if (!isset($params[$field])) {
                 require_once 'PEAR.php';
-                return PEAR::throwError(sprintf(_("Required \"%s\" not specified in configuration."), $field, $name),
+                return PEAR::throwError(sprintf(_("Required '%s' not specified in configuration."), $field, $name),
                                         HORDE_ERROR_DRIVER_CONFIG,
                                         $info);
             }
@@ -843,100 +808,6 @@ class Util {
         return str_replace($strftimeSymbols, $dateSymbols, $format);
     }
 
-    /**
-     * Utility function to obtain PATH_INFO information.
-     *
-     * @since Horde 3.2
-     *
-     * @return string  The PATH_INFO string.
-     */
-    function getPathInfo()
-    {
-        if (isset($_SERVER['PATH_INFO'])) {
-            return $_SERVER['PATH_INFO'];
-        } elseif (isset($_SERVER['REQUEST_URI']) &&
-                  isset($_SERVER['SCRIPT_NAME'])) {
-            $search = array($_SERVER['SCRIPT_NAME']);
-            $replace = array('');
-            if (!empty($_SERVER['QUERY_STRING'])) {
-                $search[] = '?' . $_SERVER['QUERY_STRING'];
-                $replace[] = '';
-            }
-            return str_replace($search, $replace, $_SERVER['REQUEST_URI']);
-        }
-
-        return '';
-    }
-
-    /**
-     * Calculate an HMAC for a given $data and secret $key using SHA-1.
-     *
-     * @param string $data  Data to sign
-     * @param string $key   Secret key
-     * @param boolean $raw_output  Return binary data? Default to hex.
-     *
-     * @return string | binary  HMAC
-     *
-     * @since Horde 3.3
-     */
-    function hmac($data, $key, $raw_output = false)
-    {
-        if (function_exists('hash_hmac')) {
-            return hash_hmac('sha1', $data, $key, $raw_output);
-        }
-
-        if (strlen($key) > 64) {
-            $key =  pack('H40', sha1($key));
-        }
-        if (strlen($key) < 64) {
-            $key = str_pad($key, 64, chr(0));
-        }
-
-        /* Calculate the padded keys and save them */
-        $ipad = substr($key, 0, 64) ^ str_repeat(chr(0x36), 64);
-        $opad = substr($key, 0, 64) ^ str_repeat(chr(0x5C), 64);
-
-        if ($rawOutput) {
-            return pack('H*', sha1($opad . pack('H40', sha1($ipad . $data))));
-        }
-        return sha1($opad . pack('H40', sha1($ipad . $data)));
-    }
-
-    /**
-     * URL-safe base64 encoding, with trimmed =
-     *
-     * @since Horde 3.3
-     *
-     * @param string $string  String to encode.
-     *
-     * @return string  URL-safe, base64 encoded data.
-     */
-    function uriB64Encode($string)
-    {
-        $data = base64_encode($string);
-        $data = str_replace(array('+', '/', '='), array('-', '_', ''), $data);
-        return $data;
-    }
-
-    /**
-     * Decode URL-safe base64 data, dealing with missing =
-     *
-     * @since Horde 3.3
-     *
-     * @param string $string  Encoded data
-     *
-     * @return string  Decoded data.
-     */
-    function uriB64Decode($string)
-    {
-        $data = str_replace(array('-', '_'), array('+', '/'), $string);
-        $mod4 = strlen($data) % 4;
-        if ($mod4) {
-            $data .= substr('====', $mod4);
-        }
-        return base64_decode($data);
-    }
-
 }
 
 if (!function_exists('_')) {
@@ -945,11 +816,6 @@ if (!function_exists('_')) {
         return $string;
     }
 
-    function ngettext($msgid1, $msgid2, $n)
-    {
-        return $n > 1 ? $msgid2 : $msgid1;
-    }
-
     function bindtextdomain()
     {
     }
