@@ -2,9 +2,9 @@
 /**
  * VC_svn implementation.
  *
- * Copyright 2000-2007 Anil Madhavapeddy, <anil@recoil.org>
+ * Copyright 2000-2005 Anil Madhavapeddy, <anil@recoil.org>
  *
- * $Horde: framework/VC/VC/svn.php,v 1.28.4.19 2007/01/02 13:54:47 jan Exp $
+ * $Horde: framework/VC/VC/svn.php,v 1.28.4.4 2005/01/13 04:36:58 chuck Exp $
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
  * @since   Horde 3.0
@@ -35,8 +35,7 @@ class VC_svn extends VC {
 
     function &queryDir($where)
     {
-        $dir = new VC_Directory_svn($this, $where);
-        return $dir;
+        return $dir = &new VC_Directory_svn($this, $where);
     }
 
     function getCheckout($file, $rev)
@@ -44,27 +43,24 @@ class VC_svn extends VC {
         return VC_Checkout_svn::get($this, $file->queryFullPath(), $rev);
     }
 
-    function getDiff($file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
+    function &getDiff(&$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
     {
         return VC_Diff_svn::get($this, $file, $rev1, $rev2, $type, $num, $ws);
     }
 
     function &getFileObject($filename, $cache = null, $quicklog = false)
     {
-        $fo = &VC_File_svn::getFileObject($this, $filename, $cache, $quicklog);
-        return $fo;
+        return VC_File_svn::getFileObject($this, $filename, $cache, $quicklog);
     }
 
     function &getAnnotateObject($filename)
     {
-        $blame = new VC_Annotate_svn($this, $filename);
-        return $blame;
+        return $blame = &new VC_Annotate_svn($this, $filename);
     }
 
     function &getPatchsetObject($filename, $cache = null)
     {
-        $po = &VC_Patchset_svn::getPatchsetObject($this, $filename, $cache);
-        return $po;
+        return VC_Patchset_svn::getPatchsetObject($this, $filename, $cache);
     }
 
 }
@@ -83,10 +79,10 @@ class VC_Annotate_svn {
     var $SVN;
     var $tmpfile;
 
-    function VC_Annotate_svn($rep, $file)
+    function VC_Annotate_svn(&$rep, $file)
     {
-        $this->SVN = $rep;
-        $this->file = $file;
+        $this->SVN = &$rep;
+        $this->file = &$file;
     }
 
     function doAnnotate($rev)
@@ -103,9 +99,6 @@ class VC_Annotate_svn {
         $Q = VC_WINDOWS ? '"' : "'";
         $command = $this->SVN->getPath('svn') . ' annotate -r 1:' . $rev . ' ' . $Q . str_replace($Q, '\\' . $Q, $this->file->queryFullPath()) . $Q . ' 2>&1';
         $pipe = popen($command, 'r');
-        if (!$pipe) {
-            return PEAR::raiseError('Failed to execute svn annotate: ' . $command);
-        }
 
         $lines = array();
         $lineno = 1;
@@ -114,7 +107,7 @@ class VC_Annotate_svn {
             if (preg_match('/^\s+(\d+)\s+([\w\.]+)\s(.*)$/', $line, $regs)) {
                 $entry = array();
                 $entry['rev']    = $regs[1];
-                $entry['author'] = trim($regs[2]);
+                $entry['author'] = $regs[2];
                 $entry['date']   = '';
                 $entry['line']   = $regs[3];
                 $entry['lineno'] = $lineno++;
@@ -139,27 +132,20 @@ class VC_Annotate_svn {
 class VC_Checkout_svn {
 
     /**
-     * Static function which returns a file pointing to the head of the requested
-     * revision of an RCS file.
-     * @param fullname Fully qualified pathname of the desired RCS file to checkout
-     * @param rev RCS revision number to check out
-     * @return Either a PEAR_Error object, or a stream pointer to the head of the checkout
-     */
-    function get($rep, $fullname, $rev)
+      * Static function which returns a file pointing to the head of the requested
+      * revision of an RCS file.
+      * @param fullname Fully qualified pathname of the desired RCS file to checkout
+      * @param rev RCS revision number to check out
+      * @return Either a PEAR_Error object, or a stream pointer to the head of the checkout
+      */
+    function get(&$rep, $fullname, $rev)
     {
         if (!VC_Revision::valid($rev)) {
             return PEAR::raiseError('Invalid revision number');
         }
 
-        if (VC_WINDOWS) {
-            $Q = '"';
-            $mode = 'rb';
-        } else {
-            $Q = "'";
-            $mode = 'r';
-        }
-
-        if (!($RCS = popen($rep->getPath('svn') . ' cat -r ' . $rev . ' ' . $Q . str_replace($Q, '\\' . $Q, $fullname) . $Q . ' 2>&1', $mode))) {
+        $Q = VC_WINDOWS ? '"' : "'";
+        if (!($RCS = popen($rep->getPath('svn') . ' cat -r ' . $rev . ' ' . $Q . str_replace($Q, '\\' . $Q, $fullname) . $Q . ' 2>&1', 'r'))) {
             return PEAR::raiseError('Couldn\'t perform checkout of the requested file');
         }
 
@@ -181,20 +167,20 @@ class VC_Diff_svn {
     /**
      * Obtain the differences between two revisions of a file.
      *
-     * @param VC_svn $rep        A repository object.
-     * @param VC_File_svn $file  The desired file.
-     * @param string $rev1       Original revision number to compare from.
-     * @param string $rev2       New revision number to compare against.
-     * @param string $type       The type of diff (e.g. 'unified').
-     * @param integer $num       Number of lines to be used in context and
-     *                           unified diffs.
-     * @param boolean $ws        Show whitespace in the diff?
+     * @param object VC_svn $rep        A repository object.
+     * @param object VC_File_svn $file  The desired file.
+     * @param string  $rev1             Original revision number to compare
+     *                                  from.
+     * @param string  $rev2             New revision number to compare against.
+     * @param string  $type             The type of diff (e.g. 'unified').
+     * @param integer $num              Number of lines to be used in context
+     *                                  and unified diffs.
+     * @param boolean $ws               Show whitespace in the diff?
      *
-     * @return string|boolean  False on failure, or a string containing the
-     *                         diff on success.
+     * @return string|boolean  False on failure, or a string containing the diff
+     *                         on success.
      */
-    function get($rep, $file, $rev1, $rev2, $type = 'context', $num = 3,
-                 $ws = true)
+    function get(&$rep, &$file, $rev1, $rev2, $type = 'context', $num = 3, $ws = true)
     {
         /* Make sure that the file parameter is valid */
         if (is_a($file, 'PEAR_Error')) {
@@ -264,15 +250,14 @@ class VC_Directory_svn {
      * Create a SVN Directory object to store information about the
      * files in a single directory in the repository
      *
-     * @param VC_Repository_svn $rp  The VC_Repository object this directory
-     *                               is part of.
-     * @param string $dn             Path to the directory.
-     * @param VC_Directory_svn $pn   The parent VC_Directory to this one.
+     * @param object VC_Repository_svn $rp  The VC_Repository object this directory is part of.
+     * @param string                   $dn  Path to the directory.
+     * @param object VC_Directory_svn  $pn  (optional) The parent VC_Directory to this one.
      */
-    function VC_Directory_svn($rep, $dn, $pn = '')
+    function VC_Directory_svn(&$rep, $dn, $pn = '')
     {
-        $this->rep = $rep;
-        $this->parent = $pn;
+        $this->rep = &$rep;
+        $this->parent = &$pn;
         $this->moduleName = $dn;
         $this->dirName = "/$dn";
         $this->files = array();
@@ -316,9 +301,6 @@ class VC_Directory_svn {
         $Q = VC_WINDOWS ? '"' : "'" ;
         $cmd = $this->rep->getPath('svn') . ' ls ' . $Q . str_replace($Q, '\\' . $Q, $this->rep->sourceroot() . $this->queryDir()) . $Q . ' 2>&1';
         $dir = popen($cmd, 'r');
-        if (!$dir) {
-            return PEAR::raiseError('Failed to execute svn ls: ' . $cmd);
-        }
 
         /* Create two arrays - one of all the files, and the other of
          * all the dirs. */
@@ -334,18 +316,18 @@ class VC_Directory_svn {
             } elseif (substr($line, -1) == '/') {
                 $this->dirs[] = substr($line, 0, -1);
             } else {
-                $fl = $this->rep->getFileObject($this->queryDir() . "/$line", $cache, $quicklog);
+                $fl = &$this->rep->getFileObject($this->queryDir() . "/$line", $cache, $quicklog);
                 if (is_a($fl, 'PEAR_Error')) {
                     return $fl;
                 } else {
-                    $this->files[] = $fl;
+                    $this->files[] = &$fl;
                 }
             }
         }
 
         pclose($dir);
 
-        if ($errors) {
+        if (count($errors)) {
             return PEAR::raiseError(implode("\n", $errors));
         }
 
@@ -471,9 +453,9 @@ class VC_File_svn extends VC_File {
      *
      * @param string $fl  Full path to this file.
      */
-    function VC_File_svn($rep, $fl, $quicklog = false)
+    function VC_File_svn(&$rep, $fl, $quicklog = false)
     {
-        $this->rep = $rep;
+        $this->rep = &$rep;
         $this->name = basename($fl);
         $this->dir = dirname($fl);
         $this->logs = array();
@@ -484,13 +466,17 @@ class VC_File_svn extends VC_File {
         $this->branches = array();
     }
 
-    function &getFileObject($rep, $filename, $cache = null, $quicklog = false)
+    function &getFileObject(&$rep, $filename, $cache = null, $quicklog = false)
     {
-        /* The version of the cached data. Increment this whenever the
+        /**
+         * The version of the cached data. Increment this whenever the
          * internal storage format changes, such that we must
-         * invalidate prior cached data. */
+         * invalidate prior cached data.
+         *
+         * @var integer $cacheVersion
+         */
         $cacheVersion = 2;
-        $cacheId = $rep->sourceroot() . '_n' . $filename . '_f' . (int)$quicklog . '_v' . $cacheVersion;
+        $cacheId = $filename . '_f' . (int)$quicklog . '_v' . $cacheVersion;
 
         if ($cache &&
             // The file is cached for one hour no matter what, because
@@ -500,7 +486,7 @@ class VC_File_svn extends VC_File {
             $fileOb = unserialize($cache->get($cacheId, 3600));
             $fileOb->setRepository($rep);
         } else {
-            $fileOb = new VC_File_svn($rep, $filename, $quicklog);
+            $fileOb = &new VC_File_svn($rep, $filename, $quicklog);
             $fileOb->setRepository($rep);
             if (is_a(($result = $fileOb->getBrowseInfo()), 'PEAR_Error')) {
                 return $result;
@@ -646,25 +632,21 @@ class VC_File_svn extends VC_File {
      * and dates of the file.
      *
      * @return mixed boolean            True on success,
-     *               PEAR_Error         On error.
+     *               object PEAR_Error  On error.
      */
     function getBrowseInfo()
     {
         /* This doesn't work; need to find another way to simply
-         * request the most recent revision:
-         *
-         * $flag = $this->quicklog ? '-r HEAD ' : ''; */
-        $flag = '';
+		 * request the most recent revision:
+		 *
+		 * $flag = $this->quicklog ? '-r HEAD ' : ''; */
+		$flag = '';
         $Q = VC_WINDOWS ? '"' : "'";
         $cmd = $this->rep->getPath('svn') . ' log -v ' . $flag . $Q . str_replace($Q, '\\' . $Q, $this->queryFullPath()) . $Q . ' 2>&1';
         $pipe = popen($cmd, 'r');
-        if (!$pipe) {
-            return PEAR::raiseError('Failed to execute svn log: ' . $cmd);
-        }
-
         fgets($pipe);
         while (!feof($pipe)) {
-            $log = new VC_Log_svn($this->rep, $this);
+            $log = &new VC_Log_svn($this->rep, $this);
             $err = $log->processLog($pipe);
             if ($err) {
                 $rev = $log->queryRevision();
@@ -672,9 +654,9 @@ class VC_File_svn extends VC_File {
                 $this->revs[] = $rev;
             }
 
-            if ($this->quicklog) {
-                break;
-            }
+			if ($this->quicklog) {
+				break;
+			}
         }
 
         pclose($pipe);
@@ -729,10 +711,10 @@ class VC_Log_svn {
     /**
      * Constructor.
      */
-    function VC_Log_svn($rep, $fl)
+    function VC_Log_svn($rep, &$fl)
     {
         $this->rep = $rep;
-        $this->file = $fl;
+        $this->file = &$fl;
         $this->branches = array();
     }
 
@@ -744,7 +726,7 @@ class VC_Log_svn {
             return false;
         }
 
-        if (preg_match('/^r([0-9]*) \| (.*?) \| (.*) \(.*\) \| ([0-9]*) lines?$/', $line, $matches)) {
+        if (preg_match('/^r([0-9]*) \| ([^ ]*) \| (.*) \(.*\) \| ([0-9]*) lines?$/', $line, $matches)) {
             $this->rev = $matches[1];
             $this->author = $matches[2];
             $this->date = strtotime($matches[3]);
@@ -829,9 +811,11 @@ class VC_Log_svn {
  * @author  Anil Madhavapeddy <anil@recoil.org>
  * @package VC
  */
-class VC_Patchset_svn extends VC_Patchset {
+class VC_Patchset_svn {
 
+    var $_rep;
     var $_file;
+    var $_patchsets = array();
 
     /**
      * Create a patchset object.
@@ -843,13 +827,17 @@ class VC_Patchset_svn extends VC_Patchset {
         $this->_file = $file;
     }
 
-    function &getPatchsetObject($rep, $filename, $cache = null)
+    function &getPatchsetObject(&$rep, $filename, $cache = null)
     {
-        /* The version of the cached data. Increment this whenever the
+        /**
+         * The version of the cached data. Increment this whenever the
          * internal storage format changes, such that we must
-         * invalidate prior cached data. */
+         * invalidate prior cached data.
+         *
+         * @var integer $cacheVersion
+         */
         $cacheVersion = 1;
-        $cacheId = $rep->sourceroot() . '_n' . $filename . '_f_v' . $cacheVersion;
+        $cacheId = $filename . '_f_v' . $cacheVersion;
 
         if ($cache &&
             // The file is cached for one hour no matter what, because
@@ -857,19 +845,20 @@ class VC_Patchset_svn extends VC_Patchset {
             // last changed.
             $cache->exists($cacheId, 3600)) {
             $psOb = unserialize($cache->get($cacheId, 3600));
-            $psOb->setRepository($rep);
         } else {
-            $psOb = new VC_Patchset_svn($filename);
-            $psOb->setRepository($rep);
-            if (is_a(($result = $psOb->getPatchsets()), 'PEAR_Error')) {
-                return $result;
-            }
+            $psOb = &new VC_Patchset_svn($filename);
 
             if ($cache) {
                 $cache->set($cacheId, serialize($psOb));
             }
         }
 
+        $psOb->_rep = &$rep;
+
+        if (is_a(($result = $psOb->getPatchsets($rep)), 'PEAR_Error')) {
+            return $result;
+        }
+
         return $psOb;
     }
 
@@ -877,11 +866,13 @@ class VC_Patchset_svn extends VC_Patchset {
      * Populate the object with information about the patchsets that
      * this file is involved in.
      *
+     * @param string $repository  The full repository location.
+     *
      * @return mixed  PEAR_Error object on error, or true on success.
      */
-    function getPatchsets()
+    function getPatchsets($repository)
     {
-        $fileOb = new VC_File_svn($this->_rep, $this->_file);
+        $fileOb = &new VC_File_svn($this->_rep, $this->_file);
         if (is_a(($result = $fileOb->getBrowseInfo()), 'PEAR_Error')) {
             return $result;
         }
