@@ -26,9 +26,9 @@ define('VCARD_GEO_LON',      1);
 /**
  * Class representing vCard entries.
  *
- * $Horde: framework/iCalendar/iCalendar/vcard.php,v 1.3.10.11 2007/03/15 18:32:23 jan Exp $
+ * $Horde: framework/iCalendar/iCalendar/vcard.php,v 1.3.10.2 2005/01/16 23:10:41 chuck Exp $
  *
- * Copyright 2003-2007 Karsten Fourmont (karsten@horde.org)
+ * Copyright 2003-2005 Karsten Fourmont (karsten@horde.org)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -38,11 +38,6 @@ define('VCARD_GEO_LON',      1);
  */
 class Horde_iCalendar_vcard extends Horde_iCalendar {
 
-    function Horde_iCalendar_vcard($version = '2.1')
-    {
-        return parent::Horde_iCalendar($version);
-    }
-
     function getType()
     {
         return 'vcard';
@@ -60,10 +55,10 @@ class Horde_iCalendar_vcard extends Horde_iCalendar {
     function exportvCalendar()
     {
         $requiredAttributes['BODY'] = '';
-        $requiredAttributes['VERSION'] = $this->_version;
+        $requiredAttributes['VERSION'] = '2.1';
 
         foreach ($requiredAttributes as $name => $default_value) {
-            if (is_a($this->getAttribute($name), 'PEAR_Error')) {
+            if (is_a($this->getattribute($name), 'PEAR_Error')) {
                 $this->setAttribute($name, $default_value);
             }
         }
@@ -79,7 +74,8 @@ class Horde_iCalendar_vcard extends Horde_iCalendar {
      * to
      *   "Professor Dagobert T Duck Sen"
      *
-     * @return string  Full name of vcard "N" tag or null if no N tag.
+     * @return string  Full name of vcard "N" tag
+     *                 or null if no N tag.
      */
     function printableName()
     {
@@ -88,8 +84,6 @@ class Horde_iCalendar_vcard extends Horde_iCalendar {
             return null;
         }
 
-        $name_arr = array();
-
         if (!empty($name_parts[VCARD_N_PREFIX])) {
             $name_arr[] = $name_parts[VCARD_N_PREFIX];
         }
@@ -118,20 +112,16 @@ class Horde_iCalendar_vcard extends Horde_iCalendar {
      */
     function getBareEmail($address)
     {
-        // Empty values are still empty.
-        if (!$address) {
-            return $address;
-        }
-
         require_once 'Mail/RFC822.php';
         require_once 'Horde/MIME.php';
 
         static $rfc822;
         if (is_null($rfc822)) {
-            $rfc822 = new Mail_RFC822();
+            $rfc822 = &new Mail_RFC822();
         }
 
         $rfc822->validateMailbox($address);
+
         return MIME::rfc822WriteAddress($address->mailbox, $address->host);
     }
 
