@@ -5,15 +5,16 @@ require_once 'Net/IMSP.php';
 /**
  * The Net_IMSP_Auth class abstract class for IMSP authentication.
  *
- * Required Parameters:<pre>
- *   'username'  Username to logon to IMSP server as.
- *   'password'  Password for current user.
- *   'server'    The hostname of the IMSP server.
- *   'port'      The port of the IMSP server.</pre>
+ * Required Parameters:
+ * ====================
+ * 'username'       -- Username to logon to IMSP server as.
+ * 'password'       -- Password for current user.
+ * 'server'         -- The hostname of the IMSP server.
+ * 'port'           -- The port of the IMSP server.
  *
- * $Horde: framework/Net_IMSP/IMSP/Auth.php,v 1.8.10.11 2006/01/01 21:28:27 jan Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Auth.php,v 1.8.10.4 2005/03/09 18:26:56 mrubinsk Exp $
  *
- * Copyright 2003-2006 Michael Rubinsky <mrubinsk@horde.org>
+ * Copyright 2003-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -24,17 +25,16 @@ require_once 'Net/IMSP.php';
 class Net_IMSP_Auth {
     /**
      * Class variable to hold the resulting Net_IMSP object
-     *
-     * @var Net_IMSP
+     * @var Net_IMSP object $_imsp
      */
     var $_imsp;
 
      /**
      * Attempts to login to IMSP server.
      *
+     * @access public
      * @param array $params         Parameters for Net_IMSP
      * @param boolean $login        Should we remain logged in after auth?
-     *
      * @return mixed                Returns a Net_IMSP object connected to
      *                              the IMSP server if login is true and
      *                              successful.  Returns boolean true if
@@ -61,19 +61,18 @@ class Net_IMSP_Auth {
      * Private authentication function. Provides actual authentication
      * code.
      *
+     * @abstract
      * @access private
      * @param  array   $params      Parameters for Net_IMSP_Auth driver.
-     *
      * @return mixed                Returns Net_IMSP object connected to server
      *                              if successful, PEAR_Error on failure.
-     * @abstract
      */
     function &_authenticate($params)
     {
 
     }
-
     /**
+     * Attempts to return a concrete Net_IMSP_Auth instance based on $driver
      * Returns the type of this driver.
      *
      * @abstract
@@ -94,11 +93,10 @@ class Net_IMSP_Auth {
     }
 
     /**
-     * Attempts to return a concrete Net_IMSP_Auth instance based on $driver
      * Must be called as &Net_IMSP_Auth::factory()
      *
+     * @access public
      * @param  string $driver Type of Net_IMSP_Auth subclass to return.
-     *
      * @return mixed  The created Net_IMSP_Auth subclass or PEAR_Error.
      */
     function &factory($driver)
@@ -106,8 +104,7 @@ class Net_IMSP_Auth {
         $driver = basename($driver);
 
         if (empty($driver) || (strcmp($driver, 'none') == 0)) {
-            $auth = &new IMSP_Auth();
-            return $auth;
+            return $ret = &new IMSP_Auth();
         }
 
         if (file_exists(dirname(__FILE__) . '/Auth/' . $driver . '.php')) {
@@ -117,10 +114,9 @@ class Net_IMSP_Auth {
         $class = 'Net_IMSP_Auth_' . $driver;
 
         if (class_exists($class)) {
-            $auth = &new $class();
-            return $auth;
+            return $ret = &new $class();
         } else {
-            Horde::fatal(PEAR::raiseError(sprintf(_("Unable to load the definition of %s."), $class)), __FILE__, __LINE__);
+           Horde::fatal(PEAR::raiseError(sprintf(_("Unable to load the definition of %s."), $class)), __FILE__, __LINE__);
         }
     }
 
@@ -131,22 +127,12 @@ class Net_IMSP_Auth {
      * Must be called like: $var = &Net_IMSP_Auth::singleton('driver_type');
      *
      * @param  string $driver Type of IMSP_Auth subclass to return.
-     *
      * @return object Reference to IMSP_Auth subclass.
      */
     function &singleton($driver)
     {
         static $instances;
-        /* Check for any imtest driver instances and kill them.
-           Otherwise, the socket will hang between requests from
-           seperate drivers (an Auth request and an Options request).*/
-        if (is_array($instances)) {
-            foreach ($instances as $obj) {
-                if ($obj->getDriverType() == 'imtest') {
-                    $obj->logout();
-                }
-            }
-        }
+
         if (!isset($instances)) {
             $instances = array();
         }
