@@ -20,14 +20,15 @@ define('IMSP_ACL_RIGHTS', 'lrwcda');
  * Net_IMSP_Book Class - provides api for dealing with IMSP
  * addressbooks.
  *
- * Required parameters:<pre>
- *   'username'     Username to logon to IMSP server as.
- *   'password'     Password for current user.
- *   'auth_method'  The authentication method to use to login.
- *   'server'       The hostname of the IMSP server.
- *   'port'         The port of the IMSP server.</pre>
+ * Required parameters:
+ * =====================
+ * 'username'       -- Username to logon to IMSP server as.
+ * 'password'       -- Password for current user.
+ * 'auth_method'    -- The authentication method to use to login.
+ * 'server'         -- The hostname of the IMSP server.
+ * 'port'           -- The port of the IMSP server.
  *
- * $Horde: framework/Net_IMSP/IMSP/Book.php,v 1.16.2.15 2005/09/29 00:40:59 selsky Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Book.php,v 1.16.2.6 2005/03/11 02:24:22 mrubinsk Exp $
  *
  * Copyright 2002-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
@@ -39,26 +40,14 @@ define('IMSP_ACL_RIGHTS', 'lrwcda');
  */
 class Net_IMSP_Book {
 
-    /**
-     * Sort order.
-     *
-     * @var string
-     */
     var $sort = 'ascend';
-
-    /**
-     * Net_IMSP object.
-     *
-     * @var Net_IMSP
-     */
     var $_imsp;
-
-    /**
-     * Parameter list.
-     *
-     * @var array
-     */
-    var $_params;
+    var $user = '';
+    var $pass = '';
+    var $auth_method = '';
+    var $server = '';
+    var $port = '';
+    var $params;
 
     /**
      * Constructor function.
@@ -67,20 +56,21 @@ class Net_IMSP_Book {
      */
     function Net_IMSP_Book($params)
     {
-        $this->_params = $params;
+        $this->params = $params;
     }
 
     /**
      * Initialization function to be called after object is returned.
      * This allows errors to occur and not break the script.
      *
+     * @access public
      * @return mixed  True on success PEAR_Error on failure.
      */
     function init()
     {
         if (!isset($this->_imsp)) {
-            $auth = &Net_IMSP_Auth::singleton($this->_params['auth_method']);
-            $this->_imsp = $auth->authenticate($this->_params);
+            $auth = &Net_IMSP_Auth::singleton($this->params['auth_method']);
+            $this->_imsp = $auth->authenticate($this->params);
         }
 
         if (is_a($this->_imsp, 'PEAR_Error')) {
@@ -95,6 +85,7 @@ class Net_IMSP_Book {
      * Returns an array containing the names of all the addressbooks
      * available to the logged in user.
      *
+     * @access public
      * @return mixed Array of addressbook names or PEAR_Error.
      */
     function getAddressBookList()
@@ -115,7 +106,7 @@ class Net_IMSP_Book {
         }
         $abooks = array();
 
-        while (preg_match("/^\* ADDRESSBOOK/", $server_response)) {
+        while (preg_match("/^\* ADDRESSBOOK/", $server_response)){
             /* If this is an ADDRESSBOOK response, then this will explode as so:
              * [0] and [1] can be discarded
              * [2] = attributes
@@ -155,8 +146,7 @@ class Net_IMSP_Book {
                                            __FILE__, __LINE__);
         }
 
-        $this->_imsp->writeToLog('ADDRESSBOOK command OK.', __FILE__, __LINE__,
-                                  PEAR_LOG_INFO);
+        $this->_imsp->writeToLog('ADDRESSBOOK command OK.', '', '', PEAR_LOG_DEBUG);
         return $abooks;
     }
 
@@ -164,6 +154,7 @@ class Net_IMSP_Book {
      * Returns an array containing the names that match $search
      * critera in the addressbook named $abook.
      *
+     * @access public
      * @param string $abook Addressbook name to search.
      * @param string Array $search Search criteria in the form of
      *        'fieldName' => 'searchTerm' (may include * wild card).
@@ -211,14 +202,14 @@ class Net_IMSP_Book {
 
         $count = count($criteria);
         $current = 1;
-        foreach ($criteria as $search_field => $search) {
+        foreach ($criteria as $search_field => $search){
             $result = $this->_imsp->imspSend(" $search_field ", false, false);
             if (is_a($result, 'PEAR_Error')) {
                 return $result;
             }
 
             // How about the search term as a {}.
-            if (preg_match(IMSP_MUST_USE_LITERAL, $search)) {
+            if (preg_match(IMSP_MUST_USE_LITERAL, $search)){
                 $biSearch = sprintf("{%d}", strlen($search));
 
                 $result = $this->_imsp->imspSend($biSearch, false, true);
@@ -231,7 +222,7 @@ class Net_IMSP_Book {
                 }
                 if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE, $result)) {
                     return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                                   __FILE__, __LINE__);
+                                                   __FILE__,__LINE__);
                 }
 
                 $result = $this->_imsp->imspSend($search, false, $current == $count);
@@ -253,7 +244,7 @@ class Net_IMSP_Book {
         $server_response = $this->_imsp->imspReceive();
         $abookNames = Array();
 
-        while (preg_match("/^\* SEARCHADDRESS/", $server_response)) {
+        while (preg_match("/^\* SEARCHADDRESS/", $server_response)){
             $chopped_response =
                 preg_replace("/^\* SEARCHADDRESS/", '', $server_response);
 
@@ -293,8 +284,7 @@ class Net_IMSP_Book {
             return $abookNames;
         }
 
-        $this->_imsp->writeToLog('SEARCHADDRESS command OK', __FILE__, __LINE__,
-                                 PEAR_LOG_INFO);
+        $this->_imsp->writeToLog('SEARCHADDRESS command OK', '', '', PEAR_LOG_DEBUG);
 
         // Determine the sort direction and perform the sort.
         switch ($this->sort) {
@@ -314,6 +304,7 @@ class Net_IMSP_Book {
      * Returns an associative array of a single addressbook entry.
      * Note that there will always be a 'name' field.
      *
+     * @access public
      * @param string $abook Name of the addressbook to search.
      * @param string $entryName 'name' attribute of the entry to retrieve
      * @return mixed Array containing entry or PEAR_Error on failure / no match.
@@ -336,7 +327,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
         }
 
@@ -356,7 +347,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
             $result = $this->_imsp->imspSend($entryName, false, true);
@@ -372,11 +363,11 @@ class Net_IMSP_Book {
 
         $server_response = $this->_imsp->imspReceive();
 
-        switch ($server_response) {
+        switch($server_response) {
         case 'BAD':
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
         case 'NO':
-            return $this->_imsp->imspError(IMSP_ENTRY_NOT_FOUND,__FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_ENTRY_NOT_FOUND,__FILE__,__LINE__);
         }
 
         // Get the data in an associative array.
@@ -385,19 +376,19 @@ class Net_IMSP_Book {
         //Get the next server response -- this *should* be the OK response.
         $server_response = $this->_imsp->imspReceive();
 
-        if ($server_response != 'OK') {
+        if($server_response != 'OK'){
             // Unexpected response throw error but still continue on.
-            $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,__FILE__, __LINE__);
+            $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,__FILE__,__LINE__);
         }
 
-        $this->_imsp->writeToLog('FETCHADDRESS completed OK', __FILE__, __LINE__,
-                                  PEAR_LOG_INFO);
+        $this->_imsp->writeToLog('FETCHADDRESS completed OK', '', '',
+                                  PEAR_LOG_DEBUG);
         return $entry;
     }
 
     /**
      * Creates a new addressbook.
-     *
+     * @access public
      * @param string $abookName FULLY QUALIFIED name such 'jdoe.clients' etc...
      * @return mixed True on success / PEAR_Error on failure.
      */
@@ -440,33 +431,34 @@ class Net_IMSP_Book {
 
         switch ($server_response) {
         case 'OK':
-            $this->_imsp->writeToLog('CREATEADDRESSBOOK completed OK', __FILE__,
-                                     __LINE__, PEAR_LOG_INFO);
+            $this->_imsp->writeToLog('CREATEADDRESSBOOK completed OK', '',
+                                     '', PEAR_LOG_DEBUG);
             return true;
 
         case 'NO':
             // Could not create abook.
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
 
         default:
             // Something unexpected.
             return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                           __FILE__, __LINE__);
+                                           __FILE__,__LINE__);
         }
     }
 
     /**
      * Deletes an addressbook completely!
      *
+     * @access public
      * @param string $abookName Name of addressbook to delete.
      * @return mixed true on success / PEAR_Error on failure
      */
     function deleteAddressBook($abookName)
     {
-        $command_text = 'DELETEADDRESSBOOK ';
+        $command_text = 'DELETEADDRESSBOOK ' ;
 
         // Check need for {}.
         if (preg_match(IMSP_MUST_USE_LITERAL, $abookName)) {
@@ -487,7 +479,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             } else {
                 $result = $this->_imsp->imspSend($abookName, false, true);
                 if (is_a($result, 'PEAR_Error')) {
@@ -497,33 +489,33 @@ class Net_IMSP_Book {
         }
 
         $server_response = $this->_imsp->imspReceive();
-        if (is_a($server_response, 'PEAR_Error')) {
+        if (is_a($server_response, 'PEAR_Error')){
             return $server_response;
         }
 
         switch ($server_response) {
         case 'OK':
-            $this->_imsp->writeToLog('DELETEADDRESSBOOK completed OK', __FILE__,
-                                     __LINE__, PEAR_LOG_INFO);
+            $this->_imsp->writeToLog('DELETEADDRESSBOOK completed OK', '',
+                                     '', PEAR_LOG_DEBUG);
             return true;
 
         case 'NO':
             // Could not DELETE abook.
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
 
         default:
             // Something unexpected.
-            return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE, __FILE__,
-                                           __LINE__);
+            return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,__FILE__,__LINE__);
         }
     }
 
     /**
      * Renames an addressbook.
      *
+     * @access public
      * @param string $abookOldName Old name.
      * @param string $abookNewName New addressbook name.
      * @return mixed True / PEAR_Error
@@ -573,7 +565,7 @@ class Net_IMSP_Book {
 
         switch ($server_response) {
         case 'NO':
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
             // Syntax problem.
@@ -581,19 +573,18 @@ class Net_IMSP_Book {
 
         case 'OK':
             $this->_imsp->writeToLog("Addressbook $abookOldName successfully
-                                      changed to $abookNewName", __FILE__,
-                                      __LINE__, PEAR_LOG_INFO);
+                                      changed to $abookNewName");
             return true;
 
         default:
-            return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE, __FILE__,
-                                           __LINE__);
+            return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,__FILE__,__LINE__);
         }
     }
 
     /**
      * Adds an addressbook entry to an addressbook.
      *
+     * @access public
      * @param string $abook Name of addressbook to add entry to.
      * @param array Addressbook entry information -
      *              there MUST be a field 'name' containing the entry name.
@@ -604,7 +595,7 @@ class Net_IMSP_Book {
         $command_text = '';
 
         if (getType($entryInfo) != 'array') {
-            return $this->_imsp->imspError(IMSP_BAD_ARGUMENT, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_BAD_ARGUMENT,__FILE__,__LINE__);
         }
 
         // Lock the entry if it already exists.
@@ -665,7 +656,7 @@ class Net_IMSP_Book {
                     if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                                     $server_response)) {
                         return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                                       __FILE__, __LINE__);
+                                                __FILE__,__LINE__);
                     }
 
                     // Send the string of octets and be sure NOT to
@@ -688,12 +679,11 @@ class Net_IMSP_Book {
         switch ($server_response) {
         case 'NO':
             //Sorry...can not do it.
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
             //Sorry...did not understand you
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__,
-                                           __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
         }
 
         if ($server_response != 'OK') {
@@ -706,19 +696,18 @@ class Net_IMSP_Book {
 
             switch ($server_response) {
             case 'NO':
-                return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+                return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
             case 'BAD':
-                return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__,
-                                               __LINE__);
+                return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
             case 'OK':
-                $this->_imsp->writeToLog('STOREADDRESS Completed successfully.',
-                                         __FILE__, __LINE__, PEAR_LOG_INFO);
+                $this->_imsp->writeToLog('STOREADDRESS Completed
+                                          successfully.', '', '',
+                                          PEAR_LOG_DEBUG);
 
                 //we were successful...so release the lock on the entry
                 if (!$this->unlockEntry($abook, $entryInfo['name'])) {
                     //could not release lock
-                    return $this->_imsp->imspError(IMSP_ENTRY_LOCKED, __FILE__,
-                                                   __LINE__);
+                    return $this->_imsp->imspError(IMSP_ENTRY_LOCKED,__FILE__,__LINE__);
                 }
 
                 return true;
@@ -729,6 +718,7 @@ class Net_IMSP_Book {
     /**
      * Deletes an abook entry.
      *
+     * @access public
      * @param string $abook Name of addressbook containing entry.
      * @param string $bookEntry Name of entry to delete.
      * @return mixed True on success / PEAR_Error on failure.
@@ -751,7 +741,7 @@ class Net_IMSP_Book {
                             $this->_imsp->imspReceive())) {
 
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
         }
@@ -767,7 +757,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
         } else {
@@ -780,21 +770,21 @@ class Net_IMSP_Book {
         switch ($server_response) {
         case 'NO':
             //Sorry..can not do it
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
         case 'BAD':
             //Do not know what your talking about
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__,
-                                           __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
         case 'OK':
-            $this->_imsp->writeToLog('DELETE Completed successfully.', __FILE__,
-                                     __LINE__, PEAR_LOG_INFO);
+            $this->_imsp->writeToLog('DELETE Completed successfully.', '',
+                                      '', PEAR_LOG_DEBUG);
             return true;
         }
     }
 
     /**
-     * Attempts to acquire a semaphore on the addressbook entry.
+     * Attempts to acquire a semephore on the addressbook entry.
      *
+     * @access public
      * @param string $abook Addressbook name
      * @param string $bookEntry Name of entry to lock
      * @return mixed true or array on success and PEAR_Error on failure
@@ -816,7 +806,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
         }
 
@@ -831,7 +821,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
             $this->_imsp->imspSend($bookEntry, false, true);
@@ -845,14 +835,13 @@ class Net_IMSP_Book {
 
         do {
 
-            switch ($server_response) {
+            switch($server_response) {
 
             case 'NO':
                 return $this->_imsp->imspError(IMSP_ENTRY_LOCKED,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             case 'BAD':
-                return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__,
-                                               __LINE__);
+                return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
             }
 
             //Check to see if this is a FETCHADDRESS resonse
@@ -862,10 +851,10 @@ class Net_IMSP_Book {
                 $server_response = $this->_imsp->imspReceive();
             }
 
-        } while ($server_response != 'OK');
+        } while($server_response != 'OK');
 
         $this->_imsp->writeToLog("LOCK ADDRESSBOOK on $abook $bookEntry OK",
-                                 __FILE__, __LINE__, PEAR_LOG_INFO);
+                                  '', '', PEAR_LOG_DEBUG);
 
         // Return either true or the FETCHADDRESS response if it exists.
         if (!$dummy) {
@@ -878,6 +867,7 @@ class Net_IMSP_Book {
     /**
      * Unlocks a previously locked addressbook.
      *
+     * @access public
      * @param string $abook Name of addressbook containing locked entry.
      * @param string $bookEntry Name of entry to unlock.
      * @return mixed True on success, PEAR_Error on failure.
@@ -899,7 +889,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
         }
@@ -914,7 +904,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
             $this->_imsp->imspSend($bookEntry, false, true);
@@ -928,14 +918,14 @@ class Net_IMSP_Book {
 
         switch ($response) {
         case 'NO':
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
 
         case 'OK':
-            $this->_imsp->writeToLog("UNLOCK ADDRESSBOOK on $abook $bookEntry OK",
-                                     __FILE__, __LINE__, PEAR_LOG_INFO);
+            $this->_imsp->writeToLog("UNLOCK ADDRESSBOOK on $abook $bookEntry
+                                      OK", '', '', PEAR_LOG_DEBUG);
             return true;
         }
     }
@@ -945,7 +935,7 @@ class Net_IMSP_Book {
      *
      * The following characters are recognized ACL characters: lrwcda
      * l - "lookup"  (see the name and existence of the addressbook)
-     * r - "read"    (search and retrieve addresses from addressbook)
+     * r - "read"    (search and retreive addresses from addressbook)
      * w - "write"   (create/edit new addressbook entries - not delete)
      * c - "create"  (create new addressbooks under the current addressbook)
      * d - "delete"  (delete entries or entire book)
@@ -960,6 +950,7 @@ class Net_IMSP_Book {
     /**
      * Sets an Access Control List for an abook.
      *
+     * @access public
      * @param string $abook Name of addressbook.
      * @param string $ident Name of user for this acl.
      * @param string $acl acl for this user/book.
@@ -970,7 +961,7 @@ class Net_IMSP_Book {
         // Verify that $acl looks good.
         if (preg_match("/[^" . IMSP_ACL_RIGHTS . "]/", $acl)) {
             //error...acl list contained unrecoginzed options
-            return $this->_imsp->imspError(IMSP_BAD_ARGUMENT, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_BAD_ARGUMENT,__FILE__,__LINE__);
         }
 
         // Begin sending command.
@@ -987,7 +978,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
         }
@@ -1002,7 +993,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
         }
@@ -1016,21 +1007,21 @@ class Net_IMSP_Book {
         switch ($response) {
         case 'NO':
             // Could not set ACL.
-            return $this->_imsp->imspError(IMSP_NO,__FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
             // Bad syntax.
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
 
         case 'OK':
             $this->_imsp->writeToLog("ACL set for $ident on $abook",
-                                      __FILE__, __LINE__, PEAR_LOG_DEBUG);
+                                      '', '', PEAR_LOG_DEBUG);
             return true;
 
         default:
             // Do not know why we would make it down here.
             return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                           __FILE__, __LINE__);
+                                           __FILE__,__LINE__);
         }
     }
 
@@ -1056,7 +1047,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
         }
 
@@ -1065,14 +1056,14 @@ class Net_IMSP_Book {
         // Get results.
         $response = $this->_imsp->imspReceive();
 
-        switch ($response) {
+        switch($response) {
         case 'NO':
             // Could not complete?
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
             // Do not know what you said!
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
         }
 
         // If we are here, we need to receive the * ACL Responses.
@@ -1121,11 +1112,11 @@ class Net_IMSP_Book {
         if ($response != 'OK') {
             //some weird problem
             return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                           __FILE__, __LINE__);
+                                           __FILE__,__LINE__);
         }
 
-        $this->_imsp->writeToLog("GETACL on $abook completed.", __FILE__,
-                                 __LINE__, PEAR_LOG_INFO);
+        $this->_imsp->writeToLog("GETACL on $abook completed.", '', '',
+                                  PEAR_LOG_DEBUG);
         return $results;
 
     }
@@ -1133,6 +1124,7 @@ class Net_IMSP_Book {
     /**
      * Deletes an ACL entry for an abook.
      *
+     * @access public
      * @param string $abook Name of the addressbook.
      * @param string $ident Name of entry to remove acl for.
      * @return mixed true on success, PEAR_Error on failure.
@@ -1152,7 +1144,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
         }
@@ -1167,7 +1159,7 @@ class Net_IMSP_Book {
             if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
                 return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
-                                               __FILE__, __LINE__);
+                                               __FILE__,__LINE__);
             }
 
             $this->_imsp->imspSend($ident, false, true);
@@ -1178,21 +1170,21 @@ class Net_IMSP_Book {
         // Get results.
         $server_response = $this->_imsp->imspReceive();
 
-        switch ($response) {
+        switch($response) {
         case 'NO':
-            return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_NO,__FILE__,__LINE__);
 
         case 'BAD':
-            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR, __FILE__, __LINE__);
+            return $this->_imsp->imspError(IMSP_SYNTAX_ERROR,__FILE__,__LINE__);
 
         case 'OK':
             $this->_imsp->writeToLog("DELETED ACL for $ident on $abook",
-                                      __FILE__, __LINE__, PEAR_LOG_INFO);
+                                      '', '', PEAR_LOG_DEBUG);
             return true;
 
         default:
             return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
-                                           __FILE__, __LINE__);
+                                           __FILE__,__LINE__);
         }
     }
 
@@ -1225,7 +1217,7 @@ class Net_IMSP_Book {
         $this->_imsp->imspSend($abook, false, true);
         $server_response = $this->_imsp->imspReceive();
 
-        switch ($server_response) {
+        switch($server_response) {
         case 'NO':
             return $this->_imsp->imspError(IMSP_NO, __FILE__, __LINE__);
 
@@ -1275,7 +1267,7 @@ class Net_IMSP_Book {
                                            __FILE__, __LINE__);
         } else {
             $this->_imsp->writeToLog("MYRIGHTS on $abook completed.",
-                                      __FILE__, __LINE__, PEAR_LOG_INFO);
+                                      '', '', PEAR_LOG_DEBUG);
             return $acl;
         }
     }
@@ -1291,7 +1283,7 @@ class Net_IMSP_Book {
         if (isset($this->_imsp)) {
             return $this->_imsp->setLogger($params);
         } else {
-            return PEAR::raiseError(_("The IMSP log could not be initialized."));
+            return PEAR::raiseError('The IMSP log could not be initialized.');
         }
     }
 
@@ -1308,8 +1300,9 @@ class Net_IMSP_Book {
         $abook = '';
         
         if (!preg_match("/^\* FETCHADDRESS /", $server_response)) {
-            $this->_imsp->writeToLog('[ERROR] Did not receive a FETCHADDRESS response from server.',
-                                     __FILE__, __LINE__, PEAR_LOG_ERR);
+            $this->_imsp->writeToLog('[ERROR] Did not receive a FETCHADDRESS
+                                         response from server.', '', '',
+                                     PEAR_LOG_ERR);
 
             $this->_imsp->exitCode = IMSP_UNEXPECTED_RESPONSE;
             return false;
@@ -1345,7 +1338,9 @@ class Net_IMSP_Book {
             $chopped_response = trim(preg_replace("/^\* FETCHADDRESS /",
                                                   '', $server_response));
         }
+
         $parts = explode(' ', $chopped_response);
+
         /* If abook was sent as a {} then we must 'push' a blank
          * value to the start of this array so the rest of the routine
          * will work with the correct indexes. */
@@ -1379,7 +1374,7 @@ class Net_IMSP_Book {
             for ($i = $firstNameIdx + 1; $i < $numOfParts; $i++) {
                 $name .=  ' ' . $parts[$i];
                 $lastChar = substr($parts[$i], strlen($parts[$i]) - 1,1);
-                if ($lastChar == "\"") {
+                if($lastChar == "\""){
                     $name = rtrim($name, "\"");
                     $nextKey = $i + 1;
                     break;
@@ -1397,7 +1392,7 @@ class Net_IMSP_Book {
             /* If only one chunk for 'name' then we just have to point
             * to the next chunk in the array...which will hopefully
             * be '2' */
-            $nextKey = $firstNameIdx + 1;
+            $nextKey = 2;
         }
 
         $lastChar = '';
@@ -1474,6 +1469,7 @@ class Net_IMSP_Book {
                 }
             }
         }
+
         return $entry;
     }
 
