@@ -6,66 +6,63 @@ require_once 'Net/IMSP/Auth.php';
  * Net_IMSP_Options Class - provides an interface to IMSP server-based
  * options storage.
  *
- * Required parameters:<pre>
- *   'username'     Username to logon to IMSP server as.
- *   'password'     Password for current user.
- *   'auth_method'  The authentication method to use to login.
- *   'server'       The hostname of the IMSP server.
- *   'port'         The port of the IMSP server.</pre>
+ * Required parameters:
+ * ====================
+ * 'username'       -- Username to logon to IMSP server as.
+ * 'password'       -- Password for current user.
+ * 'auth_method'    -- The authentication method to use to login.
+ * 'server'         -- The hostname of the IMSP server.
+ * 'port'           -- The port of the IMSP server.
  *
- * $Horde: framework/Net_IMSP/IMSP/Options.php,v 1.3.2.19 2008/01/02 11:30:45 jan Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Options.php,v 1.3.2.5 2005/03/09 18:26:56 mrubinsk Exp $
  *
- * Copyright 2004-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2004-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
+ * @version $Revision: 1.3.2.5 $
  * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Net_IMSP
  */
 class Net_IMSP_Options {
 
-    /**
-     * Net_IMSP object.
-     *
-     * @var Net_IMSP
-     */
     var $_imsp;
-
-    /**
-     * Parameter list.
-     *
-     * @var array
-     */
-    var $_params;
+    var $user        = '';
+    var $pass        = '';
+    var $auth_method = '';
+    var $server      = '';
+    var $port        = '';
+    var $params;
 
     /**
      * Constructor function.
      *
-     * @param array $params  Hash containing IMSP parameters.
+     * @access public
+     * @param array $params Hash containing IMSP parameters.
      */
     function Net_IMSP_Options($params)
     {
-        $this->_params = $params;
+        $this->params = $params;
     }
 
     /**
      * Initialization function to be called after object is returned.
      * This allows errors to occur and not break the script.
      *
+     * @access public
      * @return mixed  True on success PEAR_Error on failure.
      */
     function init()
     {
         if (!isset($this->_imsp)) {
-            $auth = &Net_IMSP_Auth::singleton($this->_params['auth_method']);
-            $this->_imsp = $auth->authenticate($this->_params);
+            $auth = &Net_IMSP_Auth::singleton($this->params['auth_method']);
+            $this->_imsp = $auth->authenticate($this->params);
         }
 
         if (is_a($this->_imsp, 'PEAR_Error')) {
             return $this->_imsp;
         }
-
         $this->_imsp->writeToLog('Net_IMSP_Options initialized.', __FILE__,
                                  __LINE__, PEAR_LOG_DEBUG);
         return true;
@@ -74,9 +71,9 @@ class Net_IMSP_Options {
     /**
      * Function sends a GET command to IMSP server and retrieves values.
      *
+     * @access public
      * @param  string $optionName Name of option to retrieve. Accepts '*'
      *                            as wild card.
-     *
      * @return mixed  Associative array containing option=>value pairs or
      *                PEAR_Error.
      */
@@ -93,9 +90,9 @@ class Net_IMSP_Options {
             return $server_response;
         }
 
-        while (preg_match("/^\* OPTION/", $server_response)) {
+        while (preg_match("/^\* OPTION/", $server_response)){
             /* First, check for a {}. */
-            if (preg_match(IMSP_OCTET_COUNT, $server_response, $tempArray)) {
+            if (preg_match(IMSP_OCTET_COUNT, $server_response, $tempArray)){
                 $temp = explode(' ', $server_response);
                 $options[$temp[2]] = $this->_imsp->receiveStringLiteral($tempArray[2]);
                 $this->_imsp->imspReceive();
@@ -138,7 +135,7 @@ class Net_IMSP_Options {
         }
 
         if ($server_response != 'OK') {
-            return $this->_imsp->imspError('Did not receive the expected response from the server.',
+            return $this->_imsp->imspError(IMSP_UNEXPECTED_RESPONSE,
                                            __FILE__, __LINE__);
         }
 
@@ -149,9 +146,9 @@ class Net_IMSP_Options {
     /**
      * Function sets an option value on the IMSP server.
      *
-     * @param string $optionName  Name of option to set.
+     * @access public
+     * @param string $optionName Name of option to set.
      * @param string $optionValue Value to assign.
-     *
      * @return mixed True or PEAR_Error.
      */
     function set($optionName, $optionValue)
@@ -167,9 +164,9 @@ class Net_IMSP_Options {
                 return $result;
             }
 
-            if (!preg_match("/^\+/",
+            if (!preg_match(IMSP_COMMAND_CONTINUATION_RESPONSE,
                             $this->_imsp->imspReceive())) {
-                return $this->_imsp->imspError('Did not receive expected command continuation response from IMSP server.',
+                return $this->_imsp->imspError(IMSP_NO_CONTINUATION_RESPONSE,
                                                __FILE__, __LINE__);
             }
         }
@@ -195,8 +192,8 @@ class Net_IMSP_Options {
     /**
      * Sets the log information in the Net_IMSP object.
      *
-     * @param array $params  The log parameters.
-     *
+     * @access public
+     * @param array The log parameters.
      * @return mixed  True on success PEAR_Error on failure.
      */
     function setLogger($params)
@@ -207,10 +204,10 @@ class Net_IMSP_Options {
             return $this->_imsp->imspError('The IMSP log could not be initialized.');
         }
     }
-
     function logout()
     {
         $this->_imsp->logout();
     }
 
+
 }
