@@ -1,16 +1,17 @@
 <?php
 /**
- * Net_SMS_clickatell_http Class implements the HTTP API for accessing the
- * Clickatell (www.clickatell.com) SMS gateway.
+ * Net_SMS_clickatell_http Class implements the HTTP API for accessing
+ * the Clickatell (www.clickatell.com) SMS gateway.
  *
- * Copyright 2003-2007 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
  *
- * See the enclosed file COPYING for license information (LGPL). If you did
- * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you did not
+ * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/Net_SMS/SMS/clickatell_http.php,v 1.13.10.11 2007/01/02 13:54:29 jan Exp $
+ * $Horde: framework/Net_SMS/SMS/clickatell_http.php,v 1.13.10.1 2005/01/03 12:19:09 jan Exp $
  *
  * @author Marko Djukic <marko@oblo.com>
+ * @version $Revision: 1.13.10.1 $
  * @package Net_SMS
  */
 class Net_SMS_clickatell_http extends Net_SMS {
@@ -20,7 +21,7 @@ class Net_SMS_clickatell_http extends Net_SMS {
 
     /**
      * An array of capabilities, so that the driver can report which operations
-     * it supports and which it doesn't. Possible values are:<pre>
+     * it supports and which it doesn't. Possible values are:
      *   auth        - The gateway require authentication before sending;
      *   batch       - Batch sending is supported;
      *   multi       - Sending of messages to multiple recipients is supported;
@@ -28,9 +29,8 @@ class Net_SMS_clickatell_http extends Net_SMS {
      *   credit      - Is use of the gateway based on credits;
      *   addressbook - Are gateway addressbooks supported;
      *   lists       - Gateway support for distribution lists.
-     * </pre>
      *
-     * @var array
+     * @var array $capabilities
      */
     var $capabilities = array('auth'        => true,
                               'batch'       => 100,
@@ -50,6 +50,8 @@ class Net_SMS_clickatell_http extends Net_SMS {
      */
     function _authenticate()
     {
+        global $conf;
+
         /* We have already authenticated so return true. */
         if (!empty($this->_session_id)) {
             return true;
@@ -82,14 +84,13 @@ class Net_SMS_clickatell_http extends Net_SMS {
      *
      * @access private
      *
-     * @param array $message  The array containing the message and its send
-     *                        parameters.
-     * @param array $to       The recipients.
+     * @param array  $message  The array containing the message and its send
+     *                         parameters.
+     * @param string $to       The destination string.
      *
-     * @return array  An array with the success status and additional
-     *                information.
+     * @return mixed  True on success or PEAR Error on failure.
      */
-    function _send($message, $to)
+    function _send(&$message, $to)
     {
         /* Set up the http sending url. */
         $url = sprintf('sendmsg?session_id=%s&text=%s',
@@ -103,8 +104,7 @@ class Net_SMS_clickatell_http extends Net_SMS {
             $req_feat =+ 16;
             $url .= '&from=' . urlencode($message['send_params']['from']);
         }
-        if (!empty($message['send_params']['msg_type']) &&
-            $message['send_params']['msg_type'] == 'SMS_FLASH') {
+        if ($message['send_params']['msg_type'] == 'SMS_FLASH') {
             /* If message type is flash, require it for transit gateways. */
             $req_feat =+ 512;
             $url .= '&msg_type=' . $message['send_params']['msg_type'];
@@ -153,7 +153,7 @@ class Net_SMS_clickatell_http extends Net_SMS {
      *
      * @access private
      *
-     * @return integer  The credit balance available on the gateway.
+     * @return int  The credit balance available on the gateway.
      */
     function _getBalance()
     {
@@ -177,6 +177,8 @@ class Net_SMS_clickatell_http extends Net_SMS {
     /**
      * Identifies this gateway driver and returns a brief description.
      *
+     * @access public
+     *
      * @return array  Array of driver info.
      */
     function getInfo()
@@ -190,6 +192,8 @@ class Net_SMS_clickatell_http extends Net_SMS {
     /**
      * Returns the required parameters for this gateway driver.
      *
+     * @access public
+     *
      * @return array  Array of required parameters.
      */
     function getParams()
@@ -206,6 +210,8 @@ class Net_SMS_clickatell_http extends Net_SMS {
      * Returns the parameters that can be set as default for sending messages
      * using this gateway driver and displayed when sending messages.
      *
+     * @access public
+     *
      * @return array  Array of parameters that can be set as default.
      * @todo  Set up batch fields/params, would be nice to have ringtone/logo
      *        support too, queue choice, unicode choice.
@@ -236,6 +242,8 @@ class Net_SMS_clickatell_http extends Net_SMS {
      * displayed when sending messages. These are filtered out using the
      * default values set for the gateway.
      *
+     * @access public
+     *
      * @return array  Array of required parameters.
      * @todo  Would be nice to use a time/date setup rather than minutes from
      *        now for the delivery time. Upload field for ringtones/logos?
@@ -270,15 +278,16 @@ class Net_SMS_clickatell_http extends Net_SMS {
     /**
      * Returns a string representation of an error code.
      *
-     * @param integer $error  The error code to look up.
-     * @param string $text    An existing error text to use to raise a
-     *                        PEAR Error.
+     * @access public
      *
-     * @return mixed  A textual message corresponding to the error code or a
+     * @param int $error             The error code to look up.
+     * @param optional string $text  An existing error text to use to raise a
+     *                               PEAR Error.
+     *
+     * @return mixed  A textual message corrisponding to the error code or a
      *                PEAR Error if passed an existing error text.
      *
-     * @todo  Check which of these are actually required and trim down the
-     *        list.
+     * @todo  Check which of these are actually required and trim down the list.
      */
     function getError($error, $error_text = '')
     {
@@ -332,7 +341,7 @@ class Net_SMS_clickatell_http extends Net_SMS {
      */
     function _callURL($url)
     {
-        $options['method'] = 'GET';
+        $options['method'] = 'POST';
         $options['timeout'] = 5;
         $options['allowRedirects'] = true;
 
