@@ -25,12 +25,12 @@ if (!function_exists('_')) {
  * The Horde_Test:: class provides functions used in the test scripts
  * used in the various applications (test.php).
  *
- * $Horde: horde/lib/Test.php,v 1.31 2004/12/06 09:57:59 jan Exp $
+ * $Horde: horde/lib/Test.php,v 1.31.4.4 2005/03/05 20:21:15 chuck Exp $
  *
- * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2004 Jon Parise <jon@horde.org>
- * Copyright 2002-2004 Brent J. Nordquist <bjn@horde.org>
- * Copyright 2003-2004 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 2002-2005 Brent J. Nordquist <bjn@horde.org>
+ * Copyright 2003-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -39,7 +39,6 @@ if (!function_exists('_')) {
  * @author  Jon Parise <jon@horde.org>
  * @author  Brent J. Nordquist <bjn@horde.org>
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.31 $
  * @since   Horde 3.0
  * @package Horde_Test
  */
@@ -199,7 +198,7 @@ class Horde_Test {
 
             if (is_null($status_out)) {
                 $mod_test = extension_loaded($key);
-                $status_out = $this->_status($mod_test);
+                $status_out = $this->_status($mod_test, $fatal);
             }
 
             $entry[] = $descrip;
@@ -207,6 +206,9 @@ class Horde_Test {
 
             if (!is_null($error_msg) && !$mod_test) {
                 $entry[] = $error_msg;
+                if (!$fatal) {
+                    $entry[] = 1;
+                }
             }
 
             $output .= $this->_outputLine($entry);
@@ -330,8 +332,8 @@ class Horde_Test {
                 }
             }
             $entry[] = $key;
-            $entry[] = $this->_status($result);
-          
+            $entry[] = $this->_status($result, !empty($val['required']));
+
             if ($result) {
                 $succeeded[$key] = true;
             } else {
@@ -339,6 +341,9 @@ class Horde_Test {
                     $error_msg .= ' THIS IS A REQUIRED MODULE!';
                 }
                 $entry[] = $error_msg;
+                if (empty($val['required'])) {
+                    $entry[] = 1;
+                }
             }
 
             $output .= $this->_outputLine($entry);
@@ -389,13 +394,15 @@ class Horde_Test {
     }
 
     /**
-     * Displays an error screen with a list of all configuration files that
-     * are missing, together with a description what they do and how they
-     * are created.
+     * Displays an error screen with a list of all configuration files
+     * that are missing, together with a description what they do and
+     * how they are created. If a file can be automatically created
+     * from the defaults, then we do that instead and don't display an
+     * error.
      *
      * @param string $app        The application name
      * @param string $appBase    The path to the application
-     * @param array $files       An array with the "standard" configuration files
+     * @param array  $files      An array with the "standard" configuration files
      *                           that should be checked. Currently supported:
      *                           - conf.php
      *                           - prefs.php
@@ -411,6 +418,24 @@ class Horde_Test {
         }
         $files = array_merge($files, array_keys($additional));
 
+        /* Try to auto-create missing .dist files. */
+        $indices = array_keys($files);
+        foreach ($indices as $index) {
+            if (is_readable($appBase . '/config/' . $files[$index])) {
+                unset($files[$index]);
+            } else {
+                if (@file_exists($appBase . '/config/' . $files[$index] . '.dist') &&
+                    @copy($appBase . '/config/' . $files[$index] . '.dist', $appBase . '/config/' . $files[$index])) {
+                    unset($files[$index]);
+                }
+            }
+        }
+
+        /* Return if we have no missing files left. */
+        if (!count($files)) {
+            return;
+        }
+
         $descriptions = array_merge(array(
             'conf.php' => sprintf('This is the main %s configuration file. ' .
                                   'It contains paths and options for the %s ' .
@@ -428,7 +453,7 @@ class Horde_Test {
                                           'downloadable.', $app),
             'backends.php' => sprintf('This file controls what backends are ' .
                                       'available from %s.', $app),
-            'sources.php' => sprintf('This file defines the list of  available ' .
+            'sources.php' => sprintf('This file defines the list of available ' .
                                      'sources for %s.', $app)
         ), $additional);
         $title = sprintf('%s is not properly configured', $app);
@@ -443,12 +468,10 @@ class Horde_Test {
 HEADER;
 
         foreach ($files as $file) {
-            if (!@is_readable($appBase . '/config/' . $file)) {
-                $description = $descriptions[$file];
-                echo <<< FILE
+            $description = $descriptions[$file];
+            echo <<< FILE
     <h3>$file</h3><p>$description</p>
 FILE;
-            }
         }
 
         echo <<< FOOTER
@@ -489,8 +512,9 @@ FOOTER;
                 $entry[] = $this->_status(false);
                 $entry[] = $val['error'];
             } else {
-                /* Strip '-cvs' from version. */
+                /* Strip '-cvs' and H3 (ver) from version string. */
                 $appver = str_replace('-cvs', '', $apps[$key]->version);
+                $appver = preg_replace('/H3 \((.*)\)/', '$1', $appver);
                 if (version_compare($val['version'], $appver) === 1) {
                     $entry[] = $this->_status(false) . ' (Have version: ' . $apps[$key]->version . '; Need version: ' . $val['version'] . ')';
                     $entry[] = $val['error'];
@@ -609,16 +633,19 @@ FOOTER;
      *
      * @access private
      *
-     * @param boolean $bool  The result of the status check.
+     * @param boolean $bool      The result of the status check.
+     * @param boolean $required  Whether the checked item is required.
      *
      * @return string  The HTML of the result of the status check.
      */
-    function _status($bool)
+    function _status($bool, $required = true)
     {
         if ($bool) {
             return '<font color="green"><b>Yes</b></font>';
-        } else {
+        } elseif ($required) {
             return '<font color="red"><b>No</b></font>';
+        } else {
+            return '<font color="orange"><b>No</b></font>';
         }
     }
 
@@ -632,6 +659,7 @@ FOOTER;
      * 1st value: Header
      * 2nd value: Test Result
      * 3rd value: Error message (if present)
+     * 4th value: Error level (if present): 0 = error, 1 = warning
      * </pre>
      *
      * @return string  HTML output.
@@ -640,7 +668,8 @@ FOOTER;
     {
         $output = '<li>' . array_shift($entry) . ': ' . array_shift($entry);
         if (!empty($entry)) {
-            $output .= '<br /><font color="red"><b>' . array_shift($entry) . '</b></font>' . "\n";
+            $msg = array_shift($entry);
+            $output .= '<br /><font color="' . (empty($entry) || !array_shift($entry) ? 'red' : 'orange') . '"><b>' . $msg . '</b></font>' . "\n";
         }
         $output .= '</li>' . "\n";
 
