@@ -6,7 +6,7 @@ require_once 'Log.php';
 /**
  * VFS API for abstracted file storage and access.
  *
- * $Horde: framework/VFS/VFS.php,v 1.69.4.6 2005/08/03 00:17:18 slusarz Exp $
+ * $Horde: framework/VFS/VFS.php,v 1.69.4.2 2005/01/31 09:25:27 jan Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -22,7 +22,7 @@ class VFS {
     /**
      * Hash containing connection parameters.
      *
-     * @var array
+     * @var array $_params
      */
     var $_params = array();
 
@@ -30,14 +30,14 @@ class VFS {
      * List of additional credentials required for this VFS backend (example:
      * For FTP, we need a username and password to log in to the server with).
      *
-     * @var array
+     * @var array $_credentials
      */
     var $_credentials = array();
 
     /**
      * List of permissions and if they can be changed in this VFS backend.
      *
-     * @var array
+     * @var array $_permissions
      */
     var $_permissions = array(
         'owner' => array('read' => false, 'write' => false, 'execute' => false),
@@ -48,7 +48,7 @@ class VFS {
      * A PEAR Log object. If present, will be used to log errors and
      * informational messages about VFS activity.
      *
-     * @var Log
+     * @var Log $_logger
      */
     var $_logger = null;
 
@@ -56,13 +56,15 @@ class VFS {
      * The log level to use - messages with a higher log level than configured
      * here will not be logged. Defaults to only logging errors or higher.
      *
-     * @var integer
+     * @var integer $_logLevel
      */
     var $_logLevel = PEAR_LOG_ERR;
 
     /**
      * Constructor.
      *
+     * @access public
+     *
      * @param array $params  A hash containing connection parameters.
      */
     function VFS($params = array())
@@ -77,6 +79,8 @@ class VFS {
      * Checks the credentials that we have by calling _connect(), to see if
      * there is a valid login.
      *
+     * @access public
+     *
      * @return mixed  True on success, PEAR_Error describing the problem if the
      *                credentials are invalid.
      */
@@ -88,6 +92,8 @@ class VFS {
     /**
      * Sets configuration parameters.
      *
+     * @access public
+     *
      * @param array $params  An associative array with parameter names as keys.
      */
     function setParams($params = array())
@@ -100,6 +106,8 @@ class VFS {
     /**
      * Returns configuration parameters.
      *
+     * @access public
+     *
      * @param string $name  The parameter to return.
      *
      * @return mixed  The parameter value or null if it doesn't exist.
@@ -163,6 +171,7 @@ class VFS {
     /**
      * Retrieves a file from the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $path  The pathname to the file.
@@ -178,6 +187,7 @@ class VFS {
     /**
      * Stores a file in the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $path         The path to store the file in.
@@ -196,6 +206,7 @@ class VFS {
     /**
      * Stores a file in the VFS from raw data.
      *
+     * @access public
      * @abstract
      *
      * @param string $path         The path to store the file in.
@@ -213,6 +224,7 @@ class VFS {
     /**
      * Moves a file through the backend.
      *
+     * @access public
      * @abstract
      *
      * @param string $path  The path of the original file.
@@ -229,6 +241,7 @@ class VFS {
     /**
      * Copies a file through the backend.
      *
+     * @access public
      * @abstract
      *
      * @param string $path  The path of the original file.
@@ -245,6 +258,7 @@ class VFS {
     /**
      * Deletes a file from the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $path  The path to delete the file from.
@@ -260,6 +274,7 @@ class VFS {
     /**
      * Renames a file in the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $oldpath  The old path to the file.
@@ -277,6 +292,8 @@ class VFS {
     /**
      * Returns if a given file or folder exists in a folder.
      *
+     * @access public
+     *
      * @param string $path  The path to the folder.
      * @param string $name  The file or folder name.
      *
@@ -295,6 +312,7 @@ class VFS {
     /**
      * Creates a folder in the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $path  The parent folder.
@@ -308,8 +326,10 @@ class VFS {
     }
 
     /**
-     * Automatically creates any necessary parent directories in the
-     * specified $path.
+     * Automatically creates any necessary parent directories in the specified
+     * $path.
+     *
+     * @access public
      *
      * @param string $path  The VFS path to autocreate.
      */
@@ -317,20 +337,18 @@ class VFS {
     {
         $dirs = explode('/', $path);
         if (is_array($dirs)) {
-            $cur = '/';
+            $cur = '';
             foreach ($dirs as $dir) {
-                if (!empty($dir)) {
-                    if (!$this->isFolder($cur, $dir)) {
-                        $result = $this->createFolder($cur, $dir);
-                        if (is_a($result, 'PEAR_Error')) {
-                            return $result;
-                        }
+                if (!$this->isFolder($cur, $dir)) {
+                    $result = $this->createFolder($cur, $dir);
+                    if (is_a($result, 'PEAR_Error')) {
+                        return $result;
                     }
-                    if ($cur != '/') {
-                        $cur .= '/';
-                    }
-                    $cur .= $dir;
                 }
+                if (!empty($cur)) {
+                    $cur .= '/';
+                }
+                $cur .= $dir;
             }
         }
 
@@ -340,6 +358,8 @@ class VFS {
     /**
      * Checks if a given item is a folder.
      *
+     * @access public
+     *
      * @param string $path  The parent folder.
      * @param string $name  The item name.
      *
@@ -354,6 +374,7 @@ class VFS {
     /**
      * Deletes a folder from the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $path        The parent folder.
@@ -370,6 +391,8 @@ class VFS {
     /**
      * Removes recursively all files and subfolders from the given folder.
      *
+     * @access public
+     *
      * @param string $path  The path of the folder to empty.
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
@@ -403,6 +426,8 @@ class VFS {
     /**
      * Returns a file list of the directory passed in.
      *
+     * @access public
+     *
      * @param string $path        The path of the directory.
      * @param mixed $filter       String/hash to filter file/dirname on.
      * @param boolean $dotfiles   Show dotfiles?
@@ -431,6 +456,7 @@ class VFS {
     /**
      * Returns an an unsorted file list of the specified directory.
      *
+     * @access public
      * @abstract
      *
      * @param string $path       The path of the directory.
@@ -449,6 +475,8 @@ class VFS {
     /**
      * Returns the current working directory of the VFS backend.
      *
+     * @access public
+     *
      * @return string  The current working directory.
      */
     function getCurrentDirectory()
@@ -502,6 +530,7 @@ class VFS {
     /**
      * Changes permissions for an item on the VFS.
      *
+     * @access public
      * @abstract
      *
      * @param string $path        The parent folder of the item.
@@ -518,6 +547,7 @@ class VFS {
     /**
      * Returns a sorted list of folders in the specified directory.
      *
+     * @access public
      * @abstract
      *
      * @param string $path         The path of the directory to get the
@@ -535,6 +565,8 @@ class VFS {
     /**
      * Returns the list of additional credentials required, if any.
      *
+     * @access public
+     *
      * @return array  Credential list.
      */
     function getRequiredCredentials()
@@ -546,6 +578,8 @@ class VFS {
      * Returns an array specifying what permissions are changeable for this
      * VFS implementation.
      *
+     * @access public
+     *
      * @return array  Changeable permisions.
      */
     function getModifiablePermissions()
@@ -557,6 +591,8 @@ class VFS {
      * Converts a string to all lowercase characters ignoring the current
      * locale.
      *
+     * @access public
+     *
      * @param string $string  The string to be lowercased
      *
      * @return string  The string with lowercase characters
@@ -573,6 +609,8 @@ class VFS {
     /**
      * Returns the character (not byte) length of a string.
      *
+     * @access public
+     *
      * @param string $string   The string to return the length of.
      * @param string $charset  The charset to use when calculating the
      *                         string's length.
@@ -596,6 +634,8 @@ class VFS {
     /**
      * Attempts to return a concrete VFS instance based on $driver.
      *
+     * @access public
+     *
      * @param mixed $driver  The type of concrete VFS subclass to return. This
      *                       is based on the storage driver ($driver). The
      *                       code is dynamically included.
@@ -626,6 +666,8 @@ class VFS {
      *
      * This method must be invoked as: $var = &VFS::singleton()
      *
+     * @access public
+     *
      * @param mixed $driver  The type of concrete VFS subclass to return. This
      *                       is based on the storage driver ($driver). The
      *                       code is dynamically included.
