@@ -4,7 +4,7 @@
  * Encapsulate strategies for getting a real, local filesystem structure from
  * a VFS.
  *
- * $Horde: framework/VFS_ISOWriter/ISOWriter/RealInputStrategy.php,v 1.1.8.4 2005/08/24 14:04:39 selsky Exp $
+ * $Horde: framework/VFS_ISOWriter/ISOWriter/RealInputStrategy.php,v 1.1.8.1 2005/01/03 12:19:21 jan Exp $
  *
  * Copyright 2004-2005 Cronosys, LLC <http://www.cronosys.com/>
  *
@@ -12,6 +12,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jason M. Felice <jfelice@cronosys.com>
+ * @version $Revision: 1.1.8.1 $
  * @package VFS_ISO
  * @since   Horde 3.0
  */
@@ -20,14 +21,14 @@ class VFS_ISOWriter_RealInputStrategy {
     /**
      * A reference to the source VFS we want to read.
      *
-     * @var VFS
+     * @var object $_sourceVfs
      */
     var $_sourceVfs = null;
 
     /**
      * The root directory within the source VFS
      *
-     * @var string
+     * @var string $_sourceRoot
      */
     var $_sourceRoot;
 
@@ -81,7 +82,7 @@ class VFS_ISOWriter_RealInputStrategy {
                       '.php';
         $class = 'VFS_ISOWriter_RealInputStrategy_' . $method;
         if (!class_exists($class)) {
-            return PEAR::raiseError(sprintf(_("Could not load strategy \"%s\"."),
+            return PEAR::raiseError(sprintf(_("Could not load strategy '%s'."),
                                             $method));
         }
 
