@@ -2,14 +2,16 @@
 /**
  * VFS implementation for a standard filesystem.
  *
- * Required parameters:<pre>
- *   'vfsroot'  The root path</pre>
+ * <pre>
+ * Required values for $params:
+ *      'vfsroot'       The root path
+ * </pre>
  *
  * Note: The user that your webserver runs as (commonly 'nobody',
  * 'apache', or 'www-data') MUST have read/write permission to the
  * directory you specific as the 'vfsroot'.
  *
- * $Horde: framework/VFS/VFS/file.php,v 1.63.4.10 2005/07/03 04:52:42 selsky Exp $
+ * $Horde: framework/VFS/VFS/file.php,v 1.63.4.3 2005/03/28 17:24:29 chuck Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -26,7 +28,7 @@ class VFS_file extends VFS {
      * List of permissions and if they can be changed in this VFS
      * backend.
      *
-     * @var array
+     * @var array $_permissions
      */
     var $_permissions = array(
         'owner' => array('read' => true, 'write' => true, 'execute' => true),
@@ -37,7 +39,9 @@ class VFS_file extends VFS {
     /**
      * Constructs a new Filesystem based VFS object.
      *
-     * @param array $params  A hash containing connection parameters.
+     * @access public
+     *
+     * @param optional array $params  A hash containing connection parameters.
      */
     function VFS_file($params = array())
     {
@@ -54,6 +58,8 @@ class VFS_file extends VFS {
     /**
      * Retrieve a file from the VFS.
      *
+     * @access public
+     *
      * @param string $path  The pathname to the file.
      * @param string $name  The filename to retrieve.
      *
@@ -81,11 +87,13 @@ class VFS_file extends VFS {
      * Store a file in the VFS, with the data copied from a temporary
      * file.
      *
-     * @param string $path         The path to store the file in.
-     * @param string $name         The filename to use.
-     * @param string $tmpFile      The temporary file containing the data to be
-     *                             stored.
-     * @param boolean $autocreate  Automatically create directories?
+     * @access public
+     *
+     * @param string $path                  The path to store the file in.
+     * @param string $name                  The filename to use.
+     * @param string $tmpFile               The temporary file containing the
+     *                                      data to be stored.
+     * @param optional boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -116,6 +124,8 @@ class VFS_file extends VFS {
     /**
      * Moves a file in the database and the file system.
      *
+     * @access public
+     *
      * @param string $path  The path to store the file in.
      * @param string $name  The filename to use.
      *
@@ -140,6 +150,8 @@ class VFS_file extends VFS {
     /**
      * Copies a file through the backend.
      *
+     * @access public
+     *
      * @param string $path  The path to store the file in.
      * @param string $name  The filename to use.
      * @param string $dest  The destination of the file.
@@ -169,10 +181,12 @@ class VFS_file extends VFS {
     /**
      * Store a file in the VFS from raw data.
      *
-     * @param string $path         The path to store the file in.
-     * @param string $name         The filename to use.
-     * @param string $data         The file data.
-     * @param boolean $autocreate  Automatically create directories?
+     * @access public
+     *
+     * @param string $path                  The path to store the file in.
+     * @param string $name                  The filename to use.
+     * @param string $data                  The file data.
+     * @param optional boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
      */
@@ -215,6 +229,8 @@ class VFS_file extends VFS {
     /**
      * Delete a file from the VFS.
      *
+     * @access public
+     *
      * @param string $path  The path to store the file in.
      * @param string $name  The filename to use.
      *
@@ -225,16 +241,16 @@ class VFS_file extends VFS {
         if (!@unlink($this->_getNativePath($path, $name))) {
             return PEAR::raiseError(_("Unable to delete VFS file."));
         }
-
-        return true;
     }
 
     /**
      * Delete a folder from the VFS.
      *
-     * @param string $path        The path to delete the folder from.
-     * @param string $name        The foldername to use.
-     * @param boolean $recursive  Force a recursive delete?
+     * @access public
+     *
+     * @param string $path                 The path to delete the folder from.
+     * @param string $name                 The foldername to use.
+     * @param optional boolean $recursive  Force a recursive delete?
      *
      * @return mixed True on success or a PEAR_Error object on failure.
      */
@@ -266,6 +282,8 @@ class VFS_file extends VFS {
     /**
      * Creates a folder on the VFS.
      *
+     * @access public
+     *
      * @param string $path  The path to delete the folder from.
      * @param string $name  The foldername to use.
      *
@@ -283,6 +301,8 @@ class VFS_file extends VFS {
     /**
      * Check if a given pathname is a folder.
      *
+     * @access public
+     *
      * @param string $path  The path to the folder.
      * @param string $name  The file/folder name.
      *
@@ -296,6 +316,8 @@ class VFS_file extends VFS {
     /**
      * Changes permissions for an item in the VFS.
      *
+     * @access public
+     *
      * @param string $path         The path of directory of the item.
      * @param string $name         The name of the item.
      * @param integer $permission  The octal value of the new permission.
@@ -314,10 +336,13 @@ class VFS_file extends VFS {
     /**
      * Return a list of the contents of a folder.
      *
-     * @param string $path       The path of the directory.
-     * @param mixed $filter      String/hash to filter file/dirname on.
-     * @param boolean $dotfiles  Show dotfiles?
-     * @param boolean $dironly   Show only directories?
+     * @access public
+     *
+     * @param string $path                The path of the directory.
+     * @param optional mixed $filter      String/hash to filter file/dirname
+     *                                    on.
+     * @param optional boolean $dotfiles  Show dotfiles?
+     * @param optional boolean $dironly   Show only directories?
      *
      * @return array  File list on success, PEAR_Error on error.
      */
@@ -441,10 +466,13 @@ class VFS_file extends VFS {
     /**
      * Returns a sorted list of folders in specified directory.
      *
-     * @param string $path         The path of the directory to get the
-     *                             directory list for.
-     * @param mixed $filter        Hash of items to filter based on folderlist.
-     * @param boolean $dotfolders  Include dotfolders?
+     * @access public
+     *
+     * @param optional string $path         The path of the directory to get
+     *                                      the directory list for.
+     * @param optional mixed $filter        Hash of items to filter based on
+     *                                      folderlist.
+     * @param optional boolean $dotfolders  Include dotfolders?
      *
      * @return mixed  Folder list on success or a PEAR_Error object on failure.
      */
@@ -465,10 +493,10 @@ class VFS_file extends VFS {
             return $folderList;
         }
 
-        foreach ($folderList as $name => $files) {
-            $folders[$name] = array('val' => $path . '/' . $files['name'],
-                                    'abbrev' => $files['name'],
-                                    'label' => $path . '/' . $files['name']);
+        foreach ($folderList as $files) {
+            $folders[$folder['val']] = array('val' => $path . '/' . $files['name'],
+                                             'abbrev' => $files['name'],
+                                             'label' => $path . '/' . $files['name']);
         }
 
         ksort($folders);
@@ -519,6 +547,8 @@ class VFS_file extends VFS {
     /**
      * Rename a file or folder in the VFS.
      *
+     * @access public
+     *
      * @param string $oldpath  The old path to the file.
      * @param string $oldname  The old filename.
      * @param string $newpath  The new path of the file.
@@ -542,8 +572,8 @@ class VFS_file extends VFS {
      *
      * @access private
      *
-     * @param string $path  The VFS file path.
-     * @param string $name  The VFS filename.
+     * @param optional string $path  The VFS file path.
+     * @param optional string $name  The VFS filename.
      *
      * @return string  The full native filename.
      */
