@@ -44,7 +44,7 @@ define('VFS_FOLDER', 2);
  *    mssql.textsize = 0 ; zero to pass through
  * </pre>
  *
- * $Horde: framework/VFS/VFS/sql.php,v 1.85.4.1 2005/01/03 12:19:20 jan Exp $
+ * $Horde: framework/VFS/VFS/sql.php,v 1.85.4.3 2005/02/17 22:09:10 jan Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -52,7 +52,7 @@ define('VFS_FOLDER', 2);
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.85.4.1 $
+ * @version $Revision: 1.85.4.3 $
  * @since   Horde 2.2
  * @package VFS
  */
@@ -88,24 +88,32 @@ class VFS_sql extends VFS {
     }
 
     /**
-     * Store a file in the VFS.
+     * Stores a file in the VFS.
      *
      * @access public
      *
-     * @param string $path                  The path to store the file in.
-     * @param string $name                  The filename to use.
-     * @param string $tmpFile               The temporary file containing the
-     *                                      data to be stored.
-     * @param optional boolean $autocreate  Automatically create directories?
+     * @param string $path         The path to store the file in.
+     * @param string $name         The filename to use.
+     * @param string $tmpFile      The temporary file containing the data to
+     *                             be stored.
+     * @param boolean $autocreate  Automatically create directories?
      *
      * @return mixed  True on success or a PEAR_Error object on failure.
-
      */
     function write($path, $name, $tmpFile, $autocreate = false)
     {
-        $dataFP = @fopen($tmpFile, 'rb');
-        $data = @fread($dataFP, filesize($tmpFile));
-        @fclose($dataFP);
+        $size = filesize($tmpFile);
+        if ($size === 0) {
+            $data = '';
+        } else {
+            $dataFP = @fopen($tmpFile, 'rb');
+            if (!$dataFP) {
+                return PEAR::raiseError(sprintf(_("The temporary file \"%s\" does not exist."), $tmpFile));
+            }
+            $data = @fread($dataFP, $size);
+            @fclose($dataFP);
+        }
+
         return $this->writeData($path, $name, $data, $autocreate);
     }
 
