@@ -5,7 +5,7 @@
  * Wrapper class that provides some examples and a few convenience
  * methods.
  *
- * $Horde: framework/XML_SVG/SVG.php,v 1.17.10.2 2005/08/01 15:09:47 jan Exp $
+ * $Horde: framework/XML_SVG/SVG.php,v 1.17.10.1 2005/01/03 12:19:22 jan Exp $
  *
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -285,19 +285,13 @@ class XML_SVG_Textpath extends XML_SVG_Element {
     var $_rotate;
     var $_textLength;
     var $_lengthAdjust;
-    var $_charset;
 
     function printElement($element = 'textpath')
     {
         echo '<' . $element;
         $this->printParams('id', 'x', 'y', 'dx', 'dy', 'rotate',
                            'textLength', 'lengthAdjust', 'style', 'transform');
-        echo '>';
-        if (isset($this->_charset)) {
-            echo @htmlspecialchars($this->_text, ENT_COMPAT, $this->_charset);
-        } else {
-            echo htmlspecialchars($this->_text);
-        }
+        echo '>' . htmlentities($this->_text);
         parent::printElement();
         echo "</$element>\n";
     }
