@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/rpc.php,v 1.30.10.3 2006/01/01 21:28:04 jan Exp $
+ * $Horde: horde/rpc.php,v 1.30.10.1 2005/01/03 12:25:28 jan Exp $
  *
- * Copyright 2002-2006 Jan Schneider <jan@horde.org>
+ * Copyright 2002-2005 Jan Schneider <jan@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -18,22 +18,11 @@ require_once 'Horde/RPC.php';
 $input = null;
 $params = null;
 
-if (!empty($_SERVER['PATH_INFO']) ||
-    in_array($_SERVER['REQUEST_METHOD'], array('PROPFIND'))) {
-    $serverType = 'webdav';
-} elseif (isset($_SERVER['REQUEST_METHOD']) &&
-          $_SERVER['REQUEST_METHOD'] == 'GET' &&
-          Util::getGet('restCall')) {
-    $serverType = 'rest';
-} elseif (!empty($_SERVER['CONTENT_TYPE'])) {
+if (!empty($_SERVER['CONTENT_TYPE'])) {
     if (strpos($_SERVER['CONTENT_TYPE'], 'application/vnd.syncml+xml') !== false) {
         $serverType = 'syncml';
-        /* Syncml does its own session handling. */
-        $session_control = 'none';
     } elseif (strpos($_SERVER['CONTENT_TYPE'], 'application/vnd.syncml+wbxml') !== false) {
         $serverType = 'syncml_wbxml';
-        /* Syncml does its own session handling. */
-        $session_control = 'none';
     } elseif (strpos($_SERVER['CONTENT_TYPE'], 'text/xml') !== false) {
         $input = Horde_RPC::getInput();
         /* Check for SOAP namespace URI. */
@@ -77,14 +66,8 @@ $server->authorize();
 if ($input === null) {
     $input = $server->getInput();
 }
-
 $out = $server->getResponse($input, $params);
 
-if (is_a($out, 'PEAR_Error')) {
-    header('HTTP/1.0 500 Internal Server Error');
-    exit;
-}
-
 /* Return the response to the client. */
 header('Content-Type: ' . $server->getResponseContentType());
 header('Content-length: ' . strlen($out));
