@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/services/images/colorpicker.php,v 1.19.10.1 2005/01/03 12:25:45 jan Exp $
+ * $Horde: horde/services/images/colorpicker.php,v 1.19.10.2 2005/01/21 04:06:34 chuck Exp $
  *
  * Copyright 2002-2005 Michael Cochrane <mike@graftonhall.co.nz>
  *
@@ -130,13 +130,7 @@ function brightness(color)
 
 function hex(dec)
 {
-    if (dec == 10) return 'A';
-    if (dec == 11) return 'B';
-    if (dec == 12) return 'C';
-    if (dec == 13) return 'D';
-    if (dec == 14) return 'E';
-    if (dec == 15) return 'F';
-    return '' + dec;
+    return (dec).toString(16);
 }
 //-->
 </script>
