@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/services/problem.php,v 2.114.8.1 2005/01/03 12:25:45 jan Exp $
+ * $Horde: horde/services/problem.php,v 2.114.8.2 2005/01/05 15:06:07 chuck Exp $
  *
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -57,7 +57,7 @@ case 'send_problem_report':
 
         if (!empty($email)) {
             if (!empty($name)) {
-                list($mailbox, $host) = @explode('@', $email);
+                @list($mailbox, $host) = @explode('@', $email, 2);
                 if (empty($host)) {
                     $host = $conf['server']['name'];
                 }
