@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: horde/services/shares/edit.php,v 1.26.10.10 2007/01/02 13:55:17 jan Exp $
+ * $Horde: horde/services/shares/edit.php,v 1.26.10.4 2005/03/14 11:30:31 stuart Exp $
  *
- * Copyright 2002-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -70,22 +70,22 @@ case 'editform':
                     $perm->addUserPermission($new_owner, PERMS_SHOW, false);
                 } else {
                     $perm->removeUserPermission($new_owner, PERMS_SHOW, false);
-                }
+                }                            
                 if (Util::getFormData('owner_read')) {
                     $perm->addUserPermission($new_owner, PERMS_READ, false);
                 } else {
                     $perm->removeUserPermission($new_owner, PERMS_READ, false);
-                }
+                }                            
                 if (Util::getFormData('owner_edit')) {
                     $perm->addUserPermission($new_owner, PERMS_EDIT, false);
                 } else {
                     $perm->removeUserPermission($new_owner, PERMS_EDIT, false);
-                }
+                }                            
                 if (Util::getFormData('owner_delete')) {
                     $perm->addUserPermission($new_owner, PERMS_DELETE, false);
                 } else {
                     $perm->removeUserPermission($new_owner, PERMS_DELETE, false);
-                }
+                }                            
             }
         }
 
@@ -227,13 +227,7 @@ case 'editform':
 
         $share->setPermission($perm, false);
         $share->save();
-
-        if (Util::getFormData('save_and_finish')) {
-            Util::closeWindowJS();
-            exit;
-        }
-
-        $notification->push(sprintf(_("Updated \"%s\"."), $share->get('name')), 'horde.success');
+        $notification->push(sprintf(_("Updated '%s'."), $share->get('name')), 'horde.success');
         $form = 'edit.inc';
     }
     break;
@@ -256,7 +250,7 @@ if ($auth->hasCapability('list')) {
     $userList = array();
 }
 
-$groupList = $groups->getGroupMemberships(Auth::getAuth(), true);
+$groupList = $groups->listGroups();
 if (is_a($groupList, 'PEAR_Error')) {
     Horde::logMessage($groupList, __FILE__, __LINE__, PEAR_LOG_NOTICE);
     $groupList = array();
