@@ -8,9 +8,10 @@
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: horde/templates/javascript/form_sections.js,v 1.11.4.4 2005/05/25 16:46:07 jan Exp $
+ * $Horde: horde/templates/javascript/form_sections.js,v 1.11.4.1 2005/01/03 12:25:46 jan Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
+ * @version $Revision: 1.11.4.1 $
  * @package Horde_Form
  */
 function Horde_Form_Sections(instanceName, openSection)
@@ -27,14 +28,14 @@ function Horde_Form_Sections(instanceName, openSection)
         openSectionId = this._get();
         if (document.getElementById('_section_' + openSectionId)) {
             document.getElementById('_section_' + openSectionId).style.display = 'none';
+            document.getElementById('_tab_' + openSectionId).className = null;
         }
-        document.getElementById('_tab_' + openSectionId).className = null;
 
         /* Get the newly opened section object. */
         if (document.getElementById('_section_' + sectionId)) {
             document.getElementById('_section_' + sectionId).style.display = 'block';
+            document.getElementById('_tab_' + sectionId).className = 'activeTab';
         }
-        document.getElementById('_tab_' + sectionId).className = 'activeTab';
 
         /* Store the newly opened section. */
         this._set(sectionId);
@@ -48,8 +49,7 @@ function Horde_Form_Sections(instanceName, openSection)
     this._set = function(sectionId)
     {
         var form = eval('document.' + this._instanceName);
-        if (typeof form != 'undefined' &&
-            typeof form.__formOpenSection != 'undefined') {
+        if (typeof form != 'undefined') {
             form.__formOpenSection.value = escape(sectionId);
         }
         this._openSection = sectionId;
