@@ -169,13 +169,7 @@ function openGoto(timestamp, imgId, target, callback)
     link.href = '#';
     link.onclick = function()
     {
-        var newMonth = currentDate.getMonth() - 1;
-        var newYear = currentYear;
-        if (newMonth == -1) {
-            newMonth = 11;
-            newYear -= 1;
-        }
-        newDate = new Date(newYear, newMonth, 1);
+        newDate = new Date(currentYear, currentDate.getMonth() - 1, 1);
         openGoto(newDate.getTime(), imgId, currentTarget, callback);
         return false;
     }
