@@ -6,14 +6,15 @@
  * The helpers available:
  *      emoticons - for inserting emoticons strings
  *
- * $Horde: horde/templates/javascript/open_html_helper.js,v 1.12.2.5 2006/05/11 19:49:14 chuck Exp $
+ * $Horde: horde/templates/javascript/open_html_helper.js,v 1.12.2.1 2005/01/03 12:25:46 jan Exp $
  *
- * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (GPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author Marko Djukic <marko@oblo.com>
+ * @version $Revision: 1.12.2.1 $
  * @package horde
  * @todo add handling for font tags, tables, etc.
  */
@@ -43,7 +44,7 @@ function openHtmlHelper(type, target)
     if (type == 'emoticons') {
         row = document.createElement('TR');
         cell = document.createElement('TD');
-        <?php require_once 'Horde/Text/Filter.php'; $filter = Text_Filter::factory('emoticons'); $icons = array_flip($filter->getIcons()); foreach ($icons as $icon => $string): ?>
+        <?php require_once 'Horde/Text/Filter.php'; $filter = &Text_Filter::singleton('emoticons'); $icons = array_flip($filter->getIcons()); foreach ($icons as $icon => $string): ?>
         link = document.createElement('A');
         link.href = '#';
         link.onclick = function() {
