@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/util/icon_browser.php,v 1.4.2.2 2005/08/24 13:42:20 selsky Exp $
+ * $Horde: horde/util/icon_browser.php,v 1.4.2.1 2005/01/03 12:25:48 jan Exp $
  *
  * Copyright 2004-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -22,19 +22,19 @@ if (($app = basename(Util::getFormData('app'))) && isset($apps[$app])) {
 
     $themeDir = $registry->get('themesfs', $app);
     if (!is_dir($themeDir)) {
-        exit(sprintf(_("Themes directory \"%s\" not found."), $themeDir));
+        exit(sprintf(_("Themes directory '%s' not found."), $themeDir));
     }
 
     // Base graphics for now, feel free to add theme support.
     $basedir = $dir = $themeDir . DIRECTORY_SEPARATOR . 'graphics';
     if (!is_dir($dir)) {
-        exit(sprintf(_("Base graphics directory \"%s\" not found."), $dir));
+        exit(sprintf(_("Base graphics directory '%s' not found."), $dir));
     }
 
     if (($subdir = basename(Util::getFormData('subdir')))) {
         $dir .= DIRECTORY_SEPARATOR . $subdir;
         if (!is_dir($dir)) {
-            exit(sprintf(_("Subdirectory \"%s\" not found."), $dir));
+            exit(sprintf(_("Subdirectory '%s' not found."), $dir));
         }
     }
 
